@@ -22,6 +22,8 @@
 #include "config.h"
 
 #include <ctype.h>
+#include <stdlib.h>
+#include <errno.h>
 #include "sbus/sbus_opath.h"
 #include "util/util.h"
 #include "confdb/confdb.h"
@@ -43,6 +45,34 @@
 #define RETRIEVE_DOMAIN_ERROR_MSG "Error (%d [%s]) retrieving domain [%s], "\
                                   "skipping!\n"
 
+static errno_t set_ldb_modules_path(void)
+{
+#ifdef LDB_MODULES_PATH_OVERRIDE
+    static bool initialized = false;
+    int ret;
+
+    if (initialized) {
+        return EOK;
+    }
+
+    ret = setenv("LDB_MODULES_PATH", LDB_MODULES_PATH_OVERRIDE, 0);
+    if (ret != 0) {
+        ret = errno;
+        DEBUG(SSSDBG_FATAL_FAILURE,
+              "Failed to set LDB_MODULES_PATH to [%s]: %s\n",
+              LDB_MODULES_PATH_OVERRIDE, strerror(ret));
+        return ret;
+    }
+
+    DEBUG(SSSDBG_CONF_SETTINGS,
+          "LDB_MODULES_PATH set to [%s]\n",
+          LDB_MODULES_PATH_OVERRIDE);
+
+    initialized = true;
+#endif
+    return EOK;
+}
+
 static int confdb_get_domain_enabled(struct confdb_ctx *cdb,
                                      const char *domain, bool *_enabled);
 
@@ -775,6 +805,14 @@ int confdb_init(TALLOC_CTX *mem_ctx,
     int ret = EOK;
     mode_t old_umask;
 
+    ret = set_ldb_modules_path();
+    if (ret != EOK) {
+        DEBUG(SSSDBG_FATAL_FAILURE,
+              "Failed to initialize LDB modules path [%d]: %s\n",
+              ret, sss_strerror(ret));
+        return ret;
+    }
+
     if (cdb_ctx == NULL) {
         DEBUG(SSSDBG_FATAL_FAILURE, "Bad argument\n");
         return EFAULT;
@@ -1197,38 +1235,22 @@ done:
 static errno_t confdb_init_domain_provider_and_enum(struct sss_domain_info *domain,
                                                     struct ldb_result *res)
 {
-    int val;
     errno_t ret;
     const char *tmp, *tmp_pam_target, *tmp_auth;
 
-#ifndef BUILD_EXTENDED_ENUMERATION_SUPPORT
     if (domain->provider != NULL &&
            ((strcasecmp(domain->provider, "ldap") == 0)
          || (strcasecmp(domain->provider, "proxy") == 0)) ) {
-#endif
-    /* TEMP: test if the old bitfield conf value is used and warn it has been
-     * superseded. */
-    val = ldb_msg_find_attr_as_int(res->msgs[0], CONFDB_DOMAIN_ENUMERATE, 0);
-    if (val > 0) { /* ok there was a number in here */
-        DEBUG(SSSDBG_FATAL_FAILURE,
-              "Warning: enumeration parameter in %s still uses integers! "
-                  "Enumeration is now a boolean and takes true/false values. "
-                  "Interpreting as true\n", domain->name);
-        domain->enumerate = true;
-    } else { /* assume the new format */
         ret = get_entry_as_bool(res->msgs[0], &domain->enumerate,
-                                CONFDB_DOMAIN_ENUMERATE, 0);
+                                CONFDB_DOMAIN_ENUMERATE, false);
         if(ret != EOK) {
             DEBUG(SSSDBG_FATAL_FAILURE,
                   "Invalid value for %s\n", CONFDB_DOMAIN_ENUMERATE);
             goto done;
         }
-    }
-#ifndef BUILD_EXTENDED_ENUMERATION_SUPPORT
     } else {
         domain->enumerate = false;
     }
-#endif
 
     if (domain->provider != NULL && strcasecmp(domain->provider, "proxy") == 0) {
         /* The password field must be reported as 'x' for proxy provider
@@ -1658,28 +1680,6 @@ static errno_t confdb_init_domain_subdomains(struct sss_domain_info *domain,
     errno_t ret;
     const char *tmp;
 
-#ifdef BUILD_EXTENDED_ENUMERATION_SUPPORT
-    tmp = ldb_msg_find_attr_as_string(res->msgs[0],
-                                      CONFDB_SUBDOMAIN_ENUMERATE,
-                                      CONFDB_DEFAULT_SUBDOMAIN_ENUMERATE);
-    if (tmp != NULL) {
-        ret = split_on_separator(domain, tmp, ',', true, true,
-                                 &domain->sd_enumerate, NULL);
-        if (ret != 0) {
-            DEBUG(SSSDBG_FATAL_FAILURE,
-                  "Cannot parse %s\n", CONFDB_SUBDOMAIN_ENUMERATE);
-            goto done;
-        }
-    }
-#else
-    ret = split_on_separator(domain, "none", ',', true, true,
-                             &domain->sd_enumerate, NULL);
-    if (ret != 0) {
-        DEBUG(SSSDBG_FATAL_FAILURE, "Cannot set 'sd_enumerate'\n");
-        goto done;
-    }
-#endif
-
     tmp = ldb_msg_find_attr_as_string(res->msgs[0],
                                       CONFDB_DOMAIN_SUBDOMAIN_INHERIT,
                                       NULL);
@@ -1688,7 +1688,7 @@ static errno_t confdb_init_domain_subdomains(struct sss_domain_info *domain,
                                  &domain->sd_inherit, NULL);
         if (ret != 0) {
             DEBUG(SSSDBG_FATAL_FAILURE,
-                  "Cannot parse %s\n", CONFDB_SUBDOMAIN_ENUMERATE);
+                  "Cannot parse %s\n", CONFDB_DOMAIN_SUBDOMAIN_INHERIT);
             goto done;
         }
     }
