@@ -523,6 +523,15 @@ static int sysdb_attrs_add_val_int(struct sysdb_attrs *attrs,
 
     return EOK;
 }
+
+int sysdb_attrs_add_empty(struct sysdb_attrs *attrs, const char *name)
+{
+    struct ldb_message_element *el;
+
+    /* Calling this will create the element if it does not exist. */
+    return sysdb_attrs_get_el_ext(attrs, name, true, &el);
+}
+
 int sysdb_attrs_add_val(struct sysdb_attrs *attrs,
                         const char *name, const struct ldb_val *val)
 {
@@ -618,7 +627,7 @@ int sysdb_attrs_add_base64_blob(struct sysdb_attrs *attrs, const char *name,
 int sysdb_attrs_add_bool(struct sysdb_attrs *attrs,
                          const char *name, bool value)
 {
-    if(value) {
+    if (value) {
         return sysdb_attrs_add_string(attrs, name, "TRUE");
     }
 
@@ -1395,114 +1404,6 @@ done:
     return ret;
 }
 
-errno_t sysdb_attrs_primary_name(struct sysdb_ctx *sysdb,
-                                 struct sysdb_attrs *attrs,
-                                 const char *ldap_attr,
-                                 const char **_primary)
-{
-    errno_t ret;
-    char *rdn_attr = NULL;
-    char *rdn_val = NULL;
-    struct ldb_message_element *sysdb_name_el;
-    struct ldb_message_element *orig_dn_el;
-    size_t i;
-    TALLOC_CTX *tmp_ctx = NULL;
-
-    tmp_ctx = talloc_new(NULL);
-    if (!tmp_ctx) {
-        return ENOMEM;
-    }
-
-    ret = sysdb_attrs_get_el(attrs,
-                             SYSDB_NAME,
-                             &sysdb_name_el);
-    if (ret != EOK || sysdb_name_el->num_values == 0) {
-        ret = EINVAL;
-        goto done;
-    }
-
-    if (sysdb_name_el->num_values == 1) {
-        /* Entry contains only one name. Just return that */
-        *_primary = (const char *)sysdb_name_el->values[0].data;
-        ret = EOK;
-        goto done;
-    }
-
-    /* Multiple values for name. Check whether one matches the RDN */
-
-    ret = sysdb_attrs_get_el(attrs, SYSDB_ORIG_DN, &orig_dn_el);
-    if (ret) {
-        goto done;
-    }
-    if (orig_dn_el->num_values == 0) {
-        DEBUG(SSSDBG_CRIT_FAILURE, "Original DN is not available.\n");
-        ret = EINVAL;
-        goto done;
-    } else if (orig_dn_el->num_values == 1) {
-        ret = sysdb_get_rdn(sysdb, tmp_ctx,
-                            (const char *) orig_dn_el->values[0].data,
-                            &rdn_attr,
-                            &rdn_val);
-        if (ret != EOK) {
-            DEBUG(SSSDBG_CRIT_FAILURE, "Could not get rdn from [%s]\n",
-                      (const char *) orig_dn_el->values[0].data);
-            goto done;
-        }
-    } else {
-        DEBUG(SSSDBG_CRIT_FAILURE, "Should not have more than one origDN\n");
-        ret = EINVAL;
-        goto done;
-    }
-
-    /* First check whether the attribute name matches */
-    DEBUG(SSSDBG_TRACE_INTERNAL, "Comparing attribute names [%s] and [%s]\n",
-              rdn_attr, ldap_attr);
-    if (strcasecmp(rdn_attr, ldap_attr) != 0) {
-        /* Multiple entries, and the RDN attribute doesn't match.
-         * We have no way of resolving this deterministically,
-         * so we'll use the first value as a fallback.
-         */
-        DEBUG(SSSDBG_MINOR_FAILURE,
-              "The entry has multiple names and the RDN attribute does "
-                  "not match. Will use the first value as fallback.\n");
-        *_primary = (const char *)sysdb_name_el->values[0].data;
-        ret = EOK;
-        goto done;
-    }
-
-    for (i = 0; i < sysdb_name_el->num_values; i++) {
-        if (strcasecmp(rdn_val,
-                       (const char *)sysdb_name_el->values[i].data) == 0) {
-            /* This name matches the RDN. Use it */
-            break;
-        }
-    }
-    if (i < sysdb_name_el->num_values) {
-        /* Match was found */
-        *_primary = (const char *)sysdb_name_el->values[i].data;
-    } else {
-        /* If we can't match the name to the RDN, we just have to
-         * throw up our hands. There's no deterministic way to
-         * decide which name is correct.
-         */
-        DEBUG(SSSDBG_CRIT_FAILURE,
-              "Can't match the name to the RDN\n");
-        ret = EINVAL;
-        goto done;
-    }
-
-    ret = EOK;
-
-done:
-    if (ret != EOK) {
-        DEBUG(SSSDBG_CRIT_FAILURE,
-              "Could not determine primary name: [%d][%s]\n",
-                  ret, strerror(ret));
-    }
-    talloc_free(tmp_ctx);
-    return ret;
-}
-
 /*
  * An entity with multiple names would have multiple SYSDB_NAME attributes
  * after being translated into sysdb names using a map.
@@ -1603,88 +1504,6 @@ done:
     return ret;
 }
 
-static errno_t _sysdb_attrs_primary_name_list(struct sss_domain_info *domain,
-                                              TALLOC_CTX *mem_ctx,
-                                              struct sysdb_attrs **attr_list,
-                                              size_t attr_count,
-                                              const char *ldap_attr,
-                                              bool qualify_names,
-                                              char ***name_list)
-{
-    errno_t ret;
-    size_t i, j;
-    char **list;
-    const char *name;
-
-    /* Assume that every entry has a primary name */
-    list = talloc_array(mem_ctx, char *, attr_count+1);
-    if (!list) {
-        return ENOMEM;
-    }
-
-    j = 0;
-    for (i = 0; i < attr_count; i++) {
-        ret = sysdb_attrs_primary_name(domain->sysdb,
-                                       attr_list[i],
-                                       ldap_attr,
-                                       &name);
-        if (ret != EOK) {
-            DEBUG(SSSDBG_CRIT_FAILURE, "Could not determine primary name\n");
-            /* Skip and continue. Don't advance 'j' */
-            continue;
-        }
-
-        if (qualify_names == false) {
-            list[j] = talloc_strdup(list, name);
-        } else {
-            list[j] = sss_create_internal_fqname(list, name, domain->name);
-        }
-        if (!list[j]) {
-            ret = ENOMEM;
-            goto done;
-        }
-
-        j++;
-    }
-
-    /* NULL-terminate the list */
-    list[j] = NULL;
-
-    *name_list = list;
-
-    ret = EOK;
-
-done:
-    if (ret != EOK) {
-        talloc_free(list);
-    }
-    return ret;
-}
-
-errno_t sysdb_attrs_primary_name_list(struct sss_domain_info *domain,
-                                      TALLOC_CTX *mem_ctx,
-                                      struct sysdb_attrs **attr_list,
-                                      size_t attr_count,
-                                      const char *ldap_attr,
-                                      char ***name_list)
-{
-    return _sysdb_attrs_primary_name_list(domain, mem_ctx, attr_list,
-                                          attr_count, ldap_attr,
-                                          false, name_list);
-}
-
-errno_t sysdb_attrs_primary_fqdn_list(struct sss_domain_info *domain,
-                                      TALLOC_CTX *mem_ctx,
-                                      struct sysdb_attrs **attr_list,
-                                      size_t attr_count,
-                                      const char *ldap_attr,
-                                      char ***name_list)
-{
-    return _sysdb_attrs_primary_name_list(domain, mem_ctx, attr_list,
-                                          attr_count, ldap_attr,
-                                          true, name_list);
-}
-
 errno_t sysdb_msg2attrs(TALLOC_CTX *mem_ctx, size_t count,
                         struct ldb_message **msgs,
                         struct sysdb_attrs ***attrs)
@@ -1879,6 +1698,13 @@ int sysdb_delete_string(struct ldb_message *msg,
     return sysdb_ldb_msg_string_helper(msg, LDB_FLAG_MOD_DELETE, attr, value);
 }
 
+int sysdb_add_bool(struct ldb_message *msg,
+                   const char *attr, bool value)
+{
+    return sysdb_ldb_msg_string_helper(msg, LDB_FLAG_MOD_ADD, attr,
+                                       value ? "TRUE" : "FALSE");
+}
+
 static int sysdb_ldb_msg_ulong_helper(struct ldb_message *msg, int flags,
                                       const char *attr, unsigned long value)
 {
