@@ -122,34 +122,6 @@ static errno_t sysdb_ldb_reconnect(TALLOC_CTX *mem_ctx,
     return ret;
 }
 
-static errno_t sysdb_chown_db_files(struct sysdb_ctx *sysdb,
-                                    uid_t uid, gid_t gid)
-{
-    errno_t ret;
-
-    ret = chown(sysdb->ldb_file, uid, gid);
-    if (ret != 0) {
-        ret = errno;
-        DEBUG(SSSDBG_CRIT_FAILURE,
-              "Cannot set sysdb ownership of %s to %"SPRIuid":%"SPRIgid"\n",
-              sysdb->ldb_file, uid, gid);
-        return ret;
-    }
-
-    if (sysdb->ldb_ts_file != NULL) {
-        ret = chown(sysdb->ldb_ts_file, uid, gid);
-        if (ret != 0) {
-            ret = errno;
-            DEBUG(SSSDBG_CRIT_FAILURE,
-                  "Cannot set sysdb ownership of %s to %"SPRIuid":%"SPRIgid"\n",
-                  sysdb->ldb_ts_file, uid, gid);
-            return ret;
-        }
-    }
-
-    return EOK;
-}
-
 int sysdb_get_db_file(TALLOC_CTX *mem_ctx,
                       const char *provider,
                       const char *name,
@@ -389,6 +361,26 @@ static errno_t sysdb_domain_cache_upgrade(TALLOC_CTX *mem_ctx,
     const char *version;
     struct ldb_context *save_ldb;
 
+    if ((strcmp(cur_version, SYSDB_VERSION_0_1) == 0) ||
+        (strcmp(cur_version, SYSDB_VERSION_0_2) == 0) ||
+        (strcmp(cur_version, SYSDB_VERSION_0_3) == 0) ||
+        (strcmp(cur_version, SYSDB_VERSION_0_4) == 0) ||
+        (strcmp(cur_version, SYSDB_VERSION_0_5) == 0) ||
+        (strcmp(cur_version, SYSDB_VERSION_0_6) == 0) ||
+        (strcmp(cur_version, SYSDB_VERSION_0_7) == 0) ||
+        (strcmp(cur_version, SYSDB_VERSION_0_8) == 0) ||
+        (strcmp(cur_version, SYSDB_VERSION_0_9) == 0) ||
+        (strcmp(cur_version, SYSDB_VERSION_0_10) == 0) ||
+        (strcmp(cur_version, SYSDB_VERSION_0_11) == 0) ||
+        (strcmp(cur_version, SYSDB_VERSION_0_12) == 0) ||
+        (strcmp(cur_version, SYSDB_VERSION_0_13) == 0) ||
+        (strcmp(cur_version, SYSDB_VERSION_0_14) == 0) ||
+        (strcmp(cur_version, SYSDB_VERSION_0_15) == 0)) {
+        DEBUG(SSSDBG_FATAL_FAILURE,
+              "Cache version is way too old and must be deleted manually\n");
+        return EIO;
+    }
+
     tmp_ctx = talloc_new(NULL);
     if (tmp_ctx == NULL) {
         return ENOMEM;
@@ -412,97 +404,6 @@ static errno_t sysdb_domain_cache_upgrade(TALLOC_CTX *mem_ctx,
           "Upgrading DB [%s] from version: %s\n",
           domain->name, version);
 
-    if (strcmp(version, SYSDB_VERSION_0_3) == 0) {
-        ret = sysdb_upgrade_03(sysdb, &version);
-        if (ret != EOK) {
-            goto done;
-        }
-    }
-
-    if (strcmp(version, SYSDB_VERSION_0_4) == 0) {
-        ret = sysdb_upgrade_04(sysdb, &version);
-        if (ret != EOK) {
-            goto done;
-        }
-    }
-
-    if (strcmp(version, SYSDB_VERSION_0_5) == 0) {
-        ret = sysdb_upgrade_05(sysdb, &version);
-        if (ret != EOK) {
-            goto done;
-        }
-    }
-
-    if (strcmp(version, SYSDB_VERSION_0_6) == 0) {
-        ret = sysdb_upgrade_06(sysdb, &version);
-        if (ret != EOK) {
-            goto done;
-        }
-    }
-
-    if (strcmp(version, SYSDB_VERSION_0_7) == 0) {
-        ret = sysdb_upgrade_07(sysdb, &version);
-        if (ret != EOK) {
-            goto done;
-        }
-    }
-
-    if (strcmp(version, SYSDB_VERSION_0_8) == 0) {
-        ret = sysdb_upgrade_08(sysdb, &version);
-        if (ret != EOK) {
-            goto done;
-        }
-    }
-
-    if (strcmp(version, SYSDB_VERSION_0_9) == 0) {
-        ret = sysdb_upgrade_09(sysdb, &version);
-        if (ret != EOK) {
-            goto done;
-        }
-    }
-
-    if (strcmp(version, SYSDB_VERSION_0_10) == 0) {
-        ret = sysdb_upgrade_10(sysdb, domain, &version);
-        if (ret != EOK) {
-            goto done;
-        }
-    }
-
-    if (strcmp(version, SYSDB_VERSION_0_11) == 0) {
-        ret = sysdb_upgrade_11(sysdb, domain, &version);
-        if (ret != EOK) {
-            goto done;
-        }
-    }
-
-    if (strcmp(version, SYSDB_VERSION_0_12) == 0) {
-        ret = sysdb_upgrade_12(sysdb, &version);
-        if (ret != EOK) {
-            goto done;
-        }
-    }
-
-    if (strcmp(version, SYSDB_VERSION_0_13) == 0) {
-        ret = sysdb_upgrade_13(sysdb, &version);
-        if (ret != EOK) {
-            goto done;
-        }
-    }
-
-    if (strcmp(version, SYSDB_VERSION_0_14) == 0) {
-        ret = sysdb_upgrade_14(sysdb, &version);
-        if (ret != EOK) {
-            goto done;
-        }
-    }
-
-    if (strcmp(version, SYSDB_VERSION_0_15) == 0) {
-        ret = sysdb_upgrade_15(sysdb, &version);
-        if (ret != EOK) {
-            goto done;
-        }
-    }
-
     if (strcmp(version, SYSDB_VERSION_0_16) == 0) {
         ret = sysdb_upgrade_16(sysdb, &version);
         if (ret != EOK) {
@@ -875,10 +776,12 @@ static int sysdb_timestamp_cache_connect(struct sysdb_ctx *sysdb,
 int sysdb_domain_init_internal(TALLOC_CTX *mem_ctx,
                                struct sss_domain_info *domain,
                                const char *db_path,
+                               bool create_missing_cache,
                                struct sysdb_dom_upgrade_ctx *upgrade_ctx,
                                struct sysdb_ctx **_ctx)
 {
     TALLOC_CTX *tmp_ctx = NULL;
+    bool ldb_file_missing;
     struct sysdb_ctx *sysdb;
     int ret;
 
@@ -898,6 +801,11 @@ int sysdb_domain_init_internal(TALLOC_CTX *mem_ctx,
     if (ret != EOK) {
         goto done;
     }
+    ldb_file_missing = (access(sysdb->ldb_file, F_OK) == -1 && errno == ENOENT);
+    if (ldb_file_missing && !create_missing_cache) {
+        ret = ENOENT;
+        goto done;
+    }
     DEBUG(SSSDBG_FUNC_DATA,
           "DB File for %s: %s\n", domain->name, sysdb->ldb_file);
     if (sysdb->ldb_ts_file) {
@@ -932,15 +840,13 @@ done:
 int sysdb_init(TALLOC_CTX *mem_ctx,
                struct sss_domain_info *domains)
 {
-    return sysdb_init_ext(mem_ctx, domains, NULL, false, 0, 0);
+    return sysdb_init_ext(mem_ctx, domains, false, NULL);
 }
 
 int sysdb_init_ext(TALLOC_CTX *mem_ctx,
                    struct sss_domain_info *domains,
-                   struct sysdb_upgrade_ctx *upgrade_ctx,
-                   bool chown_dbfile,
-                   uid_t uid,
-                   gid_t gid)
+                   bool create_missing_cache,
+                   struct sysdb_upgrade_ctx *upgrade_ctx)
 {
     struct sss_domain_info *dom;
     struct sysdb_ctx *sysdb;
@@ -948,14 +854,6 @@ int sysdb_init_ext(TALLOC_CTX *mem_ctx,
     TALLOC_CTX *tmp_ctx;
     struct sysdb_dom_upgrade_ctx *dom_upgrade_ctx;
 
-    if (upgrade_ctx != NULL) {
-        /* check if we have an old sssd.ldb to upgrade */
-        ret = sysdb_check_upgrade_02(domains, DB_PATH);
-        if (ret != EOK) {
-            return ret;
-        }
-    }
-
     tmp_ctx = talloc_new(mem_ctx);
     if (tmp_ctx == NULL) {
         return ENOMEM;
@@ -978,7 +876,7 @@ int sysdb_init_ext(TALLOC_CTX *mem_ctx,
             dom_upgrade_ctx = NULL;
         }
 
-        ret = sysdb_domain_init_internal(tmp_ctx, dom, DB_PATH,
+        ret = sysdb_domain_init_internal(tmp_ctx, dom, DB_PATH, create_missing_cache,
                                          dom_upgrade_ctx, &sysdb);
         if (ret != EOK) {
             DEBUG(SSSDBG_CRIT_FAILURE,
@@ -987,16 +885,6 @@ int sysdb_init_ext(TALLOC_CTX *mem_ctx,
             goto done;
         }
 
-        if (chown_dbfile) {
-            ret = sysdb_chown_db_files(sysdb, uid, gid);
-            if (ret != EOK) {
-                DEBUG(SSSDBG_CRIT_FAILURE,
-                      "Cannot chown databases for %s: [%d]: %s\n",
-                      dom->name, ret, sss_strerror(ret));
-                goto done;
-            }
-        }
-
         dom->sysdb = talloc_move(dom, &sysdb);
     }
 
@@ -1012,5 +900,5 @@ int sysdb_domain_init(TALLOC_CTX *mem_ctx,
                       struct sysdb_ctx **_ctx)
 {
     return sysdb_domain_init_internal(mem_ctx, domain,
-                                      db_path, false, _ctx);
+                                      db_path, false, NULL, _ctx);
 }
