@@ -598,36 +598,6 @@ static char *enum_filter(TALLOC_CTX *mem_ctx,
     return filter;
 }
 
-int sysdb_getpwupn(TALLOC_CTX *mem_ctx,
-                   struct sss_domain_info *domain,
-                   bool domain_scope,
-                   const char *upn,
-                   struct ldb_result **_res)
-{
-    TALLOC_CTX *tmp_ctx;
-    struct ldb_result *res;
-    static const char *attrs[] = SYSDB_PW_ATTRS;
-    errno_t ret;
-
-    tmp_ctx = talloc_new(NULL);
-    if (tmp_ctx == NULL) {
-        DEBUG(SSSDBG_CRIT_FAILURE, "talloc_new() failed\n");
-        return ENOMEM;
-    }
-
-    ret = sysdb_search_user_by_upn_res(tmp_ctx, domain, domain_scope, upn, attrs, &res);
-    if (ret != EOK && ret != ENOENT) {
-        DEBUG(SSSDBG_OP_FAILURE, "sysdb_search_user_by_upn_res() failed.\n");
-        goto done;
-    }
-
-    *_res = talloc_steal(mem_ctx, res);
-
-done:
-    talloc_free(tmp_ctx);
-    return ret;
-}
-
 errno_t sysdb_search_ts_matches(TALLOC_CTX *mem_ctx,
                                 struct sysdb_ctx *sysdb,
                                 const char *attrs[],
@@ -1190,6 +1160,7 @@ int sysdb_getgrnam(TALLOC_CTX *mem_ctx,
     struct ldb_result *res = NULL;
     char *lc_sanitized_name;
     const char *originalad_sanitized_name;
+    const char *objectcat;
     int ret;
 
     tmp_ctx = talloc_new(NULL);
@@ -1230,11 +1201,17 @@ int sysdb_getgrnam(TALLOC_CTX *mem_ctx,
         if (res->count > 0) {
             originalad_sanitized_name = ldb_msg_find_attr_as_string(
                     res->msgs[0], ORIGINALAD_PREFIX SYSDB_NAME, NULL);
+            objectcat = ldb_msg_find_attr_as_string(
+                        res->msgs[0], SYSDB_OBJECTCATEGORY, NULL);
+            DEBUG(SSSDBG_TRACE_FUNC, "Object category check: objectcat=%s\n",
+                  objectcat ? objectcat : "NULL");
 
             if (originalad_sanitized_name != NULL
                     && !sss_string_equal(domain->case_sensitive,
                                          originalad_sanitized_name,
-                                         sanitized_name)) {
+                                         sanitized_name)
+                    && objectcat != NULL
+                    && !strcmp(objectcat, "group")) {
                 fmt_filter = SYSDB_GRNAM_FILTER;
                 base_dn = sysdb_group_base_dn(tmp_ctx, domain);
                 res = NULL;
