@@ -36,10 +36,10 @@ struct sss_domain_info *new_subdomain(TALLOC_CTX *mem_ctx,
                                       const char *dns_name,
                                       const char *id,
                                       enum sss_domain_mpg_mode mpg_mode,
-                                      bool enumerate,
                                       const char *forest,
                                       const char **upn_suffixes,
                                       uint32_t trust_direction,
+                                      uint32_t trust_type,
                                       struct confdb_ctx *confdb,
                                       bool enabled)
 {
@@ -146,7 +146,7 @@ struct sss_domain_info *new_subdomain(TALLOC_CTX *mem_ctx,
         goto fail;
     }
 
-    dom->enumerate = enumerate;
+    dom->enumerate = false;
     dom->fqnames = true;
     dom->mpg_mode = mpg_mode;
     dom->state = enabled ? DOM_ACTIVE : DOM_DISABLED;
@@ -175,6 +175,7 @@ struct sss_domain_info *new_subdomain(TALLOC_CTX *mem_ctx,
     dom->case_preserve = inherit_option ? parent->case_preserve : false;
 
     dom->trust_direction = trust_direction;
+    dom->trust_type = trust_type;
     /* If the parent domain explicitly limits ID ranges, the subdomain
      * should honour the limits as well.
      */
@@ -412,9 +413,9 @@ errno_t sysdb_update_subdomains(struct sss_domain_info *domain,
                            SYSDB_SUBDOMAIN_DNS,
                            SYSDB_SUBDOMAIN_ID,
                            SYSDB_SUBDOMAIN_MPG,
-                           SYSDB_SUBDOMAIN_ENUM,
                            SYSDB_SUBDOMAIN_FOREST,
                            SYSDB_SUBDOMAIN_TRUST_DIRECTION,
+                           SYSDB_SUBDOMAIN_TRUST_TYPE,
                            SYSDB_UPN_SUFFIXES,
                            SYSDB_ENABLED,
                            NULL};
@@ -429,8 +430,8 @@ errno_t sysdb_update_subdomains(struct sss_domain_info *domain,
     const char *str_mpg_mode;
     bool enabled;
     enum sss_domain_mpg_mode mpg_mode;
-    bool enumerate;
     uint32_t trust_direction;
+    uint32_t trust_type;
     struct ldb_message_element *tmp_el;
     const char **upn_suffixes;
 
@@ -494,13 +495,6 @@ errno_t sysdb_update_subdomains(struct sss_domain_info *domain,
         }
         mpg_mode = str_to_domain_mpg_mode(str_mpg_mode);
 
-#ifdef BUILD_EXTENDED_ENUMERATION_SUPPORT
-        enumerate = ldb_msg_find_attr_as_bool(res->msgs[i],
-                                              SYSDB_SUBDOMAIN_ENUM, false);
-#else
-        enumerate = false;
-#endif
-
         forest = ldb_msg_find_attr_as_string(res->msgs[i],
                                              SYSDB_SUBDOMAIN_FOREST, NULL);
 
@@ -519,6 +513,10 @@ errno_t sysdb_update_subdomains(struct sss_domain_info *domain,
                                              SYSDB_SUBDOMAIN_TRUST_DIRECTION,
                                              0);
 
+        trust_type = ldb_msg_find_attr_as_int(res->msgs[i],
+                                              SYSDB_SUBDOMAIN_TRUST_TYPE,
+                                              0);
+
         enabled = ldb_msg_find_attr_as_bool(res->msgs[i], SYSDB_ENABLED, true);
 
         for (dom = domain->subdomains; dom;
@@ -590,13 +588,7 @@ errno_t sysdb_update_subdomains(struct sss_domain_info *domain,
                     dom->mpg_mode = mpg_mode;
                 }
 
-                if (dom->enumerate != enumerate) {
-                    DEBUG(SSSDBG_TRACE_INTERNAL,
-                          "enumerate state change from [%s] to [%s]!\n",
-                           dom->enumerate ? "true" : "false",
-                           enumerate ? "true" : "false");
-                    dom->enumerate = enumerate;
-                }
+                dom->enumerate = false;
 
                 if ((dom->forest == NULL && forest != NULL)
                         || (dom->forest != NULL && forest != NULL
@@ -651,15 +643,21 @@ errno_t sysdb_update_subdomains(struct sss_domain_info *domain,
                     dom->trust_direction = trust_direction;
                 }
 
+                if (dom->trust_type != trust_type) {
+                    DEBUG(SSSDBG_TRACE_INTERNAL,
+                          "Trust type change from [%d] to [%d]!\n",
+                           dom->trust_type, trust_type);
+                    dom->trust_type = trust_type;
+                }
                 break;
             }
         }
         /* If not found in loop it is a new subdomain */
         if (dom == NULL) {
             dom = new_subdomain(domain, domain, name, realm,
-                                flat, dns, id, mpg_mode, enumerate, forest,
-                                upn_suffixes, trust_direction, confdb,
-                                enabled);
+                                flat, dns, id, mpg_mode, forest,
+                                upn_suffixes, trust_direction, trust_type,
+                                confdb, enabled);
             if (dom == NULL) {
                 ret = ENOMEM;
                 goto done;
@@ -1085,8 +1083,9 @@ errno_t sysdb_subdomain_store(struct sysdb_ctx *sysdb,
                               const char *flat_name, const char *dns_name,
                               const char *domain_id,
                               enum sss_domain_mpg_mode mpg_mode,
-                              bool enumerate, const char *forest,
+                              const char *forest,
                               uint32_t trust_direction,
+                              uint32_t trust_type,
                               struct ldb_message_element *upn_suffixes)
 {
     TALLOC_CTX *tmp_ctx;
@@ -1099,25 +1098,25 @@ errno_t sysdb_subdomain_store(struct sysdb_ctx *sysdb,
                            SYSDB_SUBDOMAIN_DNS,
                            SYSDB_SUBDOMAIN_ID,
                            SYSDB_SUBDOMAIN_MPG,
-                           SYSDB_SUBDOMAIN_ENUM,
                            SYSDB_SUBDOMAIN_FOREST,
                            SYSDB_SUBDOMAIN_TRUST_DIRECTION,
+                           SYSDB_SUBDOMAIN_TRUST_TYPE,
                            SYSDB_UPN_SUFFIXES,
                            NULL};
     const char *tmp_str;
     struct ldb_message_element *tmp_el;
-    bool tmp_bool;
     bool store = false;
     int realm_flags = 0;
     int flat_flags = 0;
     int dns_flags = 0;
     int id_flags = 0;
     int mpg_flags = 0;
-    int enum_flags = 0;
     int forest_flags = 0;
     int td_flags = 0;
+    int tt_flags = 0;
     int upn_flags = 0;
     uint32_t tmp_td;
+    uint32_t tmp_tt;
     int ret;
 
     tmp_ctx = talloc_new(NULL);
@@ -1148,9 +1147,9 @@ errno_t sysdb_subdomain_store(struct sysdb_ctx *sysdb,
         if (dns_name) dns_flags = LDB_FLAG_MOD_ADD;
         if (domain_id) id_flags = LDB_FLAG_MOD_ADD;
         mpg_flags = LDB_FLAG_MOD_ADD;
-        enum_flags = LDB_FLAG_MOD_ADD;
         if (forest) forest_flags = LDB_FLAG_MOD_ADD;
         if (trust_direction) td_flags = LDB_FLAG_MOD_ADD;
+        if (trust_type) tt_flags = LDB_FLAG_MOD_ADD;
         if (upn_suffixes) upn_flags = LDB_FLAG_MOD_ADD;
     } else if (res->count != 1) {
         ret = EINVAL;
@@ -1212,12 +1211,6 @@ errno_t sysdb_subdomain_store(struct sysdb_ctx *sysdb,
             break;
         }
 
-        tmp_bool = ldb_msg_find_attr_as_bool(res->msgs[0], SYSDB_SUBDOMAIN_ENUM,
-                                             !enumerate);
-        if (tmp_bool != enumerate) {
-            enum_flags = LDB_FLAG_MOD_REPLACE;
-        }
-
         if (forest) {
             tmp_str = ldb_msg_find_attr_as_string(res->msgs[0],
                                                   SYSDB_SUBDOMAIN_FOREST, NULL);
@@ -1233,6 +1226,13 @@ errno_t sysdb_subdomain_store(struct sysdb_ctx *sysdb,
             td_flags = LDB_FLAG_MOD_REPLACE;
         }
 
+        tmp_tt = ldb_msg_find_attr_as_uint(res->msgs[0],
+                                           SYSDB_SUBDOMAIN_TRUST_TYPE,
+                                           0);
+        if (tmp_tt != trust_type) {
+            tt_flags = LDB_FLAG_MOD_REPLACE;
+        }
+
         if (upn_suffixes) {
             tmp_el = ldb_msg_find_element(res->msgs[0], SYSDB_UPN_SUFFIXES);
             /* Luckily ldb_msg_element_compare() only compares the values and
@@ -1246,8 +1246,8 @@ errno_t sysdb_subdomain_store(struct sysdb_ctx *sysdb,
 
     if (!store && realm_flags == 0 && flat_flags == 0
             && dns_flags == 0 && id_flags == 0
-            && mpg_flags == 0 && enum_flags == 0 && forest_flags == 0
-            && td_flags == 0 && upn_flags == 0) {
+            && mpg_flags == 0 && forest_flags == 0
+            && td_flags == 0 && tt_flags == 0 && upn_flags == 0) {
         ret = EOK;
         goto done;
     }
@@ -1350,21 +1350,6 @@ errno_t sysdb_subdomain_store(struct sysdb_ctx *sysdb,
         }
     }
 
-    if (enum_flags) {
-        ret = ldb_msg_add_empty(msg, SYSDB_SUBDOMAIN_ENUM, enum_flags, NULL);
-        if (ret != LDB_SUCCESS) {
-            ret = sysdb_error_to_errno(ret);
-            goto done;
-        }
-
-        ret = ldb_msg_add_string(msg, SYSDB_SUBDOMAIN_ENUM,
-                                 enumerate ? "TRUE" : "FALSE");
-        if (ret != LDB_SUCCESS) {
-            ret = sysdb_error_to_errno(ret);
-            goto done;
-        }
-    }
-
     if (forest_flags) {
         ret = ldb_msg_add_empty(msg, SYSDB_SUBDOMAIN_FOREST, forest_flags,
                                 NULL);
@@ -1396,6 +1381,22 @@ errno_t sysdb_subdomain_store(struct sysdb_ctx *sysdb,
         }
     }
 
+    if (tt_flags) {
+        ret = ldb_msg_add_empty(msg, SYSDB_SUBDOMAIN_TRUST_TYPE,
+                                tt_flags, NULL);
+        if (ret != LDB_SUCCESS) {
+            ret = sysdb_error_to_errno(ret);
+            goto done;
+        }
+
+        ret = ldb_msg_add_fmt(msg, SYSDB_SUBDOMAIN_TRUST_TYPE,
+                              "%u", trust_type);
+        if (ret != LDB_SUCCESS) {
+            ret = sysdb_error_to_errno(ret);
+            goto done;
+        }
+    }
+
     if (upn_flags) {
         tmp_el = talloc_zero(tmp_ctx, struct ldb_message_element);
         if (tmp_el == NULL) {
@@ -1579,6 +1580,84 @@ done:
     return ret;
 }
 
+errno_t
+sysdb_domain_update_domain_template(struct sss_domain_info *parent,
+                                    struct sysdb_ctx *sysdb,
+                                    const char *subdom_name,
+                                    const char *home_dir,
+                                    const char *login_shell)
+{
+
+    TALLOC_CTX *tmp_ctx;
+    struct ldb_dn *dn;
+    struct sss_domain_info *subdom;
+    errno_t ret;
+
+    if (home_dir == NULL && login_shell == NULL) {
+        DEBUG(SSSDBG_OP_FAILURE,
+              "Either login shell or home directory must be provided\n");
+        return EINVAL;
+    }
+
+    tmp_ctx = talloc_new(NULL);
+    if (tmp_ctx == NULL) {
+        return ENOMEM;
+    }
+
+    dn = ldb_dn_new_fmt(tmp_ctx, sysdb->ldb, SYSDB_DOM_BASE, subdom_name);
+    if (dn == NULL) {
+        ret = ENOMEM;
+        goto done;
+    }
+
+    ret = sysdb_update_domain_template(sysdb, dn,
+                                       home_dir, login_shell);
+    if (ret != EOK) {
+        DEBUG(SSSDBG_OP_FAILURE,
+              "sysdb_update_domain_template() failed [%d]: [%s].\n",
+              ret, sss_strerror(ret));
+        goto done;
+    }
+
+    /* Update sss_domain_info struct to have templates available in memory */
+    subdom = find_domain_by_name(parent, subdom_name, true);
+    if (!subdom) {
+        DEBUG(SSSDBG_CRIT_FAILURE,
+              "Could not find domain matching [%s]\n",
+              subdom_name);
+        ret = EIO;
+        goto done;
+    }
+
+    if (home_dir != NULL) {
+        subdom->template_homedir = talloc_strdup(subdom, home_dir);
+        if (subdom->template_homedir == NULL) {
+            DEBUG(SSSDBG_OP_FAILURE, "Failed to copy homedir template.\n");
+            ret = ENOMEM;
+            goto done;
+        }
+    } else {
+        subdom->template_homedir = NULL;
+    }
+
+    if (login_shell != NULL) {
+        subdom->template_shell = talloc_strdup(subdom, login_shell);
+        if (subdom->template_shell == NULL) {
+            DEBUG(SSSDBG_OP_FAILURE, "Failed to copy shell template.\n");
+            ret = ENOMEM;
+            goto done;
+        }
+    } else {
+        subdom->template_shell = NULL;
+    }
+
+    ret = EOK;
+
+done:
+    talloc_free(tmp_ctx);
+    return ret;
+}
+
 errno_t
 sysdb_domain_update_domain_resolution_order(struct sysdb_ctx *sysdb,
                                             const char *domain_name,
