@@ -595,3 +595,54 @@ sss_passkey_message_encode_padata_array(const struct sss_passkey_message *data)
     return sss_radius_encode_padata_array(SSSD_PASSKEY_PADATA,
         (sss_radius_message_encode_fn)sss_passkey_message_encode, data);
 }
+
+krb5_error_code
+sss_passkey_concat_credentials(char **creds,
+                               char **_creds_str)
+{
+    krb5_error_code ret;
+    char *result_creds = NULL;
+    size_t total_sz = 0;
+    size_t len = 0;
+    int rc = 0;
+
+    for (int i = 0; creds[i] != NULL; i++) {
+        total_sz += strlen(creds[i]);
+        if (i > 0) {
+            /* separating comma in resulting creds string */
+            total_sz++;
+        }
+    }
+
+    result_creds = malloc(total_sz + 1);
+    if (result_creds == NULL) {
+        ret = ENOMEM;
+        goto done;
+    }
+
+    len = strlen(creds[0]);
+
+    rc = snprintf(result_creds, len + 1, "%s", creds[0]);
+    if (rc < 0 || rc > len) {
+        ret = ENOMEM;
+        free(result_creds);
+        goto done;
+    }
+
+    for (int i = 1; creds[i] != NULL; i++) {
+        rc = snprintf(result_creds + len, total_sz - len + 1, ",%s", creds[i]);
+        if (rc < 0 || rc > total_sz - len) {
+            ret = ENOMEM;
+            free(result_creds);
+            goto done;
+        }
+
+        len += rc;
+    }
+
+    *_creds_str = result_creds;
+
+    ret = 0;
+done:
+    return ret;
+}
