@@ -30,12 +30,42 @@
 
 #include "oidc_child/oidc_child_util.h"
 
+#include "util/child_bootstrap.h"
+#include "util/memory_erase.h"
 #include "util/util.h"
+#include "util/sss_chain_id.h"
+#include "util/sss_prctl.h"
 #include "util/atomic_io.h"
 
-#define IN_BUF_SIZE 4096
+const char *oidc_cmd_str[] = {
+    "no command",
+    "get-device-code",
+    "get-access-token",
+    "get-user",
+    "get-user-groups",
+    "get-group",
+    "get-group-members",
+    NULL
+};
+
+#define IS_ID_CMD(cmd) ( \
+    cmd == GET_USER || cmd == GET_USER_GROUPS \
+                              || cmd == GET_GROUP \
+                              || cmd == GET_GROUP_MEMBERS )
+
+
+static const char *oidc_cmd_to_str(enum oidc_cmd oidc_cmd)
+{
+    if (oidc_cmd < NO_CMD || oidc_cmd >= CMD_SENTINEL) {
+        return "Unknown command";
+    }
+
+    return oidc_cmd_str[oidc_cmd];
+}
+
 static errno_t read_from_stdin(TALLOC_CTX *mem_ctx, char **out)
 {
+    static const size_t IN_BUF_SIZE = 4096;
     uint8_t buf[IN_BUF_SIZE];
     ssize_t len;
     errno_t ret;
@@ -52,7 +82,7 @@ static errno_t read_from_stdin(TALLOC_CTX *mem_ctx, char **out)
     }
 
     if (len == 0 || *buf == '\0') {
-        DEBUG(SSSDBG_CRIT_FAILURE, "Missing device code\n");
+        DEBUG(SSSDBG_CRIT_FAILURE, "Missing data on stdin.\n");
         return EINVAL;
     }
 
@@ -76,7 +106,7 @@ static errno_t read_from_stdin(TALLOC_CTX *mem_ctx, char **out)
 }
 
 static errno_t read_device_code_from_stdin(struct devicecode_ctx *dc_ctx,
-                                           const char **out)
+                                           char **out)
 {
     char *str;
     errno_t ret;
@@ -104,29 +134,34 @@ static errno_t read_device_code_from_stdin(struct devicecode_ctx *dc_ctx,
         sep = str;
     }
 
-    clean_http_data(dc_ctx);
-    dc_ctx->http_data = talloc_strdup(dc_ctx, sep);
+    clean_http_data(dc_ctx->rest_ctx);
+    ret = set_http_data(dc_ctx->rest_ctx, sep);
+    if (ret != EOK) {
+        DEBUG(SSSDBG_OP_FAILURE, "Failed to copy device code data.\n");
+        return ret;
+    }
 
-    DEBUG(SSSDBG_TRACE_ALL, "JSON device code: [%s].\n", dc_ctx->http_data);
+    DEBUG(SSSDBG_TRACE_ALL, "JSON device code: [%s].\n",
+                            get_http_data(dc_ctx->rest_ctx));
 
     return EOK;
 }
 
-static errno_t read_client_secret_from_stdin(struct devicecode_ctx *dc_ctx,
-                                             const char **out)
+static errno_t read_client_secret_from_stdin(TALLOC_CTX *mem_ctx,
+                                             char **out)
 {
     char *str;
     errno_t ret;
 
-    ret = read_from_stdin(dc_ctx, &str);
+    ret = read_from_stdin(mem_ctx, &str);
     if (ret != EOK) {
-        DEBUG(SSSDBG_OP_FAILURE, "read_from_stdin failed.\n");
+        DEBUG(SSSDBG_OP_FAILURE, "read_from_stdin() failed.\n");
         return ret;
     }
 
     *out = str;
 
-    DEBUG(SSSDBG_TRACE_ALL, "Client secret: [%s].\n", *out);
+    DEBUG(SSSDBG_TRACE_ALL, "Client secret was read.\n");
 
     return EOK;
 }
@@ -201,23 +236,13 @@ static struct devicecode_ctx *get_dc_ctx(TALLOC_CTX *mem_ctx,
         goto done;
     }
 
-    ret = init_curl(dc_ctx);
-    if (ret != EOK) {
-        DEBUG(SSSDBG_OP_FAILURE, "Failed to init libcurl.\n");
+    dc_ctx->rest_ctx = get_rest_ctx(dc_ctx, libcurl_debug, ca_db);
+    if (dc_ctx->rest_ctx == NULL) {
+        DEBUG(SSSDBG_OP_FAILURE, "Failed to get curl context.\n");
+        ret = ENOMEM;
         goto done;
     }
 
-    dc_ctx->libcurl_debug = libcurl_debug;
-
-    if (ca_db != NULL) {
-        dc_ctx->ca_db = talloc_strdup(dc_ctx, ca_db);
-        if (dc_ctx->ca_db == NULL) {
-            DEBUG(SSSDBG_OP_FAILURE, "Failed to copy CA DB path.\n");
-            ret = ENOMEM;
-            goto done;
-        }
-    }
-
     if (issuer_url != NULL) {
         ret = get_openid_configuration(dc_ctx, issuer_url);
         if (ret != EOK) {
@@ -252,45 +277,66 @@ done:
 }
 
 struct cli_opts {
-    const char *opt_logger;
-    int backtrace;
-    const char *issuer_url;
-    const char *client_id;
-    const char *device_auth_endpoint;
-    const char *token_endpoint;
-    const char *userinfo_endpoint;
-    const char *jwks_uri;
-    const char *scope;
-    const char *client_secret;
+    char *issuer_url;
+    char *client_id;
+    char *device_auth_endpoint;
+    char *token_endpoint;
+    char *userinfo_endpoint;
+    char *jwks_uri;
+    char *scope;
+    char *client_secret;
     bool client_secret_stdin;
-    const char *ca_db;
-    const char *user_identifier_attr;
+    char *ca_db;
+    char *user_identifier_attr;
     bool libcurl_debug;
-    bool get_device_code;
-    bool get_access_token;
+    enum oidc_cmd oidc_cmd;
+    enum search_str_type search_str_type;
+    char *search_str;
+    char *idp_type;
 };
 
+static void free_cli_opts_members(struct cli_opts *opts)
+{
+    free(opts->issuer_url);
+    free(opts->client_id);
+    free(opts->device_auth_endpoint);
+    free(opts->token_endpoint);
+    free(opts->userinfo_endpoint);
+    free(opts->jwks_uri);
+    free(opts->scope);
+    if (opts->client_secret != NULL) {
+        sss_erase_mem_securely(opts->client_secret, strlen(opts->client_secret));
+    }
+    free(opts->client_secret);
+    free(opts->ca_db);
+    free(opts->user_identifier_attr);
+    free(opts->search_str);
+    free(opts->idp_type);
+}
+
 static int parse_cli(int argc, const char *argv[], struct cli_opts *opts)
 {
     poptContext pc;
     int opt;
     errno_t ret;
-    int backtrace = 1;
-    int debug_fd = -1;
-    const char *opt_logger = NULL;
     bool print_usage = true;
+    char *tmp_name = NULL;
+    char *tmp_obj_id = NULL;
 
     struct poptOption long_options[] = {
-        POPT_AUTOHELP
-        SSSD_DEBUG_OPTS
-        {"backtrace", 0, POPT_ARG_INT, &backtrace, 0,
-         _("Enable debug backtrace"), NULL },
-        {"debug-fd", 0, POPT_ARG_INT, &debug_fd, 0,
-         _("An open file descriptor for the debug logs"), NULL},
-        {"get-device-code", 0, POPT_ARG_NONE, NULL, 'a',
+        SSSD_BASIC_CHILD_OPTS
+        {"get-device-code", 0, POPT_ARG_VAL, &opts->oidc_cmd, GET_DEVICE_CODE,
                 _("Get device code and URL"), NULL},
-        {"get-access-token", 0, POPT_ARG_NONE, NULL, 'b',
+        {"get-access-token", 0, POPT_ARG_VAL, &opts->oidc_cmd, GET_ACCESS_TOKEN,
                 _("Wait for access token"), NULL},
+        {"get-user", 0, POPT_ARG_VAL, &opts->oidc_cmd, GET_USER,
+                _("Lookup a user"), NULL},
+        {"get-user-groups", 0, POPT_ARG_VAL, &opts->oidc_cmd, GET_USER_GROUPS,
+                _("Lookup groups of a user"), NULL},
+        {"get-group", 0, POPT_ARG_VAL, &opts->oidc_cmd, GET_GROUP,
+                _("Lookup a group"), NULL},
+        {"get-group-members", 0, POPT_ARG_VAL, &opts->oidc_cmd, GET_GROUP_MEMBERS,
+                _("Lookup members of a group"), NULL},
         {"issuer-url", 0, POPT_ARG_STRING, &opts->issuer_url, 0,
                 _("URL of Issuer IdP"), NULL},
         {"device-auth-endpoint", 0, POPT_ARG_STRING, &opts->device_auth_endpoint, 0,
@@ -311,11 +357,16 @@ static int parse_cli(int argc, const char *argv[], struct cli_opts *opts)
                 _("Client secret (if needed)"), NULL},
         {"client-secret-stdin", 0, POPT_ARG_NONE, NULL, 's',
                 _("Read client secret from standard input"), NULL},
+        {"idp-type", 0, POPT_ARG_STRING, &opts->idp_type, 0,
+                _("Type of the IdP (entra_id, keycloak etc)"), NULL},
+        {"name", 0, POPT_ARG_STRING, &tmp_name, 0, _("Name of user or group"),
+                NULL},
+        {"object-id", 0, POPT_ARG_STRING, &tmp_obj_id, 0,
+                _("Object ID of user or group"), NULL},
         {"ca-db", 0, POPT_ARG_STRING, &opts->ca_db, 0,
                 _("Path to PEM file with CA certificates"), NULL},
         {"libcurl-debug", 0, POPT_ARG_NONE, NULL, 'c',
                 _("Enable libcurl debug output"), NULL},
-        SSSD_LOGGER_OPTS
         POPT_TABLEEND
     };
 
@@ -329,12 +380,6 @@ static int parse_cli(int argc, const char *argv[], struct cli_opts *opts)
     pc = poptGetContext(argv[0], argc, argv, long_options, 0);
     while ((opt = poptGetNextOpt(pc)) != -1) {
         switch(opt) {
-        case 'a':
-            opts->get_device_code = true;
-            break;
-        case 'b':
-            opts->get_access_token = true;
-            break;
         case 'c':
             opts->libcurl_debug = true;
             break;
@@ -348,36 +393,23 @@ static int parse_cli(int argc, const char *argv[], struct cli_opts *opts)
         }
     }
 
-    if (!opts->get_device_code && !opts->get_access_token) {
+    if (opts->oidc_cmd == NO_CMD) {
         fprintf(stderr,
-                "\n--get-device-code or --get-access-token must be given.\n\n");
+                "\nOne of the --get-* options must be given.\n\n");
         goto done;
     }
 
-    if (opts->get_device_code && opts->get_access_token) {
-        fprintf(stderr,
-                "\n--get-device-code and --get-access-token "
-                "are mutually exclusive .\n\n");
-        goto done;
-    }
-
-    if ((opts->issuer_url != NULL
-                && (opts->device_auth_endpoint != NULL
-                        || opts->token_endpoint != NULL))
-        || (opts->device_auth_endpoint != NULL && opts->token_endpoint != NULL
-                           && opts->issuer_url != NULL)
-        || (opts->issuer_url == NULL
-                && ((opts->device_auth_endpoint != NULL
-                        && opts->token_endpoint == NULL)
-                   || (opts->device_auth_endpoint == NULL
-                        && opts->token_endpoint != NULL)))
-        || (opts->issuer_url == NULL
-                && (opts->device_auth_endpoint == NULL
-                        || opts->token_endpoint == NULL))) {
-        fprintf(stderr, "\n--issuer-url or --device-auth-endpoint "
-                        "together with --token-endpoint are mutually exclusive "
-                        "but one variant must be given.\n\n");
-        goto done;
+    if (opts->oidc_cmd == GET_ACCESS_TOKEN
+                || opts->oidc_cmd == GET_DEVICE_CODE) {
+        if (!(
+                ((opts->issuer_url != NULL) != (opts->device_auth_endpoint != NULL))
+                    && ((opts->issuer_url != NULL) != (opts->token_endpoint != NULL))
+            )) {
+            fprintf(stderr, "\n--issuer-url or --device-auth-endpoint together "
+                            "with --token-endpoint are mutually exclusive "
+                            "but one variant must be given.\n\n");
+            goto done;
+        }
     }
 
     if (opts->client_id == NULL) {
@@ -391,29 +423,26 @@ static int parse_cli(int argc, const char *argv[], struct cli_opts *opts)
         goto done;
     }
 
-    poptFreeContext(pc);
-    print_usage = false;
+    if (tmp_name != NULL) {
+        opts->search_str = tmp_name;
+        opts->search_str_type = TYPE_NAME;
+    }
+    if (tmp_obj_id != NULL) {
+        if (opts->search_str != NULL) {
+            fprintf(stderr, "\n--name and --object-id are mutually exclusive.\n\n");
+            goto done;
+        }
 
-    debug_prg_name = talloc_asprintf(NULL, "oidc_child[%d]", getpid());
-    if (debug_prg_name == NULL) {
-        ERROR("talloc_asprintf failed.\n");
-        ret = ENOMEM;
+        opts->search_str = tmp_obj_id;
+        opts->search_str_type = TYPE_OBJECT_ID;
+    }
+    if (IS_ID_CMD(opts->oidc_cmd) && opts->search_str == NULL) {
+        fprintf(stderr, "\n--name or --object-id are required.\n\n");
         goto done;
     }
 
-    opts->opt_logger = opt_logger;
-    opts->backtrace = backtrace;
-
-    if (debug_fd != -1) {
-        opts->opt_logger = sss_logger_str[FILES_LOGGER];
-        ret = set_debug_file_from_fd(debug_fd);
-        if (ret != EOK) {
-            opts->opt_logger = sss_logger_str[STDERR_LOGGER];
-            ERROR("set_debug_file_from_fd failed.\n");
-            return ret;
-        }
-    }
-
+    poptFreeContext(pc);
+    print_usage = false;
     ret = EOK;
 
 done:
@@ -486,16 +515,21 @@ int main(int argc, const char *argv[])
     struct devicecode_ctx *dc_ctx;
     const char *user_identifier = NULL;
     int exit_status = EXIT_FAILURE;
+    char *out = NULL;
+    char *client_secret_tmp = NULL;
 
     ret = parse_cli(argc, argv, &opts);
     if (ret != EOK) {
         goto done;
     }
 
-    DEBUG_INIT(debug_level, opts.opt_logger);
-    sss_set_debug_backtrace_enable((opts.backtrace == 0) ? false : true);
+    sss_child_basic_settings.name = "oidc_child";
+    if (!sss_child_setup_basics(&sss_child_basic_settings)) {
+        _exit(-1);
+    }
 
-    DEBUG(SSSDBG_TRACE_FUNC, "oidc_child started.\n");
+    DEBUG(SSSDBG_TRACE_FUNC, "oidc_child started, running command [%s][%d]\n",
+                             oidc_cmd_to_str(opts.oidc_cmd), opts.oidc_cmd);
 
     DEBUG(SSSDBG_TRACE_INTERNAL,
           "Running with effective IDs: [%"SPRIuid"][%"SPRIgid"].\n",
@@ -513,25 +547,60 @@ int main(int argc, const char *argv[])
     }
     talloc_steal(main_ctx, debug_prg_name);
 
-    dc_ctx = get_dc_ctx(main_ctx, opts.libcurl_debug, opts.ca_db,
-                        opts.issuer_url,
-                        opts.device_auth_endpoint, opts.token_endpoint,
-                        opts.userinfo_endpoint, opts.jwks_uri, opts.scope);
-    if (dc_ctx == NULL) {
-        DEBUG(SSSDBG_OP_FAILURE, "Failed to initialize main context.\n");
-        goto done;
-    }
-
-    if (opts.get_device_code) {
+    if (opts.oidc_cmd == GET_DEVICE_CODE || IS_ID_CMD(opts.oidc_cmd)) {
         if (opts.client_secret_stdin) {
-            ret = read_client_secret_from_stdin(dc_ctx, &opts.client_secret);
-            if (ret != EOK) {
+            ret = read_client_secret_from_stdin(main_ctx, &client_secret_tmp);
+            if (ret != EOK || client_secret_tmp == NULL) {
                 DEBUG(SSSDBG_OP_FAILURE,
                       "Failed to read client secret from stdin.\n");
                 goto done;
             }
+            opts.client_secret = strdup(client_secret_tmp);
+            sss_erase_mem_securely(client_secret_tmp, strlen(client_secret_tmp));
+            if (opts.client_secret == NULL) {
+                DEBUG(SSSDBG_OP_FAILURE,
+                      "Failed to copy client secret.\n");
+                goto done;
+            }
+        }
+    }
+
+    if (IS_ID_CMD(opts.oidc_cmd)) {
+        ret = oidc_get_id(main_ctx, opts.oidc_cmd, opts.idp_type,
+                          opts.search_str, opts.search_str_type,
+                          opts.libcurl_debug, opts.ca_db,
+                          opts.client_id, opts.client_secret,
+                          opts.token_endpoint, opts.scope, &out);
+        if (ret != EOK) {
+            DEBUG(SSSDBG_OP_FAILURE, "Id lookup failed.\n");
+            goto done;
         }
 
+        if (out != NULL) {
+            fprintf(stdout,"%s", out);
+            fflush(stdout);
+        }
+
+        goto success;
+    }
+
+    if (opts.oidc_cmd == GET_DEVICE_CODE || opts.oidc_cmd == GET_ACCESS_TOKEN) {
+        dc_ctx = get_dc_ctx(main_ctx, opts.libcurl_debug, opts.ca_db,
+                            opts.issuer_url,
+                            opts.device_auth_endpoint, opts.token_endpoint,
+                            opts.userinfo_endpoint, opts.jwks_uri, opts.scope);
+        if (dc_ctx == NULL) {
+            DEBUG(SSSDBG_OP_FAILURE, "Failed to initialize main context.\n");
+            goto done;
+        }
+    } else {
+        DEBUG(SSSDBG_CRIT_FAILURE, "Unsupported command [%d].\n",
+                                   opts.oidc_cmd);
+        ret = EINVAL;
+        goto done;
+    }
+
+    if (opts.oidc_cmd == GET_DEVICE_CODE) {
         ret = get_devicecode(dc_ctx, opts.client_id, opts.client_secret);
         if (ret != EOK) {
             DEBUG(SSSDBG_OP_FAILURE, "Failed to get device code.\n");
@@ -539,17 +608,28 @@ int main(int argc, const char *argv[])
         }
     }
 
-    if (opts.get_access_token) {
+    if (opts.oidc_cmd == GET_ACCESS_TOKEN) {
         if (dc_ctx->device_code == NULL) {
             ret = read_device_code_from_stdin(dc_ctx,
                                               opts.client_secret_stdin
-                                                           ? &opts.client_secret
+                                                           ? &client_secret_tmp
                                                            : NULL);
             if (ret != EOK) {
                 DEBUG(SSSDBG_OP_FAILURE,
                       "Failed to read device code from stdin.\n");
                 goto done;
             }
+
+            if (opts.client_secret_stdin) {
+                opts.client_secret = strdup(client_secret_tmp);
+                sss_erase_mem_securely(client_secret_tmp, strlen(client_secret_tmp));
+                if (opts.client_secret == NULL) {
+                    DEBUG(SSSDBG_OP_FAILURE,
+                          "Failed to copy client secret.\n");
+                    ret = ENOMEM;
+                    goto done;
+                }
+            }
         }
     }
 
@@ -559,16 +639,16 @@ int main(int argc, const char *argv[])
         goto done;
     }
 
-    trace_device_code(dc_ctx, opts.get_device_code);
+    trace_device_code(dc_ctx, (opts.oidc_cmd == GET_DEVICE_CODE));
 
     ret = get_token(main_ctx, dc_ctx, opts.client_id, opts.client_secret,
-                    opts.get_device_code);
+                    (opts.oidc_cmd == GET_DEVICE_CODE));
     if (ret != EOK) {
         DEBUG(SSSDBG_OP_FAILURE, "Failed to get user token.\n");
         goto done;
     }
 
-    if (opts.get_device_code) {
+    if (opts.oidc_cmd == GET_DEVICE_CODE) {
         /* Currently this reply is used by ipa-otpd as RADIUS Proxy-State and
          * Reply-Message.
          */
@@ -586,13 +666,13 @@ int main(int argc, const char *argv[])
         fflush(stdout);
     }
 
-    if (opts.get_access_token) {
+    if (opts.oidc_cmd == GET_ACCESS_TOKEN) {
         DEBUG(SSSDBG_TRACE_ALL, "access_token: [%s].\n",
                                 dc_ctx->td->access_token_str);
         DEBUG(SSSDBG_TRACE_ALL, "id_token: [%s].\n", dc_ctx->td->id_token_str);
 
         if (dc_ctx->jwks_uri != NULL) {
-            ret = verify_token(dc_ctx);
+            ret = decode_token(dc_ctx, true);
             if (ret != EOK) {
                 DEBUG(SSSDBG_OP_FAILURE, "Failed to verify tokens.\n");
                 goto done;
@@ -605,7 +685,8 @@ int main(int argc, const char *argv[])
             goto done;
         }
 
-        dc_ctx->td->userinfo = json_loads(dc_ctx->http_data, 0, &json_error);
+        dc_ctx->td->userinfo = json_loads(get_http_data(dc_ctx->rest_ctx), 0,
+                                          &json_error);
         if (dc_ctx->td->userinfo == NULL) {
             DEBUG(SSSDBG_OP_FAILURE,
                   "Failed to parse userinfo data on line [%d]: [%s].\n",
@@ -616,7 +697,41 @@ int main(int argc, const char *argv[])
         trace_tokens(dc_ctx);
 
         user_identifier = get_user_identifier(dc_ctx, dc_ctx->td->userinfo,
-                                              opts.user_identifier_attr);
+                                              opts.user_identifier_attr,
+                                              NULL);
+        if (user_identifier == NULL) {
+            DEBUG(SSSDBG_OP_FAILURE,
+                  "User identifier not found in user info data, "
+                  "checking id token.\n");
+
+            if (dc_ctx->jwks_uri == NULL) {
+                /* Up to here the tokens are only decoded into JSON if
+                 * verification keys were provided. */
+                ret = decode_token(dc_ctx, false);
+                if (ret != EOK) {
+                    DEBUG(SSSDBG_OP_FAILURE, "Failed to decode tokens, ignored.\n");
+                }
+            }
+
+            if (dc_ctx->td->id_token_payload != NULL) {
+                user_identifier = get_user_identifier(dc_ctx, dc_ctx->td->id_token_payload,
+                                                      opts.user_identifier_attr,
+                                                      "id token");
+            }
+        }
+
+        if (user_identifier == NULL) {
+            DEBUG(SSSDBG_OP_FAILURE,
+                  "User identifier not found in user info data or id token, "
+                  "checking access token.\n");
+
+            if (dc_ctx->td->access_token_payload != NULL) {
+                user_identifier = get_user_identifier(dc_ctx, dc_ctx->td->access_token_payload,
+                                                      opts.user_identifier_attr,
+                                                      "access token");
+            }
+        }
+
         if (user_identifier == NULL) {
             DEBUG(SSSDBG_OP_FAILURE, "Failed to get user identifier.\n");
             goto done;
@@ -629,10 +744,12 @@ int main(int argc, const char *argv[])
         fflush(stdout);
     }
 
+success:
     DEBUG(SSSDBG_IMPORTANT_INFO, "oidc_child finished successful!\n");
     exit_status = EXIT_SUCCESS;
 
 done:
+    free_cli_opts_members(&opts);
     if (exit_status != EXIT_SUCCESS) {
         DEBUG(SSSDBG_IMPORTANT_INFO, "oidc_child failed!\n");
     }
