@@ -23,7 +23,6 @@
 */
 
 #include <popt.h>
-#include <sys/prctl.h>
 #include <fido/param.h>
 #include <openssl/err.h>
 #include <openssl/pem.h>
@@ -31,10 +30,12 @@
 #include <openssl/err.h>
 #include <openssl/pem.h>
 
+#include "util/child_bootstrap.h"
 #include "util/crypto/sss_crypto.h"
 #include "util/debug.h"
 #include "util/util.h"
 #include "util/crypto/sss_crypto.h"
+#include "util/sss_prctl.h"
 
 #include "passkey_child.h"
 
@@ -128,13 +129,9 @@ parse_arguments(TALLOC_CTX *mem_ctx, int argc, const char *argv[],
                 struct passkey_data *data)
 {
     int opt;
-    int dumpable = 1;
-    int backtrace = 1;
-    int debug_fd = -1;
     char *user_verification = NULL;
     char *public_keys = NULL;
     char *key_handles = NULL;
-    const char *opt_logger = NULL;
     const char *type = NULL;
     const char *cred_type = NULL;
     poptContext pc;
@@ -160,15 +157,7 @@ parse_arguments(TALLOC_CTX *mem_ctx, int argc, const char *argv[],
     data->debug_libfido2 = false;
 
     struct poptOption long_options[] = {
-        POPT_AUTOHELP
-        SSSD_DEBUG_OPTS
-        {"dumpable", 0, POPT_ARG_INT, &dumpable, 0,
-         _("Allow core dumps"), NULL },
-        {"backtrace", 0, POPT_ARG_INT, &backtrace, 0,
-         _("Enable debug backtrace"), NULL },
-        {"debug-fd", 0, POPT_ARG_INT, &debug_fd, 0,
-         _("An open file descriptor for the debug logs"), NULL},
-        SSSD_LOGGER_OPTS
+        SSSD_BASIC_CHILD_OPTS
         {"register", 0, POPT_ARG_NONE, NULL, 'r',
          _("Register a passkey for a user"), NULL },
         {"authenticate", 0, POPT_ARG_NONE, NULL, 'a',
@@ -204,7 +193,6 @@ parse_arguments(TALLOC_CTX *mem_ctx, int argc, const char *argv[],
          _("Supress prompts"), NULL},
         {"debug-libfido2", 0, POPT_ARG_NONE, NULL, 'd',
          _("Enable debug in libfido2 library"), NULL},
-        SSSD_LOGGER_OPTS
         POPT_TABLEEND
     };
 
@@ -276,8 +264,6 @@ parse_arguments(TALLOC_CTX *mem_ctx, int argc, const char *argv[],
 
     poptFreeContext(pc);
 
-    prctl(PR_SET_DUMPABLE, (dumpable == 0) ? 0 : 1);
-
     if (user_verification != NULL) {
         if (strcmp(user_verification, "true") == 0) {
             data->user_verification = FIDO_OPT_TRUE;
@@ -318,25 +304,6 @@ parse_arguments(TALLOC_CTX *mem_ctx, int argc, const char *argv[],
         }
     }
 
-    debug_prg_name = talloc_asprintf(NULL, "passkey_child[%d]", getpid());
-    if (debug_prg_name == NULL) {
-        ERROR("talloc_asprintf failed.\n");
-        ret = ENOMEM;
-        goto done;
-    }
-
-    if (debug_fd != -1) {
-        opt_logger = sss_logger_str[FILES_LOGGER];
-        ret = set_debug_file_from_fd(debug_fd);
-        if (ret != EOK) {
-            opt_logger = sss_logger_str[STDERR_LOGGER];
-            ERROR("set_debug_file_from_fd failed.\n");
-        }
-    }
-
-    DEBUG_INIT(debug_level, opt_logger);
-    sss_set_debug_backtrace_enable((backtrace == 0) ? false : true);
-
     ret = EOK;
 
 done:
