@@ -36,9 +36,16 @@
 #include "providers/ldap/sdap_async.h"
 #include "db/sysdb.h"
 
+#ifdef HAVE_LDAP_IS_LDAPC_URL
+#define AD_PING_PROTOCOL "cldap"
+#else
+#define AD_PING_PROTOCOL "ldap"
+#endif
+
 struct ad_cldap_ping_dc_state {
     struct tevent_context *ev;
     struct sdap_options *opts;
+    struct be_resolv_ctx *be_res;
     struct fo_server_info *dc;
     struct sdap_handle *sh;
     const char *ad_domain;
@@ -72,12 +79,14 @@ static struct tevent_req *ad_cldap_ping_dc_send(TALLOC_CTX *mem_ctx,
 
     state->ev = ev;
     state->opts = opts;
+    state->be_res = be_res;
     state->dc = dc;
     state->ad_domain = ad_domain;
 
     subreq = sdap_connect_host_send(state, ev, opts, be_res->resolv,
-                                    be_res->family_order, host_db, "cldap",
-                                    dc->host, dc->port, false);
+                                    be_res->family_order, host_db,
+                                    AD_PING_PROTOCOL, dc->host, dc->port,
+                                    false);
     if (subreq == NULL) {
         ret = ENOMEM;
         goto done;
@@ -103,6 +112,7 @@ static void ad_cldap_ping_dc_connect_done(struct tevent_req *subreq)
     char *filter;
     int timeout;
     errno_t ret;
+    div_t timeout_int;
 
     req = tevent_req_callback_data(subreq, struct tevent_req);
     state = tevent_req_data(req, struct ad_cldap_ping_dc_state);
@@ -127,7 +137,12 @@ static void ad_cldap_ping_dc_connect_done(struct tevent_req *subreq)
         goto done;
     }
 
-    timeout = dp_opt_get_int(state->opts->basic, SDAP_SEARCH_TIMEOUT);
+    /* DP_RES_OPT_RESOLVER_SERVER_TIMEOUT is in milli-seconds and
+     * sdap_get_generic_send() expects seconds */
+    timeout_int = div(dp_opt_get_int(state->be_res->opts,
+                                     DP_RES_OPT_RESOLVER_SERVER_TIMEOUT),
+                      1000);
+    timeout = (timeout_int.quot > 0) ? timeout_int.quot : 1;
     subreq = sdap_get_generic_send(state, state->ev, state->opts, state->sh, "",
                                    LDAP_SCOPE_BASE, filter, attrs, NULL,
                                    0, timeout, false);
@@ -601,10 +616,12 @@ struct tevent_req *ad_cldap_ping_send(TALLOC_CTX *mem_ctx,
     }
 
     if (!srv_ctx->renew_site) {
-        state->site = talloc_strdup(state, srv_ctx->current_site);
-        state->forest = talloc_strdup(state, srv_ctx->current_forest);
-        if ((srv_ctx->current_site != NULL && state->site == NULL)
-                || (srv_ctx->current_forest != NULL && state->forest == NULL)) {
+        state->site = talloc_strdup(state, srv_ctx->ad_options->current_site);
+        state->forest = talloc_strdup(state,
+                                      srv_ctx->ad_options->current_forest);
+        if ((srv_ctx->ad_options->current_site != NULL && state->site == NULL)
+                || (srv_ctx->ad_options->current_forest != NULL
+                                    && state->forest == NULL)) {
             DEBUG(SSSDBG_OP_FAILURE,
                   "Failed to copy current site or forest name.\n");
             ret = ENOMEM;
@@ -619,6 +636,14 @@ struct tevent_req *ad_cldap_ping_send(TALLOC_CTX *mem_ctx,
         goto done;
     }
 
+    if (strcmp(srv_ctx->ad_domain, discovery_domain) != 0) {
+        DEBUG(SSSDBG_TRACE_ALL, "Trying to discover domain [%s] "
+              "which is not our local domain [%s], skipping CLDAP ping.\n",
+              discovery_domain, srv_ctx->ad_domain);
+        ret = EOK;
+        goto done;
+    }
+
     DEBUG(SSSDBG_TRACE_FUNC, "Sending CLDAP ping\n");
 
     state->ev = ev;
@@ -629,9 +654,10 @@ struct tevent_req *ad_cldap_ping_send(TALLOC_CTX *mem_ctx,
     state->discovery_domain = discovery_domain;
 
     /* If possible, lookup the information in the current site first. */
-    if (srv_ctx->current_site != NULL) {
+    if (srv_ctx->ad_options->current_site != NULL) {
         state->all_tried = false;
-        domain = ad_site_dns_discovery_domain(state, srv_ctx->current_site,
+        domain = ad_site_dns_discovery_domain(state,
+                                              srv_ctx->ad_options->current_site,
                                               discovery_domain);
         if (domain == NULL) {
             DEBUG(SSSDBG_CRIT_FAILURE, "Out of memory!");
