@@ -70,9 +70,6 @@ enum ad_basic_opt {
     AD_MACHINE_ACCOUNT_PASSWORD_RENEWAL_OPTS,
     AD_UPDATE_SAMBA_MACHINE_ACCOUNT_PASSWORD,
     AD_USE_LDAPS,
-#ifdef BUILD_ALLOW_REMOTE_DOMAIN_LOCAL_GROUPS
-    AD_ALLOW_REMOTE_DOMAIN_LOCAL,
-#endif
 
     AD_OPTS_BASIC /* opts counter */
 };
