@@ -130,6 +130,7 @@ ad_srv_plugin_ctx_init(TALLOC_CTX *mem_ctx,
                        struct be_resolv_ctx *be_res,
                        enum host_database *host_dbs,
                        struct sdap_options *opts,
+                       struct ad_options *ad_options,
                        const char *hostname,
                        const char *ad_domain,
                        const char *ad_site_override)
@@ -147,6 +148,7 @@ ad_srv_plugin_ctx_init(TALLOC_CTX *mem_ctx,
     ctx->host_dbs = host_dbs;
     ctx->opts = opts;
     ctx->renew_site = true;
+    ctx->ad_options = ad_options;
 
     ctx->hostname = talloc_strdup(ctx, hostname);
     if (ctx->hostname == NULL) {
@@ -164,18 +166,20 @@ ad_srv_plugin_ctx_init(TALLOC_CTX *mem_ctx,
             goto fail;
         }
 
-        ctx->current_site = talloc_strdup(ctx, ad_site_override);
-        if (ctx->current_site == NULL) {
+        ctx->ad_options->current_site = talloc_strdup(ctx->ad_options,
+                                                      ad_site_override);
+        if (ctx->ad_options->current_site == NULL) {
             goto fail;
         }
     } else {
-        ret = sysdb_get_site(ctx, be_ctx->domain, &ctx->current_site);
+        ret = sysdb_get_site(ctx->ad_options, be_ctx->domain,
+                             &ctx->ad_options->current_site);
         if (ret != EOK) {
             /* Not fatal. */
             DEBUG(SSSDBG_MINOR_FAILURE,
                   "Unable to get current site from cache [%d]: %s\n",
                   ret, sss_strerror(ret));
-            ctx->current_site = NULL;
+            ctx->ad_options->current_site = NULL;
         }
     }
 
@@ -192,54 +196,6 @@ fail:
     return NULL;
 }
 
-static errno_t
-ad_srv_plugin_ctx_switch_site(struct ad_srv_plugin_ctx *ctx,
-                              const char *new_site,
-                              const char *new_forest)
-{
-    const char *site;
-    const char *forest;
-    errno_t ret;
-
-    /* Switch forest. */
-    if (new_forest != NULL
-        && (ctx->current_forest == NULL
-            || strcmp(ctx->current_forest, new_forest) != 0)) {
-        forest = talloc_strdup(ctx, new_forest);
-        if (forest == NULL) {
-            return ENOMEM;
-        }
-
-        talloc_zfree(ctx->current_forest);
-        ctx->current_forest = forest;
-    }
-
-    if (new_site == NULL) {
-        return EOK;
-    }
-
-    if (ctx->current_site != NULL && strcmp(ctx->current_site, new_site) == 0) {
-        return EOK;
-    }
-
-    site = talloc_strdup(ctx, new_site);
-    if (site == NULL) {
-        return ENOMEM;
-    }
-
-    talloc_zfree(ctx->current_site);
-    ctx->current_site = site;
-
-    ret = sysdb_set_site(ctx->be_ctx->domain, ctx->current_site);
-    if (ret != EOK) {
-        /* Not fatal. */
-        DEBUG(SSSDBG_MINOR_FAILURE, "Unable to store site information "
-              "[%d]: %s\n", ret, sss_strerror(ret));
-    }
-
-    return EOK;
-}
-
 struct ad_srv_plugin_state {
     struct tevent_context *ev;
     struct ad_srv_plugin_ctx *ctx;
@@ -377,16 +333,19 @@ static void ad_srv_plugin_ping_done(struct tevent_req *subreq)
         /* Remember current site so it can be used during next lookup so
          * we can contact directory controllers within a known reachable
          * site first. */
-        ret = ad_srv_plugin_ctx_switch_site(state->ctx, state->site,
-                                            state->forest);
-        if (ret != EOK) {
-            DEBUG(SSSDBG_CRIT_FAILURE, "Unable to set site [%d]: %s\n",
-                  ret, sss_strerror(ret));
-            goto done;
-        }
+        if (state->site != NULL) {
+            ret = ad_options_switch_site(state->ctx->ad_options,
+                                         state->ctx->be_ctx,
+                                         state->site, state->forest);
+            if (ret != EOK) {
+                DEBUG(SSSDBG_CRIT_FAILURE, "Unable to set site [%d]: %s\n",
+                      ret, sss_strerror(ret));
+                goto done;
+            }
 
-        /* Do not renew the site again unless we go offline. */
-        state->ctx->renew_site = false;
+            /* Do not renew the site again unless we go offline. */
+            state->ctx->renew_site = false;
+        }
 
         if (strcmp(state->service, "gc") == 0) {
             if (state->forest != NULL) {
