@@ -160,9 +160,6 @@ static errno_t ipa_parse_search_base(TALLOC_CTX *mem_ctx,
     case IPA_DESKPROFILE_SEARCH_BASE:
         class_name = "IPA_DESKPROFILE";
         break;
-    case IPA_SUBID_RANGES_SEARCH_BASE:
-        class_name = "IPA_SUBID_RANGES";
-        break;
     default:
         DEBUG(SSSDBG_CONF_SETTINGS,
               "Unknown search base type: [%d]\n", class);
@@ -548,28 +545,32 @@ ipa_set_search_bases(struct ipa_options *ipa_opts,
     if (ret != EOK) goto done;
 
 #ifdef BUILD_SUBID
-    if (NULL == dp_opt_get_string(ipa_opts->basic,
-                                  IPA_SUBID_RANGES_SEARCH_BASE)) {
-        value = talloc_asprintf(tmpctx, "cn=subids,%s",
-                                sdom->search_bases[0]->basedn);
-        if (!value) {
+    if (NULL == dp_opt_get_string(sdap_opts->basic,
+                                  SDAP_SUBID_RANGES_SEARCH_BASE)) {
+        /* check deprecated option */
+        value = dp_opt_get_string(ipa_opts->basic, IPA_SUBID_RANGES_SEARCH_BASE);
+        if (value == NULL) { /* set a default */
+            value = talloc_asprintf(tmpctx, "cn=subids,%s",
+                                    sdom->search_bases[0]->basedn);
+        }
+        if (value == NULL) {
             ret = ENOMEM;
             goto done;
         }
 
-        ret = dp_opt_set_string(ipa_opts->basic, IPA_SUBID_RANGES_SEARCH_BASE, value);
+        ret = dp_opt_set_string(sdap_opts->basic, SDAP_SUBID_RANGES_SEARCH_BASE, value);
         if (ret != EOK) {
             goto done;
         }
 
         DEBUG(SSSDBG_TRACE_FUNC, "Option %s set to %s\n",
-                  ipa_opts->basic[IPA_SUBID_RANGES_SEARCH_BASE].opt_name,
-                  dp_opt_get_string(ipa_opts->basic,
-                                    IPA_SUBID_RANGES_SEARCH_BASE));
+                  sdap_opts->basic[SDAP_SUBID_RANGES_SEARCH_BASE].opt_name,
+                  dp_opt_get_string(sdap_opts->basic,
+                                    SDAP_SUBID_RANGES_SEARCH_BASE));
     }
-    ret = ipa_parse_search_base(ipa_opts->basic, ldb, ipa_opts->basic,
-                                IPA_SUBID_RANGES_SEARCH_BASE,
-                                &sdom->subid_ranges_search_bases);
+    ret = sdap_parse_search_base(sdap_opts->basic, ldb, sdap_opts->basic,
+                                 SDAP_SUBID_RANGES_SEARCH_BASE,
+                                 &sdom->subid_ranges_search_bases);
     if (ret != EOK) goto done;
 
     ret = sdap_get_map(sdap_opts,
@@ -1273,101 +1274,6 @@ done:
     return ret;
 }
 
-errno_t ipa_get_dyndns_options(struct be_ctx *be_ctx,
-                               struct ipa_options *ctx)
-{
-    errno_t ret;
-    char *val;
-    bool update;
-    int ttl;
-
-    ret = be_nsupdate_init(ctx, be_ctx, ipa_dyndns_opts, &ctx->dyndns_ctx);
-    if (ret != EOK) {
-        DEBUG(SSSDBG_OP_FAILURE,
-              "Cannot initialize IPA dyndns opts [%d]: %s\n",
-               ret, sss_strerror(ret));
-        return ret;
-    }
-
-    if (ctx->basic == NULL) {
-        DEBUG(SSSDBG_MINOR_FAILURE, "IPA basic options not (yet) "
-              "initialized, cannot copy legacy options\n");
-        return EOK;
-    }
-
-    /* Reuse legacy option values */
-    ret = confdb_get_string(be_ctx->cdb, ctx, be_ctx->conf_path,
-                            "ipa_dyndns_update", NULL, &val);
-    if (ret != EOK) {
-        DEBUG(SSSDBG_OP_FAILURE, "Cannot get the value of %s\n",
-              "ipa_dyndns_update");
-        /* Not fatal */
-    } else if (ret == EOK && val) {
-        if (strcasecmp(val, "FALSE") == 0) {
-            update = false;
-        } else if (strcasecmp(val, "TRUE") == 0) {
-            update = true;
-        } else {
-            DEBUG(SSSDBG_MINOR_FAILURE,
-                  "ipa_dyndns_update value is not a boolean!\n");
-            talloc_free(val);
-            return EINVAL;
-        }
-
-        DEBUG(SSSDBG_MINOR_FAILURE, "Deprecation warning: The option %s is "
-              "deprecated and should not be used in favor of %s\n",
-              "ipa_dyndns_update", "dyndns_update");
-
-        ret = dp_opt_set_bool(ctx->dyndns_ctx->opts,
-                              DP_OPT_DYNDNS_UPDATE, update);
-        talloc_free(val);
-        if (ret != EOK) {
-            DEBUG(SSSDBG_OP_FAILURE, "Cannot set option value\n");
-            return ret;
-        }
-    }
-
-    ret = confdb_get_int(be_ctx->cdb, be_ctx->conf_path,
-                         "ipa_dyndns_ttl", -1, &ttl);
-    if (ret != EOK) {
-        DEBUG(SSSDBG_OP_FAILURE, "Cannot get the value of %s\n",
-              "ipa_dyndns_ttl");
-        /* Not fatal */
-    } else if (ret == EOK && ttl != -1) {
-        DEBUG(SSSDBG_MINOR_FAILURE, "Deprecation warning: The option %s is "
-              "deprecated and should not be used in favor of %s\n",
-              "ipa_dyndns_ttl", "dyndns_ttl");
-
-        ret = dp_opt_set_int(ctx->dyndns_ctx->opts, DP_OPT_DYNDNS_TTL, ttl);
-        if (ret != EOK) {
-            DEBUG(SSSDBG_OP_FAILURE, "Cannot set option value\n");
-            return ret;
-        }
-    }
-
-    /* Reuse legacy option values */
-    ret = confdb_get_string(be_ctx->cdb, ctx, be_ctx->conf_path,
-                            "ipa_dyndns_iface", NULL, &val);
-    if (ret != EOK) {
-        DEBUG(SSSDBG_OP_FAILURE, "Cannot get the value of %s\n",
-              "ipa_dyndns_iface");
-        /* Not fatal */
-    } else if (ret == EOK && val) {
-        DEBUG(SSSDBG_MINOR_FAILURE, "Deprecation warning: The option %s is "
-              "deprecated and should not be used in favor of %s\n",
-              "ipa_dyndns_iface", "dyndns_iface");
-
-        ret = dp_opt_set_string(ctx->dyndns_ctx->opts,
-                                DP_OPT_DYNDNS_IFACE, val);
-        if (ret != EOK) {
-            DEBUG(SSSDBG_OP_FAILURE, "Cannot set option value\n");
-            return ret;
-        }
-    }
-
-    return EOK;
-}
-
 errno_t ipa_get_host_attrs(struct dp_option *ipa_options,
                            size_t host_count,
                            struct sysdb_attrs **hosts,
