@@ -61,14 +61,13 @@ enum ipa_basic_opt {
     IPA_HBAC_SUPPORT_SRCHOST,
     IPA_AUTOMOUNT_LOCATION,
     IPA_RANGES_SEARCH_BASE,
-    IPA_ENABLE_DNS_SITES,
     IPA_SERVER_MODE,
     IPA_VIEWS_SEARCH_BASE,
     IPA_KRB5_CONFD_PATH,
     IPA_DESKPROFILE_SEARCH_BASE,
     IPA_DESKPROFILE_REFRESH,
     IPA_DESKPROFILE_REQUEST_INTERVAL,
-    IPA_SUBID_RANGES_SEARCH_BASE,
+    IPA_SUBID_RANGES_SEARCH_BASE, /* only used if ldap_subid_range_search_base is not set */
     IPA_ACCESS_ORDER,
 
     IPA_OPTS_BASIC /* opts counter */
@@ -210,6 +209,8 @@ struct ipa_id_ctx {
     char *view_name;
     /* Only used with server mode */
     struct ipa_server_mode_ctx *server_mode;
+    const char *global_template_homedir;
+    const char *global_template_shell;
 };
 
 struct ipa_options {
@@ -269,9 +270,6 @@ int ipa_get_autofs_options(struct ipa_options *ipa_opts,
                            const char *conf_path,
                            struct sdap_options **_opts);
 
-errno_t ipa_get_dyndns_options(struct be_ctx *be_ctx,
-                               struct ipa_options *ctx);
-
 errno_t ipa_set_sdap_options(struct ipa_options *ipa_opts,
                              struct sdap_options *sdap_opts);
 
