@@ -29,9 +29,6 @@
 #include "providers/ipa/ipa_common.h"
 #include "providers/backend.h"
 
-void ipa_dyndns_update(void *pvt);
-void ipa_dyndns_timer(void *pvt);
-
 errno_t ipa_dyndns_init(struct be_ctx *be_ctx,
                         struct ipa_options *ctx);
 
