@@ -27,7 +27,6 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 
-#include "util/child_common.h"
 #include "providers/ipa/ipa_common.h"
 #include "providers/krb5/krb5_auth.h"
 #include "providers/krb5/krb5_init_shared.h"
@@ -42,6 +41,7 @@
 #include "providers/ipa/ipa_srv.h"
 #include "providers/be_dyndns.h"
 #include "providers/ipa/ipa_session.h"
+#include "providers/ipa/ipa_opts.h"
 
 #define DNS_SRV_MISCONFIGURATION "SRV discovery is enabled on the IPA " \
     "server while using custom dns_discovery_domain. DNS discovery of " \
@@ -111,6 +111,7 @@ static errno_t ipa_init_options(TALLOC_CTX *mem_ctx,
     struct ipa_options *ipa_options;
     const char *ipa_servers;
     const char *ipa_backup_servers;
+    const char *realm;
     errno_t ret;
 
     ret = ipa_get_options(mem_ctx, be_ctx->cdb, be_ctx->conf_path,
@@ -121,9 +122,10 @@ static errno_t ipa_init_options(TALLOC_CTX *mem_ctx,
 
     ipa_servers = dp_opt_get_string(ipa_options->basic, IPA_SERVER);
     ipa_backup_servers = dp_opt_get_string(ipa_options->basic, IPA_BACKUP_SERVER);
+    realm = dp_opt_get_string(ipa_options->basic, IPA_KRB5_REALM);
 
     ret = ipa_service_init(ipa_options, be_ctx, ipa_servers,
-                           ipa_backup_servers, ipa_options,
+                           ipa_backup_servers, realm, "IPA", ipa_options,
                            &ipa_options->service);
     if (ret != EOK) {
         DEBUG(SSSDBG_FATAL_FAILURE, "Failed to init IPA service [%d]: %s\n",
@@ -143,6 +145,7 @@ static errno_t ipa_init_id_ctx(TALLOC_CTX *mem_ctx,
 {
     struct ipa_id_ctx *ipa_id_ctx = NULL;
     struct sdap_id_ctx *sdap_id_ctx = NULL;
+    char *basedn;
     errno_t ret;
 
     ipa_id_ctx = talloc_zero(mem_ctx, struct ipa_id_ctx);
@@ -165,11 +168,35 @@ static errno_t ipa_init_id_ctx(TALLOC_CTX *mem_ctx,
                              be_ctx->cdb,
                              be_ctx->conf_path,
                              be_ctx->provider,
+                             true,
                              &sdap_id_ctx->opts);
     if (ret != EOK) {
         goto done;
     }
 
+    ret = ipa_set_sdap_options(ipa_options, ipa_options->id);
+    if (ret != EOK) {
+        DEBUG(SSSDBG_OP_FAILURE, "Cannot set IPA sdap options\n");
+        goto done;
+    }
+
+    ret = domain_to_basedn(mem_ctx,
+                           dp_opt_get_string(ipa_options->basic, IPA_KRB5_REALM),
+                           &basedn);
+    if (ret != EOK) {
+        goto done;
+    }
+
+    ret = ipa_set_search_bases(ipa_options,
+                               be_ctx->cdb,
+                               basedn,
+                               be_ctx->conf_path,
+                               NULL);
+    if (ret != EOK) {
+        DEBUG(SSSDBG_OP_FAILURE, "Cannot set search bases\n");
+        goto done;
+    }
+
     *_ipa_id_ctx = ipa_id_ctx;
 
     ret = EOK;
@@ -193,10 +220,12 @@ static errno_t ipa_init_dyndns(struct be_ctx *be_ctx,
     bool enabled;
     errno_t ret;
 
-    ret = ipa_get_dyndns_options(be_ctx, ipa_options);
+    ret = be_nsupdate_init(ipa_options, be_ctx, ipa_dyndns_opts,
+                           &ipa_options->dyndns_ctx);
     if (ret != EOK) {
-        DEBUG(SSSDBG_CRIT_FAILURE, "Unable to get dyndns options [%d]: %s\n",
-              ret, sss_strerror(ret));
+        DEBUG(SSSDBG_OP_FAILURE,
+              "Cannot initialize IPA dyndns opts [%d]: %s\n",
+               ret, sss_strerror(ret));
         return ret;
     }
 
@@ -241,7 +270,6 @@ static errno_t ipa_init_server_mode(struct be_ctx *be_ctx,
     const char *ipa_servers;
     const char *dnsdomain;
     const char *hostname;
-    bool sites_enabled;
     errno_t ret;
 
     ipa_id_ctx->view_name = talloc_strdup(ipa_id_ctx, SYSDB_DEFAULT_VIEW_NAME);
@@ -258,12 +286,11 @@ static errno_t ipa_init_server_mode(struct be_ctx *be_ctx,
 
     hostname = dp_opt_get_string(ipa_options->basic, IPA_HOSTNAME);
     ipa_servers = dp_opt_get_string(ipa_options->basic, IPA_SERVER);
-    sites_enabled = dp_opt_get_bool(ipa_options->basic, IPA_ENABLE_DNS_SITES);
     dnsdomain = dp_opt_get_string(be_ctx->be_res->opts, DP_RES_OPT_DNS_DOMAIN);
 
-    if (srv_in_server_list(ipa_servers) || sites_enabled) {
-        DEBUG(SSSDBG_IMPORTANT_INFO, "SSSD configuration uses either DNS "
-              "SRV resolution or IPA site discovery to locate IPA servers. "
+    if (srv_in_server_list(ipa_servers)) {
+        DEBUG(SSSDBG_IMPORTANT_INFO, "SSSD configuration uses DNS "
+              "SRV resolution to locate IPA servers. "
               "On IPA server itself, it is recommended that SSSD is "
               "configured to only connect to the IPA server it's running at. ");
 
@@ -308,10 +335,7 @@ static errno_t ipa_init_client_mode(struct be_ctx *be_ctx,
                                     struct ipa_options *ipa_options,
                                     struct ipa_id_ctx *ipa_id_ctx)
 {
-    struct ipa_srv_plugin_ctx *srv_ctx;
-    const char *ipa_domain;
     const char *hostname;
-    bool sites_enabled;
     errno_t ret;
 
     ret = sysdb_get_view_name(ipa_id_ctx, be_ctx->domain->sysdb,
@@ -326,28 +350,13 @@ static errno_t ipa_init_client_mode(struct be_ctx *be_ctx,
     }
 
     hostname = dp_opt_get_string(ipa_options->basic, IPA_HOSTNAME);
-    sites_enabled = dp_opt_get_bool(ipa_options->basic, IPA_ENABLE_DNS_SITES);
 
-    if (sites_enabled) {
-        /* use IPA plugin */
-        ipa_domain = dp_opt_get_string(ipa_options->basic, IPA_DOMAIN);
-        srv_ctx = ipa_srv_plugin_ctx_init(be_ctx, be_ctx->be_res->resolv,
-                                          hostname, ipa_domain);
-        if (srv_ctx == NULL) {
-            DEBUG(SSSDBG_FATAL_FAILURE, "Out of memory?\n");
-            return ENOMEM;
-        }
-
-        be_fo_set_srv_lookup_plugin(be_ctx, ipa_srv_plugin_send,
-                                    ipa_srv_plugin_recv, srv_ctx, "IPA");
-    } else {
-        /* fall back to standard plugin on clients. */
-        ret = be_fo_set_dns_srv_lookup_plugin(be_ctx, hostname);
-        if (ret != EOK) {
-            DEBUG(SSSDBG_CRIT_FAILURE, "Unable to set SRV lookup plugin "
-                  "[%d]: %s\n", ret, strerror(ret));
-            return ret;
-        }
+    /* fall back to standard plugin on clients. */
+    ret = be_fo_set_dns_srv_lookup_plugin(be_ctx, hostname);
+    if (ret != EOK) {
+        DEBUG(SSSDBG_CRIT_FAILURE, "Unable to set SRV lookup plugin "
+              "[%d]: %s\n", ret, strerror(ret));
+        return ret;
     }
 
     return EOK;
