@@ -208,6 +208,13 @@ static errno_t find_ipa_ext_memberships(TALLOC_CTX *mem_ctx,
         goto done;
     }
 
+    user_dn = ldb_dn_copy(mem_ctx, result->msgs[0]->dn);
+    if (user_dn == NULL) {
+        DEBUG(SSSDBG_OP_FAILURE, "ldb_dn_copy failed.\n");
+        ret = ENOMEM;
+        goto done;
+    }
+
     ret = sss_hash_create(tmp_ctx, 0, &group_hash);
     if (ret != HASH_SUCCESS) {
         DEBUG(SSSDBG_OP_FAILURE, "sss_hash_create failed.\n");
@@ -288,13 +295,6 @@ static errno_t find_ipa_ext_memberships(TALLOC_CTX *mem_ctx,
         c++;
     }
 
-    user_dn = ldb_dn_copy(mem_ctx, result->msgs[0]->dn);
-    if (user_dn == NULL) {
-        DEBUG(SSSDBG_OP_FAILURE, "ldb_dn_copy failed.\n");
-        ret = ENOMEM;
-        goto done;
-    }
-
     ret = EOK;
 done:
     *_user_dn = user_dn;
@@ -305,11 +305,12 @@ done:
     return ret;
 }
 
-static errno_t add_ad_user_to_cached_groups(struct ldb_dn *user_dn,
+static errno_t add_ad_user_to_cached_groups(TALLOC_CTX *mem_ctx,
+                                            struct ldb_dn *user_dn,
                                             struct sss_domain_info *user_dom,
                                             struct sss_domain_info *group_dom,
                                             char **groups,
-                                            bool *missing_groups)
+                                            char  ***_missing_groups)
 {
     size_t c;
     size_t d = 0;
@@ -322,12 +323,12 @@ static errno_t add_ad_user_to_cached_groups(struct ldb_dn *user_dn,
     char *user_name;
     char **sysdb_ipa_group_memberships;
     char **add_groups;
+    size_t add_groups_count;
     char **del_groups;
+    char **mis_groups = NULL;
     errno_t sret;
     bool in_transaction = false;
 
-    *missing_groups = false;
-
     tmp_ctx = talloc_new(NULL);
     if (tmp_ctx == NULL) {
         DEBUG(SSSDBG_OP_FAILURE, "talloc_new failed.\n");
@@ -382,25 +383,23 @@ static errno_t add_ad_user_to_cached_groups(struct ldb_dn *user_dn,
     /* Add all new IPA groups to SYSDB_ORIG_MEMBEROF because they are most
      * probably removed by the previous user update and mark all new groups as
      * processed. */
-    for (c = 0; groups[c] != NULL; c++) {
+    for (c = 0; groups != NULL && groups[c] != NULL; c++) {
         ret = sysdb_attrs_add_string(user_attrs, SYSDB_ORIG_MEMBEROF,
                                      groups[c]);
         if (ret != EOK) {
             DEBUG(SSSDBG_OP_FAILURE, "sysdb_attrs_add_string failed.\n");
             goto done;
         }
-
-        groups[c][0] = '\0';
     }
 
+    for (add_groups_count = 0; add_groups[add_groups_count] != NULL; add_groups_count++);
     if (DEBUG_IS_SET(SSSDBG_TRACE_ALL)) {
         DEBUG(SSSDBG_TRACE_ALL, "New IPA groups [%zu].\n", c);
 
         for (c = 0; sysdb_ipa_group_memberships[c] != NULL; c++);
         DEBUG(SSSDBG_TRACE_ALL, "Cached IPA groups [%zu].\n", c);
 
-        for (c = 0; add_groups[c] != NULL; c++);
-        DEBUG(SSSDBG_TRACE_ALL, "Groups to add [%zu].\n", c);
+        DEBUG(SSSDBG_TRACE_ALL, "Groups to add [%zu].\n", add_groups_count);
 
         for (c = 0; del_groups[c] != NULL; c++);
         DEBUG(SSSDBG_TRACE_ALL, "Groups to delete [%zu].\n", c);
@@ -420,10 +419,18 @@ static errno_t add_ad_user_to_cached_groups(struct ldb_dn *user_dn,
             if (ret == ENOENT) {
                 DEBUG(SSSDBG_TRACE_ALL, "Group [%s] not in the cache.\n",
                                          add_groups[c]);
-                *missing_groups = true;
-                talloc_free(groups[d]);
-                /* add missing group back to the list */
-                groups[d++] = talloc_steal(groups, add_groups[c]);
+                if (mis_groups == NULL) {
+                    mis_groups = talloc_array(tmp_ctx, char *,
+                                              add_groups_count + 1);
+                    if (mis_groups == NULL) {
+                        DEBUG(SSSDBG_OP_FAILURE,
+                              "Failed to allocate memory for missing groups.\n");
+                        ret = ENOMEM;
+                        goto done;
+                    }
+                }
+                /* add missing group to the list */
+                mis_groups[d++] = talloc_steal(mis_groups, add_groups[c]);
                 continue;
             } else {
                 DEBUG(SSSDBG_OP_FAILURE, "sysdb_search_entry failed.\n");
@@ -439,8 +446,6 @@ static errno_t add_ad_user_to_cached_groups(struct ldb_dn *user_dn,
         }
 
     }
-    talloc_free(groups[d]);
-    groups[d] = NULL;
 
     for (c = 0; del_groups[c] != NULL; c++) {
         ret = sysdb_search_groups_by_orig_dn(tmp_ctx, group_dom, del_groups[c],
@@ -481,6 +486,13 @@ static errno_t add_ad_user_to_cached_groups(struct ldb_dn *user_dn,
 
     in_transaction = false;
 
+    if (mis_groups == NULL) {
+        *_missing_groups = NULL;
+    } else {
+        mis_groups[d] = NULL;
+        *_missing_groups = talloc_steal(mem_ctx, mis_groups);
+    }
+
     ret = EOK;
 done:
     if (in_transaction) {
@@ -740,8 +752,9 @@ static errno_t ipa_add_ext_groups_step(struct tevent_req *req)
         goto fail;
     }
 
-    if (groups == NULL) {
-        DEBUG(SSSDBG_TRACE_ALL, "No external groups memberships found.\n");
+    if (user_dn == NULL) {
+        DEBUG(SSSDBG_TRACE_ALL, "User [%s] not found in cache.\n",
+                                state->user_name);
         state->dp_error = DP_ERR_OK;
         return EOK;
     }
@@ -798,6 +811,58 @@ errno_t ipa_get_trusted_memberships_recv(struct tevent_req *req, int *dp_error_o
     return EOK;
 }
 
+static errno_t filter_groups_by_attribute_name(char **groups,
+                                               const char *allowed_attr_name,
+                                               char ***filtered_groups)
+{
+    size_t c;
+    size_t d = 0;
+    char **tmp_list;
+    size_t name_len;
+
+    if (allowed_attr_name == NULL || filtered_groups == NULL) {
+        DEBUG(SSSDBG_OP_FAILURE, "Missing required parameter.\n");
+        return EINVAL;
+    }
+
+    if (groups == NULL) {
+        *filtered_groups = NULL;
+        return EOK;
+    }
+
+    for (c = 0; groups[c] != NULL; c++);
+
+    /* To reduce the number of memory allocations the new list just "borrows"
+     * the items from the original list so we allocate the new list on the old
+     * one. */
+    tmp_list = talloc_array(groups, char *, c + 1);
+    if (tmp_list == NULL) {
+        DEBUG(SSSDBG_OP_FAILURE,
+              "Failed to allocate memory for output list.\n");
+        return ENOMEM;
+    }
+
+    name_len = strlen(allowed_attr_name);
+    for (c = 0; groups[c] != NULL; c++) {
+        /* If the group's DN string starts with the allowed name followed by
+         * an '=' character it will be added to the new list, all other group
+         * DNs are ignored. */
+        if (strncasecmp(groups[c], allowed_attr_name, name_len) == 0
+                && groups[c][name_len] == '=') {
+            tmp_list[d] = groups[c];
+            d++;
+        } else {
+            DEBUG(SSSDBG_TRACE_ALL, "Ignoring [%s].\n", groups[c]);
+        }
+    }
+
+    tmp_list[d] = NULL;
+
+    *filtered_groups = tmp_list;
+
+    return EOK;
+}
+
 struct add_trusted_membership_state {
     struct tevent_context *ev;
     struct sdap_id_ctx *sdap_id_ctx;
@@ -805,7 +870,9 @@ struct add_trusted_membership_state {
     struct ldb_dn *user_dn;
     struct sss_domain_info *user_dom;
     struct sss_domain_info *group_dom;
+    char **orig_groups; /* a superset of `groups`, memory is shared */
     char **groups;
+    char **missing_groups;
     int dp_error;
     size_t iter;
     struct sdap_domain *group_sdom;
@@ -814,6 +881,9 @@ struct add_trusted_membership_state {
 static void ipa_add_trusted_memberships_connect_done(struct tevent_req *subreq);
 static void ipa_add_trusted_memberships_get_next(struct tevent_req *req);
 static void ipa_add_trusted_memberships_get_group_done(struct tevent_req *subreq);
+/* It is expected (and ever was) that the 'groups' parameter is not freed by
+ * the caller or runs our of scope before the ipa_add_trusted_memberships
+ * request is finished. */
 static struct tevent_req *ipa_add_trusted_memberships_send(TALLOC_CTX *mem_ctx,
                                              struct tevent_context *ev,
                                              struct sdap_id_ctx *sdap_id_ctx,
@@ -826,7 +896,6 @@ static struct tevent_req *ipa_add_trusted_memberships_send(TALLOC_CTX *mem_ctx,
     struct tevent_req *req;
     struct tevent_req *subreq;
     struct add_trusted_membership_state *state;
-    bool missing_groups = false;
 
     req = tevent_req_create(mem_ctx, &state, struct add_trusted_membership_state);
     if (req == NULL) {
@@ -839,7 +908,27 @@ static struct tevent_req *ipa_add_trusted_memberships_send(TALLOC_CTX *mem_ctx,
     state->sdap_id_ctx = sdap_id_ctx;
     state->user_dn = user_dn;
     state->group_dom = group_dom;
-    state->groups = groups;
+    state->orig_groups = groups;
+
+    /* This request will use groups_get_send() to lookup missing groups.
+     * groups_get_send() can currently only lookup "proper" groups which
+     * besides other items means that the group name must be stored under the
+     * LDAP attribute given by the 'ldap_group_name' option. So currently it
+     * does not make sense to try to lookup other objects where the RDN
+     * attribute name is different than this value because those will always
+     * be treated as missing in the cache and always trigger an LDAP search
+     * which will fail. This will typically happen for iPAAssociation objects
+     * which are used to connect users and hosts with HBAC and sudo rules.
+     * If in future a more generic search is used this filter can be removed.
+     */
+    ret = filter_groups_by_attribute_name(groups,
+                                          state->sdap_id_ctx->opts->group_map[SDAP_AT_GROUP_NAME].name,
+                                          &state->groups);
+    if (ret != EOK) {
+        DEBUG(SSSDBG_OP_FAILURE, "Failed to filter group DN list.\n");
+        goto done;
+    }
+
     state->dp_error = -1;
     state->iter = 0;
     state->group_sdom = sdap_domain_get(sdap_id_ctx->opts, group_dom);
@@ -848,14 +937,14 @@ static struct tevent_req *ipa_add_trusted_memberships_send(TALLOC_CTX *mem_ctx,
         goto done;
     }
 
-    ret = add_ad_user_to_cached_groups(user_dn, user_dom, group_dom, groups,
-                                       &missing_groups);
+    ret = add_ad_user_to_cached_groups(state, user_dn, user_dom, group_dom,
+                                       state->groups, &state->missing_groups);
     if (ret != EOK) {
         DEBUG(SSSDBG_OP_FAILURE, "add_ad_user_to_cached_groups failed.\n");
         goto done;
     }
 
-    if (!missing_groups) {
+    if (state->missing_groups == NULL) {
         DEBUG(SSSDBG_TRACE_ALL, "All groups found in cache.\n");
         ret = EOK;
         goto done;
@@ -929,25 +1018,21 @@ static void ipa_add_trusted_memberships_get_next(struct tevent_req *req)
     struct ldb_dn *group_dn;
     int ret;
     const struct ldb_val *val;
-    bool missing_groups;
     const char *fq_name;
     char *tmp_str;
 
-    while (state->groups[state->iter] != NULL
-            && state->groups[state->iter][0] == '\0') {
-        state->iter++;
-    }
-
-    if (state->groups[state->iter] == NULL) {
-        ret = add_ad_user_to_cached_groups(state->user_dn, state->user_dom,
+    if (state->missing_groups[state->iter] == NULL) {
+        talloc_zfree(state->missing_groups);
+        ret = add_ad_user_to_cached_groups(state, state->user_dn,
+                                           state->user_dom,
                                            state->group_dom, state->groups,
-                                           &missing_groups);
+                                           &state->missing_groups);
         if (ret != EOK) {
             DEBUG(SSSDBG_OP_FAILURE, "add_ad_user_to_cached_groups failed.\n");
             goto fail;
         }
 
-        if (missing_groups) {
+        if (state->missing_groups != NULL) {
             /* this might be HBAC or sudo rule */
             DEBUG(SSSDBG_FUNC_DATA, "There are unresolved external group "
                                        "memberships even after all groups "
@@ -959,7 +1044,7 @@ static void ipa_add_trusted_memberships_get_next(struct tevent_req *req)
     }
 
     group_dn = ldb_dn_new(state, sysdb_ctx_get_ldb(state->group_dom->sysdb),
-                          state->groups[state->iter]);
+                          state->missing_groups[state->iter]);
     if (group_dn == NULL) {
         DEBUG(SSSDBG_OP_FAILURE, "ldb_dn_new failed.\n");
         ret = ENOMEM;
@@ -969,7 +1054,7 @@ static void ipa_add_trusted_memberships_get_next(struct tevent_req *req)
     val = ldb_dn_get_rdn_val(group_dn);
     if (val == NULL || val->data == NULL) {
         DEBUG(SSSDBG_OP_FAILURE,
-              "Invalid group DN [%s].\n", state->groups[state->iter]);
+              "Invalid group DN [%s].\n", state->missing_groups[state->iter]);
         ret = EINVAL;
         goto fail;
     }
