@@ -22,6 +22,9 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include <sys/wait.h>
+
+#include "util/child_common.h"
 #include "providers/ldap/sdap_async.h"
 #include "providers/ldap/sdap_idmap.h"
 #include "providers/ipa/ipa_subdomains.h"
@@ -69,7 +72,7 @@ sdap_domain_get_by_trust_type(struct ipa_subdom_server_ctx *trust,
     if (trust->type == IPA_TRUST_AD) {
         sdom = sdap_domain_get(trust->id_ctx.ad_id_ctx->sdap_id_ctx->opts,
                                dom);
-    } else if (trust->type == IPA_TRUST_AD) {
+    } else if (trust->type == IPA_TRUST_IPA) {
         sdom = sdap_domain_get(trust->id_ctx.ipa_id_ctx->sdap_id_ctx->opts,
                                dom);
     }
@@ -572,17 +575,6 @@ ipa_ad_ctx_new(struct be_ctx *be_ctx,
                          id_ctx->sdap_id_ctx->opts,
                          ad_id_ctx->sdap_id_ctx->opts);
 
-    ret = sdap_id_setup_tasks(be_ctx,
-                              ad_id_ctx->sdap_id_ctx,
-                              sdom,
-                              ldap_id_enumeration_send,
-                              ldap_id_enumeration_recv,
-                              ad_id_ctx->sdap_id_ctx);
-    if (ret != EOK) {
-        talloc_free(ad_options);
-        return ret;
-    }
-
     sdom->pvt = ad_id_ctx;
 
     /* Set up the ID mapping object */
@@ -718,16 +710,6 @@ ipa_ctx_new(struct be_ctx *be_ctx,
                          id_ctx->sdap_id_ctx->opts,
                          ipa_subdom_id_ctx->sdap_id_ctx->opts);
 
-    ret = sdap_id_setup_tasks(be_ctx,
-                              ipa_subdom_id_ctx->sdap_id_ctx,
-                              sdom,
-                              ldap_id_enumeration_send,
-                              ldap_id_enumeration_recv,
-                              ipa_subdom_id_ctx->sdap_id_ctx);
-    if (ret != EOK) {
-        goto done;
-    }
-
     sdom->pvt = ipa_subdom_id_ctx;
 
     /* Set up the ID mapping object */
@@ -754,9 +736,15 @@ done:
     return ret;
 }
 
+struct sss_child_ctx;
+int sss_child_handler_setup(struct tevent_context *ev, int pid,
+                            sss_child_sigchld_callback_t cb, void *pvt,
+                            struct sss_child_ctx **_child_ctx);
+void sss_child_handler_destroy(struct sss_child_ctx *ctx);
+
 struct ipa_getkeytab_state {
     int child_status;
-    struct sss_child_ctx_old *child_ctx;
+    struct sss_child_ctx *child_ctx;
     struct tevent_timer *timeout_handler;
 };
 
@@ -806,8 +794,8 @@ static struct tevent_req *ipa_getkeytab_send(TALLOC_CTX *mem_ctx,
         ipa_getkeytab_exec(ccache, server, principal, keytab);
     } else if (child_pid > 0) { /* parent */
         /* Set up SIGCHLD handler */
-        ret = child_handler_setup(ev, child_pid, ipa_getkeytab_done, req,
-                                  &state->child_ctx);
+        ret = sss_child_handler_setup(ev, child_pid, ipa_getkeytab_done, req,
+                                      &state->child_ctx);
         if (ret != EOK) {
             DEBUG(SSSDBG_OP_FAILURE, "Could not set up child handlers [%d]: %s\n",
                 ret, sss_strerror(ret));
@@ -933,7 +921,7 @@ static void ipa_getkeytab_timeout(struct tevent_context *ev,
             tevent_req_data(req, struct ipa_getkeytab_state);
 
     DEBUG(SSSDBG_CRIT_FAILURE, "Timeout reached for retrieving keytab from IPA server\n");
-    child_handler_destroy(state->child_ctx);
+    sss_child_handler_destroy(state->child_ctx);
     state->child_ctx = NULL;
     state->child_status = ETIMEDOUT;
     tevent_req_error(req, ERR_IPA_GETKEYTAB_FAILED);
@@ -1497,20 +1485,31 @@ int ipa_trusted_subdom_init(struct be_ctx *be_ctx,
     }
 
     /* The IPA code relies on the default FQDN format to unparse user
-     * names. Warn loudly if the full_name_format was customized on the
-     * IPA server
+     * names. Refuse to start with short names, warn if the
+     * full_name_format was customized on the IPA server
      */
-    if ((strcmp(be_ctx->domain->names->fq_fmt,
-               CONFDB_DEFAULT_FULL_NAME_FORMAT) != 0)
-            && (strcmp(be_ctx->domain->names->fq_fmt,
-                       CONFDB_DEFAULT_FULL_NAME_FORMAT_INTERNAL) != 0)) {
+    if (strcmp(be_ctx->domain->names->fq_fmt, "%1$s") == 0) {
+        /*
+         * Short name is strictly prohibited in IPA server mode
+         */
+        DEBUG(SSSDBG_FATAL_FAILURE,
+              "%s is set to [%s], this is prohibited in server mode!\n",
+              CONFDB_FULL_NAME_FORMAT, be_ctx->domain->names->fq_fmt);
+        sss_log(SSS_LOG_ERR,
+                "%s is set to [%s], this is prohibited in server mode!\n",
+                CONFDB_FULL_NAME_FORMAT, be_ctx->domain->names->fq_fmt);
+        return EINVAL;
+    } else if (strcmp(be_ctx->domain->names->fq_fmt,
+                      CONFDB_DEFAULT_FULL_NAME_FORMAT) != 0) {
+        /*
+         * Warn if full_name_format is set but attempt to continue
+         */
         DEBUG(SSSDBG_FATAL_FAILURE, "%s is set to a non-default value [%s] " \
               "lookups of subdomain users will likely fail!\n",
               CONFDB_FULL_NAME_FORMAT, be_ctx->domain->names->fq_fmt);
         sss_log(SSS_LOG_ERR, "%s is set to a non-default value [%s] " \
                 "lookups of subdomain users will likely fail!\n",
                 CONFDB_FULL_NAME_FORMAT, be_ctx->domain->names->fq_fmt);
-        /* Attempt to continue */
     }
 
     realm = dp_opt_get_string(id_ctx->ipa_options->basic, IPA_KRB5_REALM);
