@@ -26,14 +26,16 @@
 
 #include <unistd.h>
 #include <sys/types.h>
+#include <pwd.h>
+#include <grp.h>
 #include <sys/stat.h>
 #include <popt.h>
 
+#include "util/child_bootstrap.h"
+#include "shared/io.h"
 #include "util/util.h"
-#include "util/child_common.h"
 #include "util/sss_chain_id.h"
 #include "util/sss_prctl.h"
-#include "providers/backend.h"
 
 /* from selinux_child_semanage.c */
 /* Please note that libsemange relies on files and directories created with
@@ -172,11 +174,9 @@ static bool seuser_needs_update(const char *username,
 
 int main(int argc, const char *argv[])
 {
+    static const size_t IN_BUF_SIZE = 2048;
     int opt;
     poptContext pc;
-    int debug_fd = -1;
-    int dumpable = 1;
-    int backtrace = 1;
     errno_t ret;
     TALLOC_CTX *main_ctx = NULL;
     uint8_t *buf = NULL;
@@ -185,23 +185,11 @@ int main(int argc, const char *argv[])
     struct passwd *passwd = NULL;
     bool needs_update;
     const char *username;
-    const char *opt_logger = NULL;
-    long chain_id;
     uid_t ruid, euid, suid;
     gid_t rgid, egid, sgid;
 
     struct poptOption long_options[] = {
-        POPT_AUTOHELP
-        SSSD_DEBUG_OPTS
-        {"dumpable", 0, POPT_ARG_INT, &dumpable, 0,
-         _("Allow core dumps"), NULL },
-        {"backtrace", 0, POPT_ARG_INT, &backtrace, 0,
-         _("Enable debug backtrace"), NULL },
-        {"debug-fd", 0, POPT_ARG_INT, &debug_fd, 0,
-         _("An open file descriptor for the debug logs"), NULL},
-        {"chain-id", 0, POPT_ARG_LONG, &chain_id,
-         0, _("Tevent chain ID used for logging purposes"), NULL},
-        SSSD_LOGGER_OPTS
+        SSSD_BASIC_CHILD_OPTS
         POPT_TABLEEND
     };
 
@@ -221,29 +209,12 @@ int main(int argc, const char *argv[])
 
     poptFreeContext(pc);
 
-    sss_prctl_set_dumpable((dumpable == 0) ? 0 : 1);
 
-    debug_prg_name = talloc_asprintf(NULL, "selinux_child[%d]", getpid());
-    if (debug_prg_name == NULL) {
-        ERROR("talloc_asprintf failed.\n");
-        goto fail;
+    sss_child_basic_settings.name = "selinux_child";
+    if (!sss_child_setup_basics(&sss_child_basic_settings)) {
+        _exit(-1);
     }
 
-    if (debug_fd != -1) {
-        opt_logger = sss_logger_str[FILES_LOGGER];
-        ret = set_debug_file_from_fd(debug_fd);
-        if (ret != EOK) {
-            opt_logger = sss_logger_str[STDERR_LOGGER];
-            ERROR("set_debug_file_from_fd failed.\n");
-        }
-    }
-
-    sss_chain_id_set_format(DEBUG_CHAIN_ID_FMT_RID);
-    sss_chain_id_set((uint64_t)chain_id);
-
-    DEBUG_INIT(debug_level, opt_logger);
-    sss_set_debug_backtrace_enable((backtrace == 0) ? false : true);
-
     sss_log_process_caps("Starting");
 
     /* The functions semanage_genhomedircon and getseuserbyname use gepwnam_r
