@@ -58,6 +58,7 @@ enum krb5_opts {
     KRB5_RENEW_INTERVAL,
     KRB5_USE_FAST,
     KRB5_FAST_PRINCIPAL,
+    KRB5_FAST_USE_ANONYMOUS_PKINIT,
     KRB5_CANONICALIZE,
     KRB5_USE_ENTERPRISE_PRINCIPAL,
     KRB5_USE_KDCINFO,
@@ -135,6 +136,7 @@ struct krb5_ctx {
     bool sss_creds_password;
 
     hash_table_t *wait_queue_hash;
+    hash_table_t *io_table;
 
     enum krb5_config_type config_type;
 
@@ -144,6 +146,8 @@ struct krb5_ctx {
 
     const char *use_fast_str;
     const char *fast_principal;
+    bool fast_use_anonymous_pkinit;
+    uint32_t check_pac_flags;
 
     bool canonicalize;
 };
