@@ -61,6 +61,7 @@ int ldap_get_options(TALLOC_CTX *memctx,
                                         SDAP_SERVICE_SEARCH_BASE,
                                         SDAP_IPHOST_SEARCH_BASE,
                                         SDAP_IPNETWORK_SEARCH_BASE,
+                                        SDAP_SUBID_RANGES_SEARCH_BASE,
                                         -1 };
 
     opts = talloc_zero(memctx, struct sdap_options);
@@ -153,6 +154,13 @@ int ldap_get_options(TALLOC_CTX *memctx,
                                  &opts->sdom->ipnetwork_search_bases);
     if (ret != EOK && ret != ENOENT) goto done;
 
+#ifdef BUILD_SUBID
+    ret = sdap_parse_search_base(opts, ldb, opts->basic,
+                                 SDAP_SUBID_RANGES_SEARCH_BASE,
+                                 &opts->sdom->subid_ranges_search_bases);
+    if (ret != EOK && ret != ENOENT) goto done;
+#endif
+
     pwd_policy = dp_opt_get_string(opts->basic, SDAP_PWD_POLICY);
     if (pwd_policy == NULL) {
         DEBUG(SSSDBG_CRIT_FAILURE,
@@ -341,6 +349,16 @@ int ldap_get_options(TALLOC_CTX *memctx,
         goto done;
     }
 
+#ifdef BUILD_SUBID
+    ret = sdap_get_map(opts, cdb, conf_path,
+                       subid_map,
+                       SDAP_OPTS_SUBID_RANGE,
+                       &opts->subid_map);
+    if (ret != EOK) {
+        goto done;
+    }
+#endif
+
     ret = sdap_get_map(opts, cdb, conf_path,
                        default_host_map,
                        SDAP_OPTS_HOST,
@@ -621,6 +639,9 @@ errno_t sdap_parse_search_base(TALLOC_CTX *mem_ctx,
     case SDAP_IPNETWORK_SEARCH_BASE:
         class_name = "IPNETWORK";
         break;
+    case SDAP_SUBID_RANGES_SEARCH_BASE:
+        class_name = "SUBID_RANGES";
+        break;
     default:
         DEBUG(SSSDBG_CONF_SETTINGS,
               "Unknown search base type: [%d]\n", class);
