@@ -346,7 +346,7 @@ static errno_t sdap_ad_resolve_sids_step(struct tevent_req *req)
 
     subreq = groups_get_send(state, state->ev, state->id_ctx, sdap_domain,
                              state->conn, state->current_sid,
-                             BE_FILTER_SECID, false, true);
+                             BE_FILTER_SECID, false, true, false);
     if (subreq == NULL) {
         return ENOMEM;
     }
@@ -640,7 +640,7 @@ errno_t sdap_ad_save_group_membership_with_idmapping(const char *username,
             }
 
             ret = sysdb_add_incomplete_group(domain, name, gid,
-                                             NULL, sid, NULL, false, now);
+                                             NULL, sid, NULL, gid != 0, now);
             if (ret == ERR_GID_DUPLICATED) {
                 /* In case o group id-collision, do:
                  * - Delete the group from sysdb
@@ -1333,6 +1333,8 @@ sdap_ad_get_domain_local_groups_parse_parents(TALLOC_CTX *mem_ctx,
         ret = sdap_get_primary_fqdn_list(dom, tmp_ctx, gr->ldap_parents,
                                        gr->parents_count,
                                        opts->group_map[SDAP_AT_GROUP_NAME].name,
+                                       opts->group_map[SDAP_AT_GROUP_OBJECTSID].name,
+                                       opts->idmap_ctx,
                                        &groupnamelist);
         if (ret != EOK) {
             DEBUG(SSSDBG_OP_FAILURE, "sysdb_attrs_primary_fqdn_list failed.\n");
