@@ -41,30 +41,11 @@
 #define LDAP_CHILD SSSD_LIBEXEC_PATH"/ldap_child"
 #endif
 
-struct sdap_child {
-    /* child info */
-    pid_t pid;
-    struct child_io_fds *io;
-};
+#define SIGTERM_TO_SIGKILL_TIME 2
 
-static void sdap_close_fd(int *fd)
-{
-    int ret;
-
-    if (*fd == -1) {
-        DEBUG(SSSDBG_TRACE_FUNC, "fd already closed\n");
-        return;
-    }
-
-    ret = close(*fd);
-    if (ret) {
-        ret = errno;
-        DEBUG(SSSDBG_OP_FAILURE, "Closing fd %d, return error %d (%s)\n",
-                  *fd, ret, strerror(ret));
-    }
-
-    *fd = -1;
-}
+static void get_tgt_timeout_handler(struct tevent_context *ev,
+                                      struct tevent_timer *te,
+                                      struct timeval tv, void *pvt);
 
 static void child_callback(int child_status,
                            struct tevent_signal *sige,
@@ -79,69 +60,6 @@ static void child_callback(int child_status,
     }
 }
 
-static errno_t sdap_fork_child(struct tevent_context *ev,
-                               struct sdap_child *child, struct tevent_req *req)
-{
-    int pipefd_to_child[2] = PIPE_INIT;
-    int pipefd_from_child[2] = PIPE_INIT;
-    pid_t pid;
-    errno_t ret;
-
-    ret = pipe(pipefd_from_child);
-    if (ret == -1) {
-        ret = errno;
-        DEBUG(SSSDBG_CRIT_FAILURE,
-              "pipe(from) failed [%d][%s].\n", ret, strerror(ret));
-        goto fail;
-    }
-    ret = pipe(pipefd_to_child);
-    if (ret == -1) {
-        ret = errno;
-        DEBUG(SSSDBG_CRIT_FAILURE,
-              "pipe(to) failed [%d][%s].\n", ret, strerror(ret));
-        goto fail;
-    }
-
-    pid = fork();
-
-    if (pid == 0) { /* child */
-        exec_child(child,
-                   pipefd_to_child, pipefd_from_child,
-                   LDAP_CHILD, LDAP_CHILD_LOG_FILE);
-
-        /* We should never get here */
-        DEBUG(SSSDBG_CRIT_FAILURE, "BUG: Could not exec LDAP child\n");
-    } else if (pid > 0) { /* parent */
-        child->pid = pid;
-        child->io->read_from_child_fd = pipefd_from_child[0];
-        PIPE_FD_CLOSE(pipefd_from_child[1]);
-        child->io->write_to_child_fd = pipefd_to_child[1];
-        PIPE_FD_CLOSE(pipefd_to_child[0]);
-        sss_fd_nonblocking(child->io->read_from_child_fd);
-        sss_fd_nonblocking(child->io->write_to_child_fd);
-
-        if (ev != NULL) {
-            ret = child_handler_setup(ev, pid, child_callback, req, NULL);
-            if (ret != EOK) {
-                goto fail;
-            }
-        }
-
-    } else { /* error */
-        ret = errno;
-        DEBUG(SSSDBG_CRIT_FAILURE,
-              "fork failed [%d][%s].\n", ret, strerror(ret));
-        goto fail;
-    }
-
-    return EOK;
-
-fail:
-    PIPE_CLOSE(pipefd_from_child);
-    PIPE_CLOSE(pipefd_to_child);
-    return ret;
-}
-
 static errno_t create_child_req_send_buffer(TALLOC_CTX *mem_ctx,
                                             enum ldap_child_command cmd,
                                             const char *realm_str,
@@ -259,32 +177,6 @@ static int parse_child_response(TALLOC_CTX *mem_ctx,
     return EOK;
 }
 
-static errno_t alloc_child(TALLOC_CTX *mem_ctx, struct sdap_child **_child)
-{
-    struct sdap_child *child = NULL;
-
-    if (_child == NULL) {
-        return EFAULT;
-    }
-
-    child = talloc_zero(mem_ctx, struct sdap_child);
-    if (child == NULL) {
-        return ENOMEM;
-    }
-    child->io = talloc(child, struct child_io_fds);
-    if (child->io == NULL) {
-        talloc_free(child);
-        return ENOMEM;
-    }
-    child->io->read_from_child_fd = -1;
-    child->io->write_to_child_fd = -1;
-    talloc_set_destructor((TALLOC_CTX *)child->io, child_io_destructor);
-
-    *_child = child;
-
-    return EOK;
-}
-
 static errno_t parse_select_principal_response(TALLOC_CTX *mem_ctx,
                                                uint8_t *buf, ssize_t size,
                                                char **sasl_primary,
@@ -330,14 +222,9 @@ errno_t sdap_select_principal_from_keytab_sync(TALLOC_CTX *mem_ctx,
     static uint8_t response[2048];
     struct io_buffer *buf = NULL;
     int ret;
-    struct sdap_child *child = NULL;
+    struct child_io_fds *io = NULL;
     ssize_t len;
 
-    ret = alloc_child(mem_ctx, &child);
-    if (ret != EOK) {
-        return ret;
-    }
-
     ret = create_child_req_send_buffer(mem_ctx, LDAP_CHILD_SELECT_PRINCIPAL,
                                        realm_str, princ_str, keytab_name, 0,
                                        &buf);
@@ -347,34 +234,37 @@ errno_t sdap_select_principal_from_keytab_sync(TALLOC_CTX *mem_ctx,
         goto done;
     }
 
-    ret = sdap_fork_child(NULL, child, NULL);
+    ret = sss_child_start(mem_ctx, NULL, LDAP_CHILD, NULL, false,
+                          LDAP_CHILD_LOG_FILE, STDOUT_FILENO,
+                          NULL, NULL,
+                          0, NULL, NULL, false, &io);
     if (ret != EOK) {
-        DEBUG(SSSDBG_CRIT_FAILURE, "sdap_fork_child() failed.\n");
+        DEBUG(SSSDBG_CRIT_FAILURE, "sss_child_start() failed.\n");
         goto done;
     }
 
-    len = sss_atomic_write_s(child->io->write_to_child_fd, buf->data, buf->size);
+    len = sss_atomic_write_s(io->write_to_child_fd, buf->data, buf->size);
     if (len != buf->size) {
         DEBUG(SSSDBG_CRIT_FAILURE, "sss_atomic_write_s() failed\n");
         ret = EIO;
         goto done;
     }
 
-    sdap_close_fd(&child->io->write_to_child_fd);
+    FD_CLOSE(io->write_to_child_fd);
 
-    len = sss_atomic_read_s(child->io->read_from_child_fd,
+    len = sss_atomic_read_s(io->read_from_child_fd,
                             response, sizeof(response));
     if (len <= 0) {
         DEBUG(SSSDBG_CRIT_FAILURE,
               "Failed to get principal from keytab (sss_atomic_read_s() failed), "
-              "see ldap_child.log (pid = %ld) for details.\n", (long)(child->pid));
+              "see ldap_child.log (pid = %ld) for details.\n", (long)(io->pid));
         ret = EIO;
         goto done;
     }
 
-    sdap_close_fd(&child->io->read_from_child_fd);
+    FD_CLOSE(io->read_from_child_fd);
 
-    if (waitpid(child->pid, NULL, WNOHANG) != child->pid) {
+    if (waitpid(io->pid, NULL, WNOHANG) != io->pid) {
         DEBUG(SSSDBG_MINOR_FAILURE, "waitpid(ldap_child) failed, "
               "process might be leaking\n");
     }
@@ -383,7 +273,7 @@ errno_t sdap_select_principal_from_keytab_sync(TALLOC_CTX *mem_ctx,
                                           sasl_primary, sasl_realm);
 
 done:
-    talloc_free(child);
+    talloc_free(io);
     talloc_free(buf);
 
     return ret;
@@ -393,16 +283,13 @@ done:
 
 struct sdap_get_tgt_state {
     struct tevent_context *ev;
-    struct sdap_child *child;
+    struct child_io_fds *io;
     ssize_t len;
     uint8_t *buf;
 
     struct tevent_timer *kill_te;
 };
 
-static errno_t set_tgt_child_timeout(struct tevent_req *req,
-                                     struct tevent_context *ev,
-                                     int timeout);
 static void sdap_get_tgt_step(struct tevent_req *subreq);
 static void sdap_get_tgt_done(struct tevent_req *subreq);
 
@@ -426,11 +313,6 @@ struct tevent_req *sdap_get_tgt_send(TALLOC_CTX *mem_ctx,
 
     state->ev = ev;
 
-    ret = alloc_child(state, &state->child);
-    if (ret != EOK) {
-        goto fail;
-    }
-
     /* prepare the data to pass to child */
     ret = create_child_req_send_buffer(state, LDAP_CHILD_GET_TGT,
                                        realm_str, princ_str, keytab_name, lifetime,
@@ -440,20 +322,18 @@ struct tevent_req *sdap_get_tgt_send(TALLOC_CTX *mem_ctx,
         goto fail;
     }
 
-    ret = sdap_fork_child(state->ev, state->child, req);
+    ret = sss_child_start(state, state->ev, LDAP_CHILD, NULL, false,
+                          LDAP_CHILD_LOG_FILE, STDOUT_FILENO,
+                          child_callback, req,
+                          timeout, get_tgt_timeout_handler, req, false,
+                          &(state->io));
     if (ret != EOK) {
-        DEBUG(SSSDBG_CRIT_FAILURE, "sdap_fork_child failed.\n");
-        goto fail;
-    }
-
-    ret = set_tgt_child_timeout(req, ev, timeout);
-    if (ret != EOK) {
-        DEBUG(SSSDBG_CRIT_FAILURE, "set_tgt_child_timeout failed.\n");
+        DEBUG(SSSDBG_CRIT_FAILURE, "sss_child_start() failed.\n");
         goto fail;
     }
 
     subreq = write_pipe_send(state, ev, buf->data, buf->size,
-                             state->child->io->write_to_child_fd);
+                             state->io->write_to_child_fd);
     if (!subreq) {
         ret = ENOMEM;
         goto fail;
@@ -483,10 +363,10 @@ static void sdap_get_tgt_step(struct tevent_req *subreq)
         return;
     }
 
-    sdap_close_fd(&state->child->io->write_to_child_fd);
+    FD_CLOSE(state->io->write_to_child_fd);
 
     subreq = read_pipe_send(state, state->ev,
-                            state->child->io->read_from_child_fd);
+                            state->io->read_from_child_fd);
     if (!subreq) {
         tevent_req_error(req, ENOMEM);
         return;
@@ -509,7 +389,7 @@ static void sdap_get_tgt_done(struct tevent_req *subreq)
         return;
     }
 
-    sdap_close_fd(&state->child->io->read_from_child_fd);
+    FD_CLOSE(state->io->read_from_child_fd);
 
     if (state->kill_te == NULL) {
         tevent_req_done(req);
@@ -565,9 +445,9 @@ static void get_tgt_sigkill_handler(struct tevent_context *ev,
 
     DEBUG(SSSDBG_TRACE_ALL,
           "timeout for sending SIGKILL to TGT child [%d] reached.\n",
-          state->child->pid);
+          state->io->pid);
 
-    ret = kill(state->child->pid, SIGKILL);
+    ret = kill(state->io->pid, SIGKILL);
     if (ret == -1) {
         DEBUG(SSSDBG_CRIT_FAILURE,
               "kill failed [%d][%s].\n", errno, strerror(errno));
@@ -587,9 +467,9 @@ static void get_tgt_timeout_handler(struct tevent_context *ev,
 
     DEBUG(SSSDBG_TRACE_ALL,
           "timeout for sending SIGTERM to TGT child [%d] reached.\n",
-          state->child->pid);
+          state->io->pid);
 
-    ret = kill(state->child->pid, SIGTERM);
+    ret = kill(state->io->pid, SIGTERM);
     if (ret == -1) {
         ret = errno;
         DEBUG(SSSDBG_CRIT_FAILURE,
@@ -608,24 +488,3 @@ static void get_tgt_timeout_handler(struct tevent_context *ev,
         tevent_req_error(req, ECANCELED);
     }
 }
-
-static errno_t set_tgt_child_timeout(struct tevent_req *req,
-                                     struct tevent_context *ev,
-                                     int timeout)
-{
-    struct tevent_timer *te;
-    struct timeval tv;
-
-    DEBUG(SSSDBG_TRACE_FUNC,
-          "Setting %d seconds timeout for TGT child\n", timeout);
-
-    tv = tevent_timeval_current_ofs(timeout, 0);
-
-    te = tevent_add_timer(ev, req, tv, get_tgt_timeout_handler, req);
-    if (te == NULL) {
-        DEBUG(SSSDBG_CRIT_FAILURE, "tevent_add_timer failed.\n");
-        return ENOMEM;
-    }
-
-    return EOK;
-}
