@@ -52,6 +52,7 @@ struct proxy_id_ctx {
     struct be_ctx *be;
     bool fast_alias;
     struct sss_nss_ops ops;
+    struct sss_certmap_ctx *sss_certmap_ctx;
 };
 
 struct proxy_auth_ctx {
@@ -65,6 +66,16 @@ struct proxy_auth_ctx {
     int timeout_ms;
 };
 
+struct proxy_resolver_ctx {
+    struct sss_nss_ops ops;
+};
+
+struct proxy_module_ctx {
+    struct proxy_id_ctx *id_ctx;
+    struct proxy_auth_ctx *auth_ctx;
+    struct proxy_resolver_ctx *resolver_ctx;
+};
+
 struct proxy_child_ctx {
     struct proxy_auth_ctx *auth_ctx;
     struct be_req *be_req;
@@ -89,9 +100,6 @@ struct pc_init_ctx {
     struct sbus_connection *conn;
 };
 
-//int proxy_client_init(struct sbus_connection *conn, void *data);
-
-#define PROXY_CHILD_PIPE "private/proxy_child"
 #define DEFAULT_BUFSIZE 4096
 #define MAX_BUF_SIZE 1024*1024 /* max 1MiB */
 
@@ -138,8 +146,41 @@ errno_t enum_services(struct proxy_id_ctx *ctx,
                       struct sysdb_ctx *sysdb,
                       struct sss_domain_info *dom);
 
+/* From proxy_hosts.c */
+struct tevent_req *
+proxy_hosts_handler_send(TALLOC_CTX *mem_ctx,
+                      struct proxy_resolver_ctx *proxy_resolver_ctx,
+                      struct dp_resolver_data *resolver_data,
+                      struct dp_req_params *params);
+
+errno_t
+proxy_hosts_handler_recv(TALLOC_CTX *mem_ctx,
+                         struct tevent_req *req,
+                         struct dp_reply_std *data);
+
+/* From proxy_ipnetworks.c */
+struct tevent_req *
+proxy_nets_handler_send(TALLOC_CTX *mem_ctx,
+                        struct proxy_resolver_ctx *proxy_resolver_ctx,
+                        struct dp_resolver_data *resolver_data,
+                        struct dp_req_params *params);
+
+errno_t
+proxy_nets_handler_recv(TALLOC_CTX *mem_ctx,
+                        struct tevent_req *req,
+                        struct dp_reply_std *data);
+
 errno_t
 proxy_client_init(struct sbus_connection *conn,
                   struct proxy_auth_ctx *auth_ctx);
 
+errno_t proxy_init_certmap(TALLOC_CTX *mem_ctx, struct proxy_id_ctx *id_ctx);
+
+
+errno_t proxy_map_cert_to_user(struct proxy_id_ctx *id_ctx,
+                               struct dp_id_data *data);
+
+int get_pw_name(struct proxy_id_ctx *ctx,
+                struct sss_domain_info *dom,
+                const char *i_name);
 #endif /* __PROXY_H__ */
