@@ -39,6 +39,10 @@ enum cache_req_type {
     CACHE_REQ_INITGROUPS,
     CACHE_REQ_INITGROUPS_BY_UPN,
 
+#ifdef BUILD_SUBID
+    CACHE_REQ_SUBID_RANGES_BY_NAME,
+#endif
+
     CACHE_REQ_OBJECT_BY_SID,
     CACHE_REQ_OBJECT_BY_NAME,
     CACHE_REQ_OBJECT_BY_ID,
@@ -95,6 +99,12 @@ enum cache_req_behavior {
 
 struct cache_req_data;
 
+struct cache_req_data *
+cache_req_data_attr(TALLOC_CTX *mem_ctx,
+                    enum cache_req_type type,
+                    const char *attr,
+                    const char *filter);
+
 struct cache_req_data *
 cache_req_data_name(TALLOC_CTX *mem_ctx,
                     enum cache_req_type type,
@@ -175,6 +185,10 @@ void
 cache_req_data_set_propogate_offline_status(struct cache_req_data *data,
                                             bool propogate_offline_status);
 
+void
+cache_req_data_set_hybrid_lookup(struct cache_req_data *data,
+                                 bool hybrid_lookup);
+
 enum cache_req_type
 cache_req_data_get_type(struct cache_req_data *data);
 
@@ -359,6 +373,7 @@ cache_req_user_by_filter_send(TALLOC_CTX *mem_ctx,
                               struct resp_ctx *rctx,
                               enum cache_req_dom_type req_dom_type,
                               const char *domain,
+                              const char *attr,
                               const char *filter);
 
 #define cache_req_user_by_filter_recv(mem_ctx, req, _result) \
@@ -414,28 +429,6 @@ cache_req_object_by_id_send(TALLOC_CTX *mem_ctx,
 #define cache_req_object_by_id_recv(mem_ctx, req, _result) \
     cache_req_single_domain_recv(mem_ctx, req, _result)
 
-struct tevent_req *
-cache_req_enum_users_send(TALLOC_CTX *mem_ctx,
-                          struct tevent_context *ev,
-                          struct resp_ctx *rctx,
-                          struct sss_nc_ctx *ncache,
-                          int cache_refresh_percent,
-                          const char *domain);
-
-#define cache_req_enum_users_recv(mem_ctx, req, _result) \
-    cache_req_recv(mem_ctx, req, _result)
-
-struct tevent_req *
-cache_req_enum_groups_send(TALLOC_CTX *mem_ctx,
-                           struct tevent_context *ev,
-                           struct resp_ctx *rctx,
-                           struct sss_nc_ctx *ncache,
-                           int cache_refresh_percent,
-                           const char *domain);
-
-#define cache_req_enum_groups_recv(mem_ctx, req, _result) \
-    cache_req_recv(mem_ctx, req, _result)
-
 struct tevent_req *
 cache_req_svc_by_name_send(TALLOC_CTX *mem_ctx,
                            struct tevent_context *ev,
