@@ -51,20 +51,6 @@ get_subdomains_send(TALLOC_CTX *mem_ctx,
         return NULL;
     }
 
-    if (is_files_provider(dom)) {
-        DEBUG(SSSDBG_TRACE_INTERNAL, "Domain %s does not check DP\n",
-              dom->name);
-        state->dp_error = DP_ERR_OK;
-        state->error = EOK;
-        state->error_message = talloc_strdup(state, "Success");
-        if (state->error_message == NULL) {
-            ret = ENOMEM;
-            goto done;
-        }
-        ret = EOK;
-        goto done;
-    }
-
     if (rctx->sbus_conn == NULL) {
         DEBUG(SSSDBG_CRIT_FAILURE,
             "BUG: The D-Bus connection is not available!\n");
@@ -86,12 +72,6 @@ get_subdomains_send(TALLOC_CTX *mem_ctx,
     ret = EAGAIN;
 
 done:
-#ifdef BUILD_FILES_PROVIDER
-    if (ret == EOK) {
-        tevent_req_done(req);
-        tevent_req_post(req, rctx->ev);
-    } else
-#endif
     if (ret != EAGAIN) {
         tevent_req_error(req, ret);
         tevent_req_post(req, rctx->ev);
@@ -164,7 +144,6 @@ struct tevent_req *sss_dp_get_domains_send(TALLOC_CTX *mem_ctx,
     struct tevent_req *req;
     struct tevent_req *subreq;
     struct sss_dp_get_domains_state *state;
-    bool refresh_timeout = false;
 
     req = tevent_req_create(mem_ctx, &state, struct sss_dp_get_domains_state);
     if (req == NULL) {
@@ -189,7 +168,6 @@ struct tevent_req *sss_dp_get_domains_send(TALLOC_CTX *mem_ctx,
             goto immediately;
         }
     }
-    refresh_timeout = true;
 
     state->rctx = rctx;
     if (hint != NULL) {
@@ -203,22 +181,6 @@ struct tevent_req *sss_dp_get_domains_send(TALLOC_CTX *mem_ctx,
     }
 
     state->dom = rctx->domains;
-    while(is_files_provider(state->dom)) {
-        state->dom = get_next_domain(state->dom, 0);
-    }
-
-    if (state->dom == NULL) {
-        /* All domains were local */
-        ret = sss_resp_populate_cr_domains(state->rctx);
-        if (ret != EOK) {
-            DEBUG(SSSDBG_CRIT_FAILURE,
-                  "sss_resp_populate_cr_domains() failed [%d]: [%s]\n",
-                  ret, sss_strerror(ret));
-            goto immediately;
-        }
-        ret = EOK;
-        goto immediately;
-    }
 
     subreq = get_subdomains_send(req, rctx, state->dom, state->hint);
     if (subreq == NULL) {
@@ -231,9 +193,6 @@ struct tevent_req *sss_dp_get_domains_send(TALLOC_CTX *mem_ctx,
 
 immediately:
     if (ret == EOK) {
-        if (refresh_timeout) {
-            set_time_of_last_request(rctx);
-        }
         tevent_req_done(req);
     } else {
         tevent_req_error(req, ret);
@@ -291,11 +250,6 @@ sss_dp_get_domains_process(struct tevent_req *subreq)
     /* Advance to the next domain */
     state->dom = get_next_domain(state->dom, 0);
 
-    /* Skip "files provider" */
-    while(is_files_provider(state->dom)) {
-        state->dom = get_next_domain(state->dom, 0);
-    }
-
     if (state->dom == NULL) {
         /* No more domains to check, refreshing the active configuration */
         set_time_of_last_request(state->rctx);
@@ -457,14 +411,6 @@ static void get_domains_at_startup_done(struct tevent_req *req)
         }
     }
 
-    if (is_files_provider(state->rctx->domains)) {
-        ret = sysdb_master_domain_update(state->rctx->domains);
-        if (ret != EOK) {
-            DEBUG(SSSDBG_OP_FAILURE, "sysdb_master_domain_update failed, "
-                                     "ignored.\n");
-        }
-    }
-
     if (state->callback != NULL) {
         state->callback(state->callback_pvt);
     }
