@@ -872,8 +872,8 @@ static errno_t ccdb_secdb_get_cc_for_uuid(TALLOC_CTX *mem_ctx,
             continue;
         }
 
-        cli_cred.ucred.uid = pwd->pw_uid;
-        cli_cred.ucred.gid = pwd->pw_gid;
+        cli_creds_set_uid(&cli_cred, pwd->pw_uid);
+        cli_creds_set_gid(&cli_cred, pwd->pw_gid);
 
         ret = key_by_uuid(tmp_ctx, secdb->sctx, &cli_cred, uuid, &secdb_key);
         if (ret != EOK) {
@@ -1222,7 +1222,7 @@ struct tevent_req *ccdb_secdb_name_by_uuid_send(TALLOC_CTX *mem_ctx,
         goto immediate;
     }
 
-    DEBUG(SSSDBG_TRACE_INTERNAL, "Got ccache by UUID\n");
+    DEBUG(SSSDBG_TRACE_INTERNAL, "Got name '%s' by UUID\n", name);
     ret = EOK;
 immediate:
     if (ret == EOK) {
@@ -1261,7 +1261,7 @@ struct tevent_req *ccdb_secdb_uuid_by_name_send(TALLOC_CTX *mem_ctx,
     errno_t ret;
     char *key;
 
-    DEBUG(SSSDBG_TRACE_INTERNAL, "Translating name to UUID\n");
+    DEBUG(SSSDBG_TRACE_INTERNAL, "Translating name '%s' to UUID\n", name);
 
     req = tevent_req_create(mem_ctx, &state, struct ccdb_secdb_uuid_by_name_state);
     if (req == NULL) {
@@ -1283,7 +1283,7 @@ struct tevent_req *ccdb_secdb_uuid_by_name_send(TALLOC_CTX *mem_ctx,
         goto immediate;
     }
 
-    DEBUG(SSSDBG_TRACE_INTERNAL, "Got ccache by UUID\n");
+    DEBUG(SSSDBG_TRACE_INTERNAL, "Got UUID by name\n");
     ret = EOK;
 immediate:
     if (ret == EOK) {
