@@ -404,6 +404,30 @@ static int pam_process_init(TALLOC_CTX *mem_ctx,
         }
     }
 
+    /* Check if JSON authentication selection method is enabled for any PAM
+     * services
+     */
+    ret = confdb_get_string(pctx->rctx->cdb, pctx, CONFDB_PAM_CONF_ENTRY,
+                            CONFDB_PAM_JSON_SERVICES, "-", &tmpstr);
+    if (ret != EOK) {
+        DEBUG(SSSDBG_FATAL_FAILURE,
+              "Failed to determine json services.\n");
+        goto done;
+    }
+    DEBUG(SSSDBG_TRACE_INTERNAL, "Found value [%s] for option [%s].\n", tmpstr,
+          CONFDB_PAM_JSON_SERVICES);
+
+    if (tmpstr != NULL) {
+        ret = split_on_separator(pctx, tmpstr, ',', true, true,
+                                 &pctx->json_services, NULL);
+        if (ret != EOK) {
+            DEBUG(SSSDBG_MINOR_FAILURE,
+                  "split_on_separator() failed [%d]: [%s].\n", ret,
+                  sss_strerror(ret));
+            goto done;
+        }
+    }
+
     /* The responder is initialized. Now tell it to the monitor. */
     ret = sss_monitor_register_service(rctx, rctx->sbus_conn,
                                        SSS_PAM_SBUS_SERVICE_NAME,
@@ -436,11 +460,13 @@ int main(int argc, const char *argv[])
     char *opt_logger = NULL;
     struct main_context *main_ctx;
     int ret;
+    char *env_listen_pid = NULL;
+    char *env_listen_fds = NULL;
 
     struct poptOption long_options[] = {
         POPT_AUTOHELP
-        SSSD_MAIN_OPTS
-        SSSD_LOGGER_OPTS
+        SSSD_DEBUG_OPTS
+        SSSD_LOGGER_OPTS(&opt_logger)
         SSSD_RESPONDER_OPTS
         POPT_TABLEEND
     };
@@ -452,14 +478,25 @@ int main(int argc, const char *argv[])
 
 #ifndef INTGCHECK_BUILD
     /* This is to clear dangerous variables like 'LDB_MODULES_PATH'
-     * from environment of privileged responder. It's easier to
-     * clear everything since 'sssd_pam' shouldn't rely on any.
+     * from environment of privileged responder.
+     * In case of socket activation, 'LISTEN_PID' and 'LISTEN_FDS'
+     * should be kept as those are used by `sd_listen_fds()`.
      */
+    sss_getenv(NULL, "LISTEN_PID", NULL, &env_listen_pid);
+    sss_getenv(NULL, "LISTEN_FDS", NULL, &env_listen_fds);
     ret = clearenv();
     if (ret != 0) {
         fprintf(stderr, "Failed to clear env.\n");
         return 1;
     }
+    if (env_listen_pid != NULL) {
+        setenv("LISTEN_PID", env_listen_pid, 1);
+        talloc_free(env_listen_pid);
+    }
+    if (env_listen_fds != NULL) {
+        setenv("LISTEN_FDS", env_listen_fds, 1);
+        talloc_free(env_listen_fds);
+    }
 #endif  /* 'intgcheck' relies on 'LDB_MODULES_PATH' to setup a test env */
 
     pc = poptGetContext(argv[0], argc, argv, long_options, 0);
@@ -500,4 +537,3 @@ int main(int argc, const char *argv[])
 
     return 0;
 }
-
