@@ -21,7 +21,6 @@
 #include <popt.h>
 
 #include "util/util.h"
-#include "util/child_common.h"
 #include "confdb/confdb.h"
 #include "responder/common/responder.h"
 #include "responder/ssh/ssh_private.h"
@@ -145,8 +144,8 @@ int main(int argc, const char *argv[])
 
     struct poptOption long_options[] = {
         POPT_AUTOHELP
-        SSSD_MAIN_OPTS
-        SSSD_LOGGER_OPTS
+        SSSD_DEBUG_OPTS
+        SSSD_LOGGER_OPTS(&opt_logger)
         SSSD_RESPONDER_OPTS
         POPT_TABLEEND
     };
