@@ -22,11 +22,18 @@
 #ifndef _SHARED_IO_H_
 #define _SHARED_IO_H_
 
+#include <stdint.h>
+
 /* CAUTION:
  * This file is also used in sss_client (pam, nss). Therefore it have to be
  * minimalist and cannot include DEBUG macros or header file util.h.
  */
 
+struct io_buffer {
+    uint8_t *data;
+    size_t size;
+};
+
 int sss_open_cloexec(const char *pathname, int flags, int *ret);
 int sss_openat_cloexec(int dir_fd, const char *pathname, int flags, int *ret);
 
