@@ -49,7 +49,7 @@ enum sss_mc_state {
  * `SSS_CLI_MC_CTX_INITIALIZER` and `sss_nss_mc_destroy_ctx()`.
  */
 struct sss_cli_mc_ctx {
-    enum sss_mc_state initialized;
+    _Atomic(enum sss_mc_state) initialized;
 #if HAVE_PTHREAD
     pthread_mutex_t *mutex;
 #endif
