@@ -30,6 +30,7 @@
 
 #include "tests/cmocka/common_mock.h"
 #include "tests/common.h"
+#include "providers/ipa/ipa_subdomains.h"
 #include "db/sysdb_private.h" /* for sysdb->ldb member */
 
 #define TESTS_PATH "tp_" BASE_FILE_STEM
@@ -99,8 +100,9 @@ static void test_sysdb_subdomain_create(void **state)
     const char *const dom2[4] = { "dom2.sub", "DOM2.SUB", "dom2", "S-2" };
 
     ret = sysdb_subdomain_store(test_ctx->tctx->sysdb,
-                                dom1[0], dom1[1], dom1[2], dom1[3],
-                                false, false, NULL, 0, NULL);
+                                dom1[0], dom1[1], dom1[2], dom1[0], dom1[3],
+                                MPG_DISABLED, NULL, 0, IPA_TRUST_UNKNOWN,
+                                NULL);
     assert_int_equal(ret, EOK);
 
     ret = sysdb_update_subdomains(test_ctx->tctx->dom, test_ctx->tctx->confdb);
@@ -109,10 +111,12 @@ static void test_sysdb_subdomain_create(void **state)
     assert_non_null(test_ctx->tctx->dom->subdomains);
     assert_string_equal(test_ctx->tctx->dom->subdomains->name, dom1[0]);
     assert_int_equal(test_ctx->tctx->dom->subdomains->trust_direction, 0);
+    assert_true(test_ctx->tctx->dom->subdomains->mpg_mode == MPG_DISABLED);
 
     ret = sysdb_subdomain_store(test_ctx->tctx->sysdb,
-                                dom2[0], dom2[1], dom2[2], dom2[3],
-                                false, false, NULL, 1, NULL);
+                                dom2[0], dom2[1], dom2[2], dom2[0], dom2[3],
+                                MPG_DISABLED, NULL, 1, IPA_TRUST_UNKNOWN,
+                                NULL);
     assert_int_equal(ret, EOK);
 
     ret = sysdb_update_subdomains(test_ctx->tctx->dom, test_ctx->tctx->confdb);
@@ -121,16 +125,19 @@ static void test_sysdb_subdomain_create(void **state)
     assert_non_null(test_ctx->tctx->dom->subdomains->next);
     assert_string_equal(test_ctx->tctx->dom->subdomains->next->name, dom2[0]);
     assert_int_equal(test_ctx->tctx->dom->subdomains->next->trust_direction, 1);
+    assert_true(test_ctx->tctx->dom->subdomains->next->mpg_mode == MPG_DISABLED);
 
     /* Reverse the trust directions */
     ret = sysdb_subdomain_store(test_ctx->tctx->sysdb,
-                                dom1[0], dom1[1], dom1[2], dom1[3],
-                                false, false, NULL, 1, NULL);
+                                dom1[0], dom1[1], dom1[2], dom1[0], dom1[3],
+                                MPG_DISABLED, NULL, 1, IPA_TRUST_UNKNOWN,
+                                NULL);
     assert_int_equal(ret, EOK);
 
     ret = sysdb_subdomain_store(test_ctx->tctx->sysdb,
-                                dom2[0], dom2[1], dom2[2], dom2[3],
-                                false, false, NULL, 0, NULL);
+                                dom2[0], dom2[1], dom2[2], dom2[0], dom2[3],
+                                MPG_DISABLED, NULL, 0, IPA_TRUST_UNKNOWN,
+                                NULL);
     assert_int_equal(ret, EOK);
 
     ret = sysdb_update_subdomains(test_ctx->tctx->dom, test_ctx->tctx->confdb);
@@ -153,6 +160,43 @@ static void test_sysdb_subdomain_create(void **state)
     assert_int_equal(
             sss_domain_get_state(test_ctx->tctx->dom->subdomains->next),
             DOM_DISABLED);
+
+    /* Test that changing the MPG status works */
+    ret = sysdb_subdomain_store(test_ctx->tctx->sysdb,
+                                dom1[0], dom1[1], dom1[2], dom1[0], dom1[3],
+                                MPG_ENABLED, NULL, 1, IPA_TRUST_UNKNOWN,
+                                NULL);
+    assert_int_equal(ret, EOK);
+
+    ret = sysdb_subdomain_store(test_ctx->tctx->sysdb,
+                                dom2[0], dom2[1], dom2[2], dom2[0], dom2[3],
+                                MPG_ENABLED, NULL, 0, IPA_TRUST_UNKNOWN,
+                                NULL);
+    assert_int_equal(ret, EOK);
+
+    ret = sysdb_update_subdomains(test_ctx->tctx->dom, test_ctx->tctx->confdb);
+    assert_int_equal(ret, EOK);
+
+    assert_true(test_ctx->tctx->dom->subdomains->mpg_mode == MPG_ENABLED);
+    assert_true(test_ctx->tctx->dom->subdomains->next->mpg_mode == MPG_ENABLED);
+
+    ret = sysdb_subdomain_store(test_ctx->tctx->sysdb,
+                                dom1[0], dom1[1], dom1[2], dom1[0], dom1[3],
+                                MPG_HYBRID, NULL, 1, IPA_TRUST_UNKNOWN,
+                                NULL);
+    assert_int_equal(ret, EOK);
+
+    ret = sysdb_subdomain_store(test_ctx->tctx->sysdb,
+                                dom2[0], dom2[1], dom2[2], dom2[0], dom2[3],
+                                MPG_HYBRID, NULL, 0, IPA_TRUST_UNKNOWN,
+                                NULL);
+    assert_int_equal(ret, EOK);
+
+    ret = sysdb_update_subdomains(test_ctx->tctx->dom, test_ctx->tctx->confdb);
+    assert_int_equal(ret, EOK);
+
+    assert_true(test_ctx->tctx->dom->subdomains->mpg_mode == MPG_HYBRID);
+    assert_true(test_ctx->tctx->dom->subdomains->next->mpg_mode == MPG_HYBRID);
 }
 
 static void test_sysdb_master_domain_ops(void **state)
@@ -162,7 +206,7 @@ static void test_sysdb_master_domain_ops(void **state)
         talloc_get_type(*state, struct subdom_test_ctx);
 
     ret = sysdb_master_domain_add_info(test_ctx->tctx->dom,
-                                       "realm1", "flat1", "id1", "forest1",
+                                       "realm1", "flat1", "realm1", "id1", "forest1",
                                        NULL);
     assert_int_equal(ret, EOK);
 
@@ -175,7 +219,7 @@ static void test_sysdb_master_domain_ops(void **state)
     assert_string_equal(test_ctx->tctx->dom->forest, "forest1");
 
     ret = sysdb_master_domain_add_info(test_ctx->tctx->dom,
-                                       "realm2", "flat2", "id2", "forest2",
+                                       "realm2", "flat2", "realm2", "id2", "forest2",
                                        NULL);
     assert_int_equal(ret, EOK);
 
@@ -211,28 +255,29 @@ static void test_sysdb_link_forest_root_ipa(void **state)
                                         "CHILD2.DOM1", "S-2-2", "DOM2.SUB" };
 
     ret = sysdb_subdomain_store(test_ctx->tctx->sysdb,
-                                dom1[0], dom1[1], dom1[2], dom1[3],
-                                false, false, dom1[4], 0, NULL);
+                                dom1[0], dom1[1], dom1[2], dom1[0], dom1[3],
+                                MPG_DISABLED, dom1[4], 0, IPA_TRUST_UNKNOWN,
+                                NULL);
     assert_int_equal(ret, EOK);
 
     ret = sysdb_subdomain_store(test_ctx->tctx->sysdb,
                                 child_dom1[0], child_dom1[1],
-                                child_dom1[2], child_dom1[3],
-                                false, false, child_dom1[4],
-                                0, NULL);
+                                child_dom1[2], child_dom1[0], child_dom1[3],
+                                MPG_DISABLED, child_dom1[4],
+                                0, IPA_TRUST_UNKNOWN, NULL);
     assert_int_equal(ret, EOK);
 
     ret = sysdb_subdomain_store(test_ctx->tctx->sysdb,
-                                dom2[0], dom2[1], dom2[2], dom2[3],
-                                false, false, dom2[4],
-                                0, NULL);
+                                dom2[0], dom2[1], dom2[2], dom2[0], dom2[3],
+                                MPG_DISABLED, dom2[4],
+                                0, IPA_TRUST_UNKNOWN, NULL);
     assert_int_equal(ret, EOK);
 
     ret = sysdb_subdomain_store(test_ctx->tctx->sysdb,
                                 child_dom2[0], child_dom2[1],
-                                child_dom2[2], child_dom2[3],
-                                false, false, child_dom2[4],
-                                0, NULL);
+                                child_dom2[2], child_dom2[0], child_dom2[3],
+                                MPG_DISABLED, child_dom2[4],
+                                0, IPA_TRUST_UNKNOWN, NULL);
     assert_int_equal(ret, EOK);
 
     ret = sysdb_update_subdomains(test_ctx->tctx->dom, test_ctx->tctx->confdb);
@@ -296,6 +341,7 @@ static void test_sysdb_link_forest_root_ad(void **state)
     ret = sysdb_master_domain_add_info(test_ctx->tctx->dom,
                                        TEST_REALM,
                                        TEST_FLAT_NAME,
+                                       TEST_REALM,
                                        TEST_SID,
                                        TEST_FOREST,
                                        NULL);
@@ -303,16 +349,16 @@ static void test_sysdb_link_forest_root_ad(void **state)
 
     ret = sysdb_subdomain_store(test_ctx->tctx->sysdb,
                                 child_dom[0], child_dom[1],
-                                child_dom[2], child_dom[3],
-                                false, false, child_dom[4],
-                                0, NULL);
+                                child_dom[2], child_dom[0], child_dom[3],
+                                MPG_DISABLED, child_dom[4],
+                                0, IPA_TRUST_UNKNOWN, NULL);
     assert_int_equal(ret, EOK);
 
     ret = sysdb_subdomain_store(test_ctx->tctx->sysdb,
                                 sub_dom[0], sub_dom[1],
-                                sub_dom[2], sub_dom[3],
-                                false, false, sub_dom[4],
-                                0, NULL);
+                                sub_dom[2], sub_dom[0], sub_dom[3],
+                                MPG_DISABLED, sub_dom[4],
+                                0, IPA_TRUST_UNKNOWN, NULL);
     assert_int_equal(ret, EOK);
 
     ret = sysdb_update_subdomains(test_ctx->tctx->dom, test_ctx->tctx->confdb);
@@ -373,6 +419,7 @@ static void test_sysdb_link_forest_member_ad(void **state)
     ret = sysdb_master_domain_add_info(test_ctx->tctx->dom,
                                        child_dom[1],
                                        child_dom[2],
+                                       child_dom[0],
                                        child_dom[3],
                                        TEST_FOREST,
                                        NULL);
@@ -380,16 +427,16 @@ static void test_sysdb_link_forest_member_ad(void **state)
 
     ret = sysdb_subdomain_store(test_ctx->tctx->sysdb,
                                 sub_dom[0], sub_dom[1],
-                                sub_dom[2], sub_dom[3],
-                                false, false, sub_dom[4],
-                                0, NULL);
+                                sub_dom[2], sub_dom[0], sub_dom[3],
+                                MPG_DISABLED, sub_dom[4],
+                                0, IPA_TRUST_UNKNOWN, NULL);
     assert_int_equal(ret, EOK);
 
     ret = sysdb_subdomain_store(test_ctx->tctx->sysdb,
                                 forest_root[0], forest_root[1],
-                                forest_root[2], forest_root[3],
-                                false, false, forest_root[4],
-                                0, NULL);
+                                forest_root[2], forest_root[0], forest_root[3],
+                                MPG_DISABLED, forest_root[4],
+                                0, IPA_TRUST_UNKNOWN, NULL);
     assert_int_equal(ret, EOK);
 
     ret = sysdb_master_domain_update(test_ctx->tctx->dom);
@@ -458,6 +505,7 @@ static void test_sysdb_link_ad_multidom(void **state)
     ret = sysdb_master_domain_add_info(main_dom1,
                                        TEST_REALM,
                                        TEST_FLAT_NAME,
+                                       TEST_REALM,
                                        TEST_SID,
                                        TEST_FOREST,
                                        NULL);
@@ -465,9 +513,9 @@ static void test_sysdb_link_ad_multidom(void **state)
 
     ret = sysdb_subdomain_store(main_dom1->sysdb,
                                 child_dom[0], child_dom[1],
-                                child_dom[2], child_dom[3],
-                                false, false, child_dom[4],
-                                0, NULL);
+                                child_dom[2], child_dom[0], child_dom[3],
+                                MPG_DISABLED, child_dom[4],
+                                0, IPA_TRUST_UNKNOWN, NULL);
     assert_int_equal(ret, EOK);
 
     ret = sysdb_master_domain_update(main_dom1);
@@ -479,6 +527,7 @@ static void test_sysdb_link_ad_multidom(void **state)
     ret = sysdb_master_domain_add_info(main_dom2,
                                        TEST_REALM2,
                                        TEST_FLAT_NAME2,
+                                       TEST_REALM2,
                                        TEST_SID2,
                                        TEST_FOREST2,
                                        NULL);
@@ -486,8 +535,9 @@ static void test_sysdb_link_ad_multidom(void **state)
 
     ret = sysdb_subdomain_store(main_dom2->sysdb,
                                 dom2_forest_root[0], dom2_forest_root[1],
-                                dom2_forest_root[2], dom2_forest_root[3],
-                                false, false, dom2_forest_root[4], 0, NULL);
+                                dom2_forest_root[2], dom2_forest_root[0], dom2_forest_root[3],
+                                MPG_DISABLED, dom2_forest_root[4], 0, IPA_TRUST_UNKNOWN,
+                                NULL);
     assert_int_equal(ret, EOK);
 
     ret = sysdb_master_domain_update(main_dom2);
@@ -594,12 +644,12 @@ int main(int argc, const char *argv[])
     DEBUG_CLI_INIT(debug_level);
 
     tests_set_cwd();
-    test_dom_suite_cleanup(TESTS_PATH, TEST_CONF_DB, LOCAL_SYSDB_FILE);
+    test_dom_suite_cleanup(TESTS_PATH, TEST_CONF_DB, NULL);
     test_dom_suite_setup(TESTS_PATH);
     rv = cmocka_run_group_tests(tests, NULL, NULL);
 
     if (rv == 0 && no_cleanup == 0) {
-        test_dom_suite_cleanup(TESTS_PATH, TEST_CONF_DB, LOCAL_SYSDB_FILE);
+        test_dom_suite_cleanup(TESTS_PATH, TEST_CONF_DB, NULL);
     }
     return rv;
 }
