@@ -117,7 +117,7 @@ static int _setup_sysdb_tests(struct sysdb_test_ctx **ctx, bool enumerate)
                            "config/domain/FILES", "cache_credentials", val);
     assert_int_equal(ret, EOK);
 
-    ret = sssd_domain_init(test_ctx, test_ctx->confdb, "FILES",
+    ret = test_domain_init(test_ctx, test_ctx->confdb, "FILES",
                            TESTS_PATH, &test_ctx->domain);
     assert_int_equal(ret, EOK);
 
@@ -716,7 +716,7 @@ static void test_sysdb_domain_update_domain_template(void **state)
 
     ret = sysdb_subdomain_store(test_ctx->domain->sysdb,
                                 dom1[0], dom1[1], dom1[2], dom1[0], dom1[3],
-                                MPG_DISABLED, false, dom1[4], 0, IPA_TRUST_UNKNOWN,
+                                MPG_DISABLED, dom1[4], 0, IPA_TRUST_UNKNOWN,
                                 NULL);
     assert_int_equal(ret, EOK);
     ret = sysdb_update_subdomains(test_ctx->domain,
