@@ -582,7 +582,7 @@ int main(int argc, const char *argv[]) {
 
     struct poptOption long_options[] = {
         POPT_AUTOHELP
-        SSSD_MAIN_OPTS
+        SSSD_DEBUG_OPTS
         POPT_TABLEEND
     };
 
