@@ -290,7 +290,7 @@ void dyndns_test_get_ifaddr(void **state)
     will_return_getifaddrs("eth1", "192.168.0.2", AF_INET);
     will_return_getifaddrs(NULL, NULL, 0); /* sentinel */
     will_return_nl_cache_foreach_always(NULL);
-    ret = sss_iface_addr_list_get(dyndns_test_ctx, "eth0", &addrlist);
+    ret = sss_iface_addr_list_get(dyndns_test_ctx, "eth0", NULL, &addrlist);
     assert_int_equal(ret, EOK);
 
     /* There must be only one address with the correct value */
@@ -321,7 +321,7 @@ void dyndns_test_get_multi_ifaddr(void **state)
     will_return_getifaddrs("eth0", "192.168.0.1", AF_INET);
     will_return_getifaddrs(NULL, NULL, 0); /* sentinel */
     will_return_nl_cache_foreach_always(NULL);
-    ret = sss_iface_addr_list_get(dyndns_test_ctx, "eth0", &addrlist);
+    ret = sss_iface_addr_list_get(dyndns_test_ctx, "eth0", NULL, &addrlist);
     assert_int_equal(ret, EOK);
 
     sss_if_addr = addrlist;
@@ -364,7 +364,7 @@ void dyndns_test_get_ifaddr_enoent(void **state)
     will_return_getifaddrs(NULL, NULL, 0); /* sentinel */
     will_return_nl_cache_foreach_always(NULL);
     ret = sss_iface_addr_list_get(dyndns_test_ctx, "non_existing_interface",
-                                  &addrlist);
+                                  NULL, &addrlist);
     assert_int_equal(ret, ENOENT);
     talloc_free(addrlist);
 
@@ -386,30 +386,92 @@ void dyndns_test_get_ifaddr_pattern(void **state)
 {
     errno_t ret;
     struct sss_iface_addr *addrlist;
-    const char *pattern[] = {"*", "eth*", "eth?", "eth[12]", "*vpn*"};
-    int expected_items[] =  {5,   4,      3,      2,         1};
+    struct pattern {
+        const char *pattern;
+        int count;
+    } patterns[] = {
+        {"*", 5},
+        {"eth*", 4},
+        {"eth?", 3},
+        {"eth[12]", 2},
+        {"*vpn*", 1},
+        {"!eth1, eth*", 3},
+        {"!  eth1*, eth*", 2},
+        {NULL, 0}
+    };
     int i;
 
     check_leaks_push(dyndns_test_ctx);
 
     will_return_nl_cache_foreach_always(NULL);
-    for (i = 0; i < 5; i++) {
+    for (i = 0; patterns[i].pattern != NULL; ++i) {
         will_return_getifaddrs("eth0", "192.168.0.1", AF_INET);
         will_return_getifaddrs("eth1", "192.168.0.2", AF_INET);
         will_return_getifaddrs("eth2", "192.168.0.3", AF_INET);
         will_return_getifaddrs("eth10", "192.168.0.4", AF_INET);
         will_return_getifaddrs("vpn1", "192.168.0.5", AF_INET);
         will_return_getifaddrs(NULL, NULL, 0); /* sentinel */
-        ret = sss_iface_addr_list_get(dyndns_test_ctx, pattern[i],
+        ret = sss_iface_addr_list_get(dyndns_test_ctx, patterns[i].pattern,
+                                      NULL,
                                       &addrlist);
         assert_int_equal(ret, EOK);
-        assert_int_equal(ifaddr_list_size (addrlist), expected_items[i]);
+        assert_int_equal(ifaddr_list_size (addrlist), patterns[i].count);
         talloc_free(addrlist);
     }
 
     assert_true(check_leaks_pop(dyndns_test_ctx) == true);
 }
 
+void dyndns_test_get_network_pattern(void **state)
+{
+    errno_t ret;
+    int i;
+    struct sss_iface_addr *addrlist;
+    struct pattern {
+        const char *pattern;
+        int count;
+    } patterns[] = {
+        {"10.0.0.0/8", 3},
+        {"0.0.0.0/0", 3},
+        {"!0.0.0.0/0", 0},
+        {"192.168.0.0/24", 0},
+        {"0.0.0.0/0, !10.0.1.0/24", 2},
+        {"10.0.0.0/24", 1},
+        {"10.0.0.0/23", 2},
+        {"! 10.0.0.2, 10.0.0.0/8", 2},
+        {"::0/0, 0.0.0.0/0", 4},
+        {"cafe::0/32, 10.0.0.0/28", 2},
+        /* invalid filter => no updates */
+        {"noaddress", 0},
+        {"!noaddress", 0},
+        {"!! 10.0.0.0/8", 0},
+        {NULL, 0}
+    };
+
+    check_leaks_push(dyndns_test_ctx);
+
+    will_return_nl_cache_foreach_always(NULL);
+    for (i = 0; patterns[i].pattern != NULL; ++i) {
+        will_return_getifaddrs("eth0", "10.0.0.2", AF_INET);
+        will_return_getifaddrs("eth1", "10.0.1.2", AF_INET);
+        will_return_getifaddrs("eth2", "10.0.2.2", AF_INET);
+        will_return_getifaddrs("eth3", "cafe::2", AF_INET6);
+        will_return_getifaddrs(NULL, NULL, 0); /* sentinel */
+        ret = sss_iface_addr_list_get(dyndns_test_ctx, NULL,
+                                      patterns[i].pattern,
+                                      &addrlist);
+        if (patterns[i].count == 0) {
+            assert_int_not_equal(ret, EOK);
+        } else {
+            assert_int_equal(ret, EOK);
+            assert_int_equal(ifaddr_list_size (addrlist), patterns[i].count);
+            talloc_free(addrlist);
+        }
+    }
+
+    assert_true(check_leaks_pop(dyndns_test_ctx) == true);
+}
+
 
 void dyndns_test_addr_list_as_str_list(void **state)
 {
@@ -436,7 +498,7 @@ void dyndns_test_addr_list_as_str_list(void **state)
     }
     will_return_getifaddrs(NULL, NULL, 0); /* sentinel */
 
-    ret = sss_iface_addr_list_get(dyndns_test_ctx, "eth0", &addrlist);
+    ret = sss_iface_addr_list_get(dyndns_test_ctx, "eth0", NULL, &addrlist);
     assert_int_equal(ret, EOK);
 
     ret = sss_iface_addr_list_as_str_list(dyndns_test_ctx, addrlist, &output);
@@ -477,6 +539,7 @@ void dyndns_test_create_fwd_msg(void **state)
     sin.sin_addr.s_addr = inet_addr ("192.168.0.2");
     ret = sss_get_dualstack_addresses(dyndns_test_ctx,
                                       (struct sockaddr *) &sin,
+                                      NULL,
                                       &addrlist);
     assert_int_equal(ret, EOK);
 
@@ -619,6 +682,7 @@ void dyndns_test_create_fwd_msg_mult(void **state)
     sin.sin_addr.s_addr = inet_addr ("192.168.0.2");
     ret = sss_get_dualstack_addresses(dyndns_test_ctx,
                                       (struct sockaddr *) &sin,
+                                      NULL,
                                       &addrlist);
     assert_int_equal(ret, EOK);
 
@@ -677,6 +741,7 @@ void dyndns_test_exclude_temporary_address(void **state)
     sin.sin_addr.s_addr = inet_addr ("192.168.0.2");
     ret = sss_get_dualstack_addresses(dyndns_test_ctx,
                                       (struct sockaddr *) &sin,
+                                      NULL,
                                       &addrlist);
     assert_int_equal(ret, EOK);
 
@@ -723,6 +788,7 @@ void dyndns_test_create_fwd_msg_A(void **state)
     sin.sin_addr.s_addr = inet_addr ("192.168.0.2");
     ret = sss_get_dualstack_addresses(dyndns_test_ctx,
                                       (struct sockaddr *) &sin,
+                                      NULL,
                                       &addrlist);
     assert_int_equal(ret, EOK);
 
@@ -768,6 +834,7 @@ void dyndns_test_create_fwd_msg_AAAA(void **state)
     assert_int_equal(ret, 1);
     ret = sss_get_dualstack_addresses(dyndns_test_ctx,
                                       (struct sockaddr *) &sin,
+                                      NULL,
                                       &addrlist);
     assert_int_equal(ret, EOK);
 
@@ -814,6 +881,7 @@ void dyndns_test_create_ptr_msg(void **state)
     sin.sin_addr.s_addr = inet_addr ("192.168.0.2");
     ret = sss_get_dualstack_addresses(dyndns_test_ctx,
                                       (struct sockaddr *) &sin,
+                                      NULL,
                                       &addrlist);
     assert_int_equal(ret, EOK);
 
@@ -885,6 +953,7 @@ void dyndns_test_dualstack(void **state)
     sin.sin_addr.s_addr = inet_addr ("192.168.0.2");
     ret = sss_get_dualstack_addresses(dyndns_test_ctx,
                                       (struct sockaddr *) &sin,
+                                      NULL,
                                       &addrlist);
     assert_int_equal(ret, EOK);
 
@@ -947,6 +1016,7 @@ void dyndns_test_dualstack_multiple_addresses(void **state)
     sin.sin_addr.s_addr = inet_addr ("192.168.0.2");
     ret = sss_get_dualstack_addresses(dyndns_test_ctx,
                                       (struct sockaddr *) &sin,
+                                      NULL,
                                       &addrlist);
     assert_int_equal(ret, EOK);
 
@@ -1022,6 +1092,7 @@ void dyndns_test_dualstack_no_iface(void **state)
     sin.sin_addr.s_addr = inet_addr ("192.168.0.3");
     ret = sss_get_dualstack_addresses(dyndns_test_ctx,
                                       (struct sockaddr *) &sin,
+                                      NULL,
                                       &addrlist);
     assert_int_equal(ret, ENOENT);
 
@@ -1204,10 +1275,12 @@ int main(int argc, const char *argv[])
         cmocka_unit_test_setup_teardown(dyndns_test_get_ifaddr_pattern,
                                         dyndns_test_simple_setup,
                                         dyndns_test_teardown),
+        cmocka_unit_test_setup_teardown(dyndns_test_get_network_pattern,
+                                        dyndns_test_simple_setup,
+                                        dyndns_test_teardown),
         cmocka_unit_test_setup_teardown(dyndns_test_addr_list_as_str_list,
                                         dyndns_test_simple_setup,
                                         dyndns_test_teardown),
-
         /* Dynamic DNS update unit tests*/
         cmocka_unit_test_setup_teardown(dyndns_test_ok,
                                         dyndns_test_setup,
