@@ -23,6 +23,7 @@
 #include <popt.h>
 
 #include "db/sysdb_private.h"
+#include "providers/ipa/ipa_subdomains.h"
 #include "tests/cmocka/common_mock.h"
 
 #define NAME        "name"
@@ -109,8 +110,6 @@ void test_default(void **state)
     errno_t ret;
 
     char *fqdn;
-    const int fqdn_size = 255;
-    char fqdn_s[fqdn_size];
 
     if (test_ctx == NULL) {
         DEBUG(SSSDBG_CRIT_FAILURE, "Type mismatch\n");
@@ -127,10 +126,6 @@ void test_default(void **state)
     assert_string_equal(fqdn, NAME"@"DOMNAME);
     talloc_free(fqdn);
 
-    ret = sss_fqname(fqdn_s, fqdn_size, test_ctx->nctx, test_ctx->dom, NAME);
-    assert_int_equal(ret + 1, sizeof(NAME"@"DOMNAME));
-    assert_string_equal(fqdn_s, NAME"@"DOMNAME);
-
     talloc_free(test_ctx->nctx);
 }
 
@@ -141,8 +136,6 @@ void test_all(void **state)
     errno_t ret;
 
     char *fqdn;
-    const int fqdn_size = 255;
-    char fqdn_s[fqdn_size];
 
     if (test_ctx == NULL) {
         DEBUG(SSSDBG_CRIT_FAILURE, "Type mismatch\n");
@@ -159,10 +152,6 @@ void test_all(void **state)
     assert_string_equal(fqdn, NAME"@"DOMNAME"@"FLATNAME);
     talloc_free(fqdn);
 
-    ret = sss_fqname(fqdn_s, fqdn_size, test_ctx->nctx, test_ctx->dom, NAME);
-    assert_int_equal(ret + 1, sizeof(NAME"@"DOMNAME"@"FLATNAME));
-    assert_string_equal(fqdn_s, NAME"@"DOMNAME"@"FLATNAME);
-
     talloc_free(test_ctx->nctx);
 }
 
@@ -173,8 +162,6 @@ void test_flat(void **state)
     errno_t ret;
 
     char *fqdn;
-    const int fqdn_size = 255;
-    char fqdn_s[fqdn_size];
 
     if (test_ctx == NULL) {
         DEBUG(SSSDBG_CRIT_FAILURE, "Type mismatch\n");
@@ -191,10 +178,6 @@ void test_flat(void **state)
     assert_string_equal(fqdn, NAME"@"FLATNAME);
     talloc_free(fqdn);
 
-    ret = sss_fqname(fqdn_s, fqdn_size, test_ctx->nctx, test_ctx->dom, NAME);
-    assert_int_equal(ret + 1, sizeof(NAME"@"FLATNAME));
-    assert_string_equal(fqdn_s, NAME"@"FLATNAME);
-
     talloc_free(test_ctx->nctx);
 }
 
@@ -205,8 +188,6 @@ void test_flat_fallback(void **state)
     errno_t ret;
 
     char *fqdn;
-    const int fqdn_size = 255;
-    char fqdn_s[fqdn_size];
 
     if (test_ctx == NULL) {
         DEBUG(SSSDBG_CRIT_FAILURE, "Type mismatch\n");
@@ -228,10 +209,6 @@ void test_flat_fallback(void **state)
     assert_string_equal(fqdn, NAME"@"DOMNAME);
     talloc_free(fqdn);
 
-    ret = sss_fqname(fqdn_s, fqdn_size, test_ctx->nctx, test_ctx->dom, NAME);
-    assert_int_equal(ret + 1, sizeof(NAME"@"DOMNAME));
-    assert_string_equal(fqdn_s, NAME"@"DOMNAME);
-
     talloc_free(test_ctx->nctx);
 }
 
@@ -307,8 +284,9 @@ static int parse_name_test_setup_re(void **state, const char *regexp)
      * discovered
      */
     test_ctx->subdom = new_subdomain(dom, dom, SUBDOMNAME, NULL, SUBFLATNAME,
-                                     SUBDOMNAME, NULL, MPG_DISABLED, false,
-                                     NULL, NULL, 0, NULL, true);
+                                     SUBDOMNAME, NULL, MPG_DISABLED,
+                                     NULL, NULL, 0, IPA_TRUST_UNKNOWN,
+                                     NULL, true);
     assert_non_null(test_ctx->subdom);
 
     check_leaks_push(test_ctx);
