@@ -10,13 +10,14 @@ import pytest
 from sssd_test_framework.roles.client import Client
 from sssd_test_framework.roles.generic import GenericProvider
 from sssd_test_framework.roles.nfs import NFS
-from sssd_test_framework.topology import KnownTopologyGroup
+from sssd_test_framework.topology import KnownTopology, KnownTopologyGroup
 
 
 @pytest.mark.importance("critical")
 @pytest.mark.ticket(gh=6739)
 @pytest.mark.parametrize("cache_first", [False, True])
 @pytest.mark.topology(KnownTopologyGroup.AnyProvider)
+@pytest.mark.preferred_topology(KnownTopology.LDAP)
 @pytest.mark.parametrize("sssd_service_user", ("root", "sssd"))
 @pytest.mark.require(
     lambda client, sssd_service_user: ((sssd_service_user == "root") or client.features["non-privileged"]),
@@ -31,24 +32,24 @@ def test_autofs__cache_first_set_to_true(
         1. Create NFS export
         2. Create auto.master map
         3. Create auto.export map
-        4. Add /export (auto.export) key to auto.master
+        4. Add /var/export (auto.export) key to auto.master
         5. Add "NFS export" key as "export" to auto.export
         6. Enable autofs responder
         7. Set [autofs]/cache_first = $cache_first
         8. Start SSSD
         9. Reload autofs daemon
     :steps:
-        1. Access /export/export
+        1. Access /var/export/export
         2. Dump automount maps "automount -m"
     :expectedresults:
         1. Directory can be accessed and it is correctly mounted to the NFS share
-        2. /export contains auto.export map and "export" key
+        2. /var/export contains auto.export map and "export" key
     :customerscenario: False
     """
     nfs_export = nfs.export("export").add()
     auto_master = provider.automount.map("auto.master").add()
     auto_export = provider.automount.map("auto.export").add()
-    auto_master.key("/export").add(info=auto_export)
+    auto_master.key("/var/export").add(info=auto_export)
     key = auto_export.key("export").add(info=nfs_export)
 
     # Start SSSD
@@ -60,16 +61,17 @@ def test_autofs__cache_first_set_to_true(
     client.automount.reload()
 
     # Check that we can mount the exported directory
-    assert client.automount.mount("/export/export", nfs_export), "Unable to mount /export/export!"
+    assert client.automount.mount("/var/export/export", nfs_export), "Unable to mount /var/export/export!"
 
     # Check that the maps are correctly fetched
     assert client.automount.dumpmaps() == {
-        "/export": {"map": "auto.export", "keys": [str(key)]},
+        "/var/export": {"map": "auto.export", "keys": [str(key)]},
     }, "Automount maps do not match!"
 
 
 @pytest.mark.importance("medium")
 @pytest.mark.topology(KnownTopologyGroup.AnyProvider)
+@pytest.mark.preferred_topology(KnownTopology.LDAP)
 def test_autofs__propagate_offline_status_for_a_single_domain(client: Client, provider: GenericProvider):
     """
     :title: Autofs propagates offline status if a domain is offline
@@ -108,6 +110,7 @@ def test_autofs__propagate_offline_status_for_a_single_domain(client: Client, pr
 
 @pytest.mark.importance("critical")
 @pytest.mark.topology(KnownTopologyGroup.AnyProvider)
+@pytest.mark.preferred_topology(KnownTopology.LDAP)
 def test_autofs__propagate_offline_status_for_multiple_domains(client: Client):
     """
     :title: Autofs propagates offline status if a domain is offline in multi domain environment
@@ -156,6 +159,7 @@ def test_autofs__propagate_offline_status_for_multiple_domains(client: Client):
 
 @pytest.mark.importance("critical")
 @pytest.mark.topology(KnownTopologyGroup.AnyProvider)
+@pytest.mark.preferred_topology(KnownTopology.LDAP)
 def test_autofs__works_with_some_offline_domains(client: Client, nfs: NFS, provider: GenericProvider):
     """
     :title: Autofs works if some domain is offline in multi domain environment
@@ -163,18 +167,18 @@ def test_autofs__works_with_some_offline_domains(client: Client, nfs: NFS, provi
         1. Create NFS export
         2. Create auto.master map
         3. Create auto.export map
-        4. Add /export (auto.export) key to auto.master
+        4. Add /var/export (auto.export) key to auto.master
         5. Add "NFS export" key as "export" to auto.export
         6. Create two fake LDAP domains that will be offline (the provider is online)
         7. Enable autofs responder
         8. Start SSSD
         9. Reload autofs daemon
     :steps:
-        1. Access /export/export
+        1. Access /var/export/export
         2. Dump automount maps "automount -m"
     :expectedresults:
         1. Directory can be accessed and it is correctly mounted to the NFS share
-        2. /export contains auto.export map and "export" key
+        2. /var/export contains auto.export map and "export" key
     :customerscenario: False
     """
 
@@ -182,7 +186,7 @@ def test_autofs__works_with_some_offline_domains(client: Client, nfs: NFS, provi
     nfs_export = nfs.export("export").add()
     auto_master = provider.automount.map("auto.master").add()
     auto_export = provider.automount.map("auto.export").add()
-    auto_master.key("/export").add(info=auto_export)
+    auto_master.key("/var/export").add(info=auto_export)
     key = auto_export.key("export").add(info=nfs_export)
 
     # Create fake domains, these will be offline
@@ -207,9 +211,9 @@ def test_autofs__works_with_some_offline_domains(client: Client, nfs: NFS, provi
     client.automount.reload()
 
     # Check that we can mount the exported directory
-    assert client.automount.mount("/export/export", nfs_export), "Unable to mount /export/export!"
+    assert client.automount.mount("/var/export/export", nfs_export), "Unable to mount /var/export/export!"
 
     # Check that the maps are correctly fetched
     assert client.automount.dumpmaps() == {
-        "/export": {"map": "auto.export", "keys": [str(key)]},
+        "/var/export": {"map": "auto.export", "keys": [str(key)]},
     }, "Automount maps do not match!"
