@@ -725,3 +725,39 @@ def test_identity__lookup_when_backend_restarts(client: Client, ldap: LDAP):
     # The next lookup should not timeout
     result = client.tools.wait_for_condition("getent passwd tuser", timeout=5)
     assert "tuser" in result.stdout, "tuser was not found"
+
+
+@pytest.mark.importance("high")
+@pytest.mark.ticket(jira="RHEL-128594", gh=8194)
+@pytest.mark.topology(KnownTopology.LDAP)
+def test_identity__filter_groups_by_name_and_lookup_by_gid(client: Client, ldap: LDAP):
+    """
+    :title: Filtered groups cannot be looked up by GID and do not cause hangs
+    :setup:
+        1. Create user 'user-1' and group 'group-1' with GID 20001
+        2. Add 'group-1' to filter_groups in SSSD configuration and start SSSD
+    :steps:
+        1. Lookup group by GID 20001 with getent
+        2. Expire SSSD cache
+        3. Lookup group by GID 20001 again with a timeout to ensure it doesn't hang
+    :expectedresults:
+        1. Group is not found (filtered)
+        2. Cache is expired successfully
+        3. Group lookup completes within timeout and group is still not found
+    :customerscenario: False
+    """
+    u = ldap.user("user-1").add()
+    ldap.group("group-1").add(gid=20001).add_member(u)
+
+    client.sssd.nss["filter_groups"] = "group-1"
+    client.sssd.start()
+
+    result = client.tools.getent.group(20001)
+    assert result is None, "Filtered group was found"
+
+    # Check that the command does not hang when refreshing the GID
+    client.sssctl.cache_expire(everything=True)
+    client.tools.wait_for_condition("getent group 20001 || :", timeout=5)
+
+    result = client.tools.getent.group(20001)
+    assert result is None, "Filtered group was found"
