@@ -33,7 +33,7 @@
 #include "util/util.h"
 #include "db/sysdb.h"
 #include "tools/tools_util.h"
-#include "tools/sss_sync_ops.h"
+#include "tools/common/sss_tools.h"
 #include "confdb/confdb.h"
 
 #ifndef BUFSIZE
@@ -460,7 +460,7 @@ static int seed_init(TALLOC_CTX *mem_ctx,
                      struct seed_ctx **_sctx)
 {
     TALLOC_CTX *tmp_ctx = NULL;
-    int pc_debug = SSSDBG_DEFAULT;
+    int pc_debug = SSSDBG_TOOLS_DEFAULT;
     const char *pc_domain = NULL;
     const char *pc_name = NULL;
     uid_t pc_uid = 0;
@@ -505,14 +505,14 @@ static int seed_init(TALLOC_CTX *mem_ctx,
 
     sctx = talloc_zero(tmp_ctx, struct seed_ctx);
     if (sctx == NULL) {
-        DEBUG(SSSDBG_CRIT_FAILURE, "Could not allocate tools context\n");
+        ERROR("Could not allocate tools context\n");
         ret = ENOMEM;
         goto fini;
     }
 
     sctx->uctx = talloc_zero(sctx, struct user_ctx);
     if (sctx->uctx == NULL) {
-        DEBUG(SSSDBG_CRIT_FAILURE, "Could not allocate user data context\n");
+        ERROR("Could not allocate user data context\n");
         ret = ENOMEM;
         goto fini;
     }
@@ -520,9 +520,7 @@ static int seed_init(TALLOC_CTX *mem_ctx,
     debug_prg_name = argv[0];
     ret = set_locale();
     if (ret != EOK) {
-        DEBUG(SSSDBG_CRIT_FAILURE, "set_locale failed (%d): %s\n",
-                                    ret, strerror(ret));
-        ERROR("Error setting the locale\n");
+        ERROR("set_locale failed (%d): %s\n", ret, strerror(ret));
         ret = EINVAL;
         goto fini;
     }
@@ -631,7 +629,6 @@ static int seed_init_db(TALLOC_CTX *mem_ctx,
                         struct sysdb_ctx **_sysdb)
 {
     TALLOC_CTX *tmp_ctx = NULL;
-    char *confdb_path = NULL;
     struct confdb_ctx *confdb = NULL;
     struct sss_domain_info *domain = NULL;
     int ret = EOK;
@@ -642,14 +639,7 @@ static int seed_init_db(TALLOC_CTX *mem_ctx,
         goto done;
     }
 
-    /* setup confdb */
-    confdb_path = talloc_asprintf(tmp_ctx, "%s/%s", DB_PATH, CONFDB_FILE);
-    if (confdb_path == NULL) {
-        ret = ENOMEM;
-        goto done;
-    }
-
-    ret = confdb_init(tmp_ctx, &confdb, confdb_path);
+    ret = sss_tool_confdb_init(tmp_ctx, &confdb);
     if (ret != EOK) {
         DEBUG(SSSDBG_CRIT_FAILURE,
               "Could not initialize connection to the confdb\n");
