@@ -508,6 +508,21 @@ errno_t sss_authtok_get_passkey(TALLOC_CTX *mem_ctx,
 errno_t sss_authtok_get_passkey_pin(struct sss_auth_token *tok,
                                     const char **pin, size_t *len);
 
+/**
+ * @brief Set local passkey PIN in sss_auth_token structure
+ *
+ * @param tok    A pointer to an sss_auth_token
+ * @param pin    A pointer to a const char *, that will point to a null
+ *               terminated string
+ *
+ * @return       EOK on success
+ *               EINVAL if there's no token
+ *               ENOENT if the token is empty
+ *               EACCESS if the token is not a passkey token
+ */
+errno_t sss_authtok_set_local_passkey_pin(struct sss_auth_token *tok,
+                                          const char *pin);
+
 /**
  * @brief Set passkey kerberos preauth credentials into an auth token,
  *        replacing any previous data.
