@@ -17,7 +17,6 @@
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
-#include <ctype.h>
 #include <stdio.h>
 #include <errno.h>
 #include <talloc.h>
@@ -30,43 +29,6 @@
 #include "util/util_errors.h"
 #include "util/sss_krb5.h"
 
-static char *
-sss_krb5_get_primary(TALLOC_CTX *mem_ctx,
-                     const char *pattern,
-                     const char *hostname)
-{
-    char *primary;
-    char *dot;
-    char *c;
-    char *shortname;
-
-    if (strcmp(pattern, "%S$") == 0) {
-        shortname = talloc_strdup(mem_ctx, hostname);
-        if (!shortname) return NULL;
-
-        dot = strchr(shortname, '.');
-        if (dot) {
-            *dot = '\0';
-        }
-
-        for (c=shortname; *c != '\0'; ++c) {
-            *c = toupper(*c);
-        }
-
-        /* The samAccountName is recommended to be less than 20 characters.
-         * This is only for users and groups. For machine accounts,
-         * the real limit is caused by NetBIOS protocol.
-         * NetBIOS names are limited to 16 (15 + $)
-         * https://support.microsoft.com/en-us/help/163409/netbios-suffixes-16th-character-of-the-netbios-name
-         */
-        primary = talloc_asprintf(mem_ctx, "%.15s$", shortname);
-        talloc_free(shortname);
-        return primary;
-    }
-
-    return talloc_asprintf(mem_ctx, pattern, hostname);
-}
-
 const char *sss_printable_keytab_name(krb5_context ctx, const char *keytab_name)
 {
     /* sss_printable_keytab_name() output is expected to be used
@@ -94,201 +56,6 @@ const char *sss_printable_keytab_name(krb5_context ctx, const char *keytab_name)
     return buff;
 }
 
-errno_t select_principal_from_keytab(TALLOC_CTX *mem_ctx,
-                                     const char *hostname,
-                                     const char *desired_realm,
-                                     const char *keytab_name,
-                                     char **_principal,
-                                     char **_primary,
-                                     char **_realm)
-{
-    krb5_error_code kerr = 0;
-    krb5_context krb_ctx = NULL;
-    krb5_keytab keytab = NULL;
-    krb5_principal client_princ = NULL;
-    TALLOC_CTX *tmp_ctx;
-    char *primary = NULL;
-    char *realm = NULL;
-    int i = 0;
-    errno_t ret;
-    char *principal_string;
-    const char *realm_name;
-    int realm_len;
-    const char *error_message = NULL;
-
-    /**
-     * The %s conversion is passed as-is, the %S conversion is translated to
-     * "short host name"
-     *
-     * Priority of lookup:
-     * - our.hostname@REALM or host/our.hostname@REALM depending on the input
-     * - SHORT.HOSTNAME$@REALM (AD domain)
-     * - host/our.hostname@REALM
-     * - foobar$@REALM (AD domain)
-     * - host/foobar@REALM
-     * - host/foo@BAR
-     * - pick the first principal in the keytab
-     */
-    const char *primary_patterns[] = {"%s", "%S$", "host/%s", "*$", "host/*",
-                                      "host/*", NULL};
-    const char *realm_patterns[] =   {"%s", "%s",  "%s",      "%s", "%s",
-                                      NULL,     NULL};
-
-    DEBUG(SSSDBG_FUNC_DATA,
-          "trying to select the most appropriate principal from keytab\n");
-    tmp_ctx = talloc_new(NULL);
-    if (!tmp_ctx) {
-        DEBUG(SSSDBG_CRIT_FAILURE, "talloc_new failed\n");
-        return ENOMEM;
-    }
-
-    kerr = sss_krb5_init_context(&krb_ctx);
-    if (kerr) {
-        error_message = "Failed to init Kerberos context";
-        ret = EFAULT;
-        goto done;
-    }
-
-    if (keytab_name != NULL) {
-        kerr = krb5_kt_resolve(krb_ctx, keytab_name, &keytab);
-    } else {
-        kerr = krb5_kt_default(krb_ctx, &keytab);
-    }
-    if (kerr) {
-        const char *krb5_err_msg = sss_krb5_get_error_message(krb_ctx, kerr);
-        error_message = talloc_strdup(tmp_ctx, krb5_err_msg);
-        sss_krb5_free_error_message(krb_ctx, krb5_err_msg);
-        ret = EFAULT;
-        goto done;
-    }
-
-    if (!desired_realm) {
-        desired_realm = "*";
-    }
-    if (!hostname) {
-        hostname = "*";
-    }
-
-    do {
-        if (primary_patterns[i]) {
-            primary = sss_krb5_get_primary(tmp_ctx,
-                                           primary_patterns[i],
-                                           hostname);
-            if (primary == NULL) {
-                ret = ENOMEM;
-                goto done;
-            }
-        } else {
-            primary = NULL;
-        }
-        if (realm_patterns[i]) {
-            realm = talloc_asprintf(tmp_ctx, realm_patterns[i], desired_realm);
-            if (realm == NULL) {
-                ret = ENOMEM;
-                goto done;
-            }
-        } else {
-            realm = NULL;
-        }
-
-        kerr = find_principal_in_keytab(krb_ctx, keytab, primary, realm,
-                                        &client_princ);
-        talloc_zfree(primary);
-        talloc_zfree(realm);
-        if (kerr == 0) {
-            break;
-        }
-        if (client_princ != NULL) {
-            krb5_free_principal(krb_ctx, client_princ);
-            client_princ = NULL;
-        }
-        i++;
-    } while(primary_patterns[i-1] != NULL || realm_patterns[i-1] != NULL);
-
-    if (kerr == 0) {
-        if (_principal) {
-            kerr = krb5_unparse_name(krb_ctx, client_princ, &principal_string);
-            if (kerr) {
-                error_message = "krb5_unparse_name failed (_principal)";
-                ret = EINVAL;
-                goto done;
-            }
-
-            *_principal = talloc_strdup(mem_ctx, principal_string);
-            sss_krb5_free_unparsed_name(krb_ctx, principal_string);
-            if (!*_principal) {
-                ret = ENOMEM;
-                goto done;
-            }
-            DEBUG(SSSDBG_FUNC_DATA, "Selected principal: %s\n", *_principal);
-        }
-
-        if (_primary) {
-            kerr = sss_krb5_unparse_name_flags(krb_ctx, client_princ,
-                                               KRB5_PRINCIPAL_UNPARSE_NO_REALM,
-                                               &principal_string);
-            if (kerr) {
-                if (_principal) talloc_zfree(*_principal);
-                error_message = "krb5_unparse_name failed (_primary)";
-                ret = EINVAL;
-                goto done;
-            }
-
-            *_primary = talloc_strdup(mem_ctx, principal_string);
-            sss_krb5_free_unparsed_name(krb_ctx, principal_string);
-            if (!*_primary) {
-                if (_principal) talloc_zfree(*_principal);
-                ret = ENOMEM;
-                goto done;
-            }
-            DEBUG(SSSDBG_FUNC_DATA, "Selected primary: %s\n", *_primary);
-        }
-
-        if (_realm) {
-            sss_krb5_princ_realm(krb_ctx, client_princ,
-                                 &realm_name,
-                                 &realm_len);
-            if (realm_len == 0) {
-                error_message = "sss_krb5_princ_realm failed";
-                if (_principal) talloc_zfree(*_principal);
-                if (_primary) talloc_zfree(*_primary);
-                ret = EINVAL;
-                goto done;
-            }
-
-            *_realm = talloc_asprintf(mem_ctx, "%.*s",
-                                      realm_len, realm_name);
-            if (!*_realm) {
-                if (_principal) talloc_zfree(*_principal);
-                if (_primary) talloc_zfree(*_primary);
-                ret = ENOMEM;
-                goto done;
-            }
-            DEBUG(SSSDBG_FUNC_DATA, "Selected realm: %s\n", *_realm);
-        }
-
-        ret = EOK;
-    } else {
-        ret = ERR_KRB5_PRINCIPAL_NOT_FOUND;
-    }
-
-done:
-    if (ret != EOK) {
-        DEBUG(SSSDBG_FATAL_FAILURE, "Failed to read keytab [%s]: %s\n",
-              sss_printable_keytab_name(krb_ctx, keytab_name),
-              (error_message ? error_message : sss_strerror(ret)));
-
-        sss_log(SSS_LOG_ERR, "Failed to read keytab [%s]: %s\n",
-                sss_printable_keytab_name(krb_ctx, keytab_name),
-                (error_message ? error_message : sss_strerror(ret)));
-    }
-    if (keytab) krb5_kt_close(krb_ctx, keytab);
-    if (client_princ) krb5_free_principal(krb_ctx, client_princ);
-    if (krb_ctx) krb5_free_context(krb_ctx);
-    talloc_free(tmp_ctx);
-    return ret;
-}
-
 enum matching_mode {MODE_NORMAL, MODE_PREFIX, MODE_POSTFIX};
 /**
  * We only have primary and instances stored separately, we need to
