@@ -25,7 +25,6 @@
 #include <stdio.h>
 #include <stdint.h>
 #include <stdbool.h>
-#include <libintl.h>
 #include <locale.h>
 #include <time.h>
 #include <sys/types.h>
@@ -96,8 +95,6 @@ typedef int cap_value_t;
 #define ALLPERMS (S_ISUID|S_ISGID|S_ISVTX|S_IRWXU|S_IRWXG|S_IRWXO)/* 07777 */
 #endif
 
-#define SSSD_MAIN_OPTS SSSD_DEBUG_OPTS
-
 #define SSSD_CONFIG_OPTS(opt_config_file) \
         {"config", 'c', POPT_ARG_STRING, &opt_config_file, 0, \
          _("Specify a non-default config file"), NULL}, \
@@ -125,20 +122,13 @@ enum sssd_exit_status {
     SSS_WATCHDOG_EXIT_CODE = 70 /* to match EX_SOFTWARE in sysexits.h */
 };
 
-#define PIPE_INIT { -1, -1 }
-
-#define PIPE_FD_CLOSE(fd) do {      \
+#define FD_CLOSE(fd) do {           \
     if (fd != -1) {                 \
         close(fd);                  \
         fd = -1;                    \
     }                               \
 } while(0);
 
-#define PIPE_CLOSE(p) do {          \
-    PIPE_FD_CLOSE(p[0]);            \
-    PIPE_FD_CLOSE(p[1]);            \
-} while(0);
-
 #ifndef talloc_zfree
 #define talloc_zfree(ptr) do { talloc_free(discard_const(ptr)); ptr = NULL; } while(0)
 #endif
@@ -191,9 +181,6 @@ void sss_log(int priority, const char *format, ...) SSS_ATTRIBUTE_PRINTF(2, 3);
 void sss_log_ext(int priority, int facility, const char *format, ...) SSS_ATTRIBUTE_PRINTF(3, 4);
 
 /* from server.c */
-#define DEBUG_CHAIN_ID_FMT_RID "[RID#%"PRIu64"] %s"
-#define DEBUG_CHAIN_ID_FMT_CID "[CID#%"PRIu64"] %s"
-
 struct main_context {
     struct tevent_context *event_ctx;
     struct confdb_ctx *confdb_ctx;
@@ -640,9 +627,6 @@ find_domain_by_object_name_ex(struct sss_domain_info *domain,
                               const char *object_name, bool strict,
                               uint32_t gnd_flags);
 
-bool subdomain_enumerates(struct sss_domain_info *parent,
-                          const char *sd_name);
-
 char *subdomain_create_conf_path_from_str(TALLOC_CTX *mem_ctx,
                                           const char *parent_name,
                                           const char *subdom_name);
@@ -737,6 +721,8 @@ errno_t guid_blob_to_string_buf(const uint8_t *blob, char *str_buf,
                                 size_t buf_size);
 
 const char *get_last_x_chars(const char *str, size_t x);
+errno_t string_begins_with(const char *str, const char *prefix, bool *_result);
+errno_t string_ends_with(const char *str, const char *suffix, bool *_result);
 
 char **concatenate_string_array(TALLOC_CTX *mem_ctx,
                                 char **arr1, size_t len1,
